#  ------------------------------------------------------------------------------------------------ #
#  FILE :        Demo_3_EVK1101.mak																	#
# 																									#
#  CONTENTS :																						#
#                Makefile for Demo #3 EVK1101 evaluation board & GCC								#
# 																									#
# 																									#
#  Copyright (c) 2012-2017, Code-Time Technologies Inc. All rights reserved.						#
# 																									#
#  Code-Time Technologies retains all right, title, and interest in and to this work				#
# 																									#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS							#
#  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF										#
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL							#
#  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR								#
#  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,							#
#  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR							#
#  OTHER DEALINGS IN THE SOFTWARE.																	#
# 																									#
# 																									#
# 	$Revision: 1.2 $																				#
# 	$Date: 2014/06/15 14:19:51 $																	#
# 																									#
#  ------------------------------------------------------------------------------------------------ #
#
# Selection between TINY & FULL feature
# SET to either YES or NO
#
TINY := NO

#
# GCC compiler path, if not in the $PATH environment variable; leave empty if in $PATH
# Executable used: avr32-gcc only
# Always put a final "/" as in: /AVRToolchain/bin/
#
TOOLS = 

#  ------------------------------------------------------------------------------------------------ #

.SILENT:
.SUFFIXES:

# -----------------------------------------------------------------
# Project identification & target
#

BOARD     = EVK1101
DEVICE    = uc3b0256
PROJECT   = Demo_3_EVK1101
OPTLVL    = -O3 -g

# -----------------------------------------------------------------
# All the directories where the source code is
# and they are put in VPATH 
#
ASF_DIR  = ../../../asf-3.0.1
DRV_DIR  = ../../../Drivers
INC_DIR  = ../../inc
OBJ_DIR  = ../../obj
PRJ_DIR  = ../Projects
SRC_DIR  = ../../src
RTOS_DIR = ../../../Abassi

DEFINES  = -D BOARD=$(BOARD)								\
           -D OS_ISR_STACK=1024								\
           -D OS_AVR32A_INT_LINE=32							\
           -D OS_AVR32A_INT_GRP=64							\
           -D OS_DEMO=-3									\
           -D OS_PLATFORM=0x00AEA101						\
           -D TC_TSK_STACK=1024								\
           -D OS_UART_ISR=1									\
           -D UART_CIRC_BUF_TX=128							\
           -D UART_CIRC_BUF_RX=128

DEF_ASM =  -D OS_ISR_STACK=0								\
           -D OS_FAST_INTS=0								\
           -D OS_HANDLE_SR_Q=1								\
           -D OS_NEWLIB_REENT=0								\
           -D OS_FIX_RETE_L=1								\
           -D OS_FIX_SR_GIM=1								\
           -D OS_SPURIOUS_ISR=1

# -----------------------------------------------------------------
# Substitution path to look for
#

VPATH = ${RTOS_DIR}											\
		:${INC_DIR}											\
		:${OBJ_DIR}											\
		:${PRJ_DIR}											\
		:${SRC_DIR}											\
		:${DRV_DIR}/inc										\
		:${DRV_DIR}/src										\
		:${ASF_DIR}/avr32/drivers/gpio						\
		:${ASF_DIR}/avr32/drivers/pm						\
		:${ASF_DIR}/avr32/utils/startup						\
		:${ASF_DIR}/avr32/drivers/tc						\
		:${ASF_DIR}/utils/startup							\
		:${ASF_DIR}/avr32/drivers/usart


# -----------------------------------------------------------------
# List of all the source files for this project
#

SRC = 														\
		$(SRC_DIR)/Demo_3_AVR32A.c							\
		${RTOS_DIR}/SysCall_noFS.c							\
		$(DRV_DIR)/src/avr32_uart.c							\
		${ASF_DIR}/avr32/drivers/gpio/gpio.c				\
		${ASF_DIR}/avr32/drivers/pm/pm.c					\
		${ASF_DIR}/avr32/drivers/pm/power_clocks_lib.c		\
		${ASF_DIR}/avr32/drivers/tc/tc.c					\
		${ASF_DIR}/avr32/utils/startup/startup_uc3.S		\
		${ASF_DIR}/avr32/utils/startup/trampoline_uc3.S

# -----------------------------------------------------------------
# List of all the include files for this project
#

INC = 														\
		Abassi.h											\
		AbassiLib.h											\
		SysCall.h											\
		HWinfo.h											\
		Platform.h											\
		avr32_uart.h

# -----------------------------------------------------------------
# Tools set-up
#

CC		=	"$(TOOLS)avr32-gcc"
CFLAGS	=	$(OPTLVL) 													\
			-I$(RTOS_DIR)												\
			-I${INC_DIR}												\
			-I${DRV_DIR}/inc											\
			-I$(ASF_DIR)/avr32/drivers/tc								\
			-I$(ASF_DIR)/avr32/drivers/cpu/cycle_counter				\
			-I$(ASF_DIR)/avr32/boards									\
			-I$(ASF_DIR)/avr32/drivers/intc								\
			-I$(ASF_DIR)/common/utils									\
			-I$(ASF_DIR)/common/boards									\
			-I$(ASF_DIR)/avr32/utils/preprocessor						\
			-I$(ASF_DIR)/avr32/utils									\
			-I$(ASF_DIR)/avr32/drivers/gpio								\
			-I$(ASF_DIR)/avr32/drivers/pm								\
			-I$(ASF_DIR)/avr32/drivers/usart							\
			-fdata-sections	 											\
			-Wall -c -fmessage-length=0						 			\
			-mpart=$(DEVICE)											\
			-ffunction-sections											\
			-masm-addr-pseudos 						\
			-mimm-in-const-pool

LD		=	"$(TOOLS)avr32-gcc"

# -----------------------------------------------------------------

OBJS    = $(patsubst %,%.o, $(basename $(notdir $(SRC))))

ifeq ($(TINY),YES)
	DEFINES += -D TINY_ABASSI=1
	ABASSI_OBJ = $(OBJ_DIR)/Abassi_AVR32_TINY.o $(OBJ_DIR)/Abassi_AVR32A_GCC.o
else
	ABASSI_OBJ = $(OBJ_DIR)/Abassi_AVR32_FULL.o $(OBJ_DIR)/Abassi_AVR32A_GCC.o
endif

# -----------------------------------------------------------------
# Linking
#
all: $(PROJECT).elf

$(PROJECT).elf: $(OBJS)
	echo "Linking"
	$(LD) -o "$(PROJECT).elf" 														\
		$(OBJS)																		\
		$(ABASSI_OBJ)																\
		-nostartfiles 																\
		-L${ASF_DIR}/thirdparty/newlib_addons/libs/at32ucr1							\
		-Wl,-Map="${PROJECT}.map" -Wl,--gc-sections									\
		-Wl,--direct-data															\
		-T$(ASF_DIR)/avr32/utils/linker_scripts/at32uc3b/0256/gcc/link_uc3b0256.lds	\
		-Wl,-e,_trampoline															\
		-mpart=$(DEVICE)															\
		-lnewlib_addons-at32ucr1-speed_opt

# -----------------------------------------------------------------
# Compilation
#

%.o: %.c ${INC}
	echo "Processing $<"
	$(CC) $(DEFINES) $(CFLAGS) -c $<

# -----------------------------------------------------------------
# Assembly
#

%.o: %.s ${INC}
	echo "Processing $<"
	$(CC) $(DEF_ASM) -Wa,-gdwarf2 -x assembler-with-cpp -c -mpart=$(DEVICE) $<

# -----------------------------------------------------------------

clean:
	rm -f $(OBJS)
	rm -f ${PROJECT}.elf
	rm -f ${PROJECT}.map

#EOF
