/*****************************************************************************
 *
 * \file
 *
 * \brief FIR coefficients for the dsp16_resampling function from the DPSLib.
 *        These coefficients have the following caracterizations:
 *          - Input sampling frequency: 44100 Hz
 *          - Output sampling frequency: 48000 Hz
 *          - Re-sampling order: 10
 *          - Coefficients are normalized
 *          - Memory foot print: 3200 bytes
 *         It matches the following parameters:
 *         (dsp16_resampling_options_t::dsp16_custom_filter)
 *          - Cut-off frequency (fc_hz): 22050
 *          - Sampling frequency (fs_hz): 7056000
 *          - Actual FIR filter order (order): 1600
 *
 * Copyright (c) 2010 Atmel Corporation. All rights reserved.
 *
 * \asf_license_start
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 *    Atmel microcontroller product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * \asf_license_stop
 *
 ******************************************************************************/

A_ALIGNED static const dsp16_t dsp16_resampling_fircoef_ord10_44100_48000_norm[] = {
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00004279),
  DSP16_Q(0.00020645),
  DSP16_Q(-0.00058684),
  DSP16_Q(0.00162397),
  DSP16_Q(0.57244643),
  DSP16_Q(-0.00161179),
  DSP16_Q(0.00058334),
  DSP16_Q(-0.00020491),
  DSP16_Q(0.00004221),
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00013012),
  DSP16_Q(0.00062393),
  DSP16_Q(-0.00177086),
  DSP16_Q(0.00490825),
  DSP16_Q(0.57236845),
  DSP16_Q(-0.00479865),
  DSP16_Q(0.00173936),
  DSP16_Q(-0.00061005),
  DSP16_Q(0.00012488),
  DSP16_Q(0.00000003),
  DSP16_Q(-0.00021976),
  DSP16_Q(0.00104741),
  DSP16_Q(-0.00296837),
  DSP16_Q(0.00824062),
  DSP16_Q(0.57221251),
  DSP16_Q(-0.00793621),
  DSP16_Q(0.00288089),
  DSP16_Q(-0.00100886),
  DSP16_Q(0.00020522),
  DSP16_Q(0.00000009),
  DSP16_Q(-0.00031171),
  DSP16_Q(0.00147676),
  DSP16_Q(-0.00417901),
  DSP16_Q(0.01162065),
  DSP16_Q(0.57197864),
  DSP16_Q(-0.01102410),
  DSP16_Q(0.00400762),
  DSP16_Q(-0.00140124),
  DSP16_Q(0.00028322),
  DSP16_Q(0.00000020),
  DSP16_Q(-0.00040596),
  DSP16_Q(0.00191186),
  DSP16_Q(-0.00540244),
  DSP16_Q(0.01504789),
  DSP16_Q(0.57166692),
  DSP16_Q(-0.01406198),
  DSP16_Q(0.00511924),
  DSP16_Q(-0.00178709),
  DSP16_Q(0.00035889),
  DSP16_Q(0.00000038),
  DSP16_Q(-0.00050250),
  DSP16_Q(0.00235259),
  DSP16_Q(-0.00663827),
  DSP16_Q(0.01852187),
  DSP16_Q(0.57127742),
  DSP16_Q(-0.01704950),
  DSP16_Q(0.00621547),
  DSP16_Q(-0.00216631),
  DSP16_Q(0.00043223),
  DSP16_Q(0.00000065),
  DSP16_Q(-0.00060130),
  DSP16_Q(0.00279880),
  DSP16_Q(-0.00788613),
  DSP16_Q(0.02204211),
  DSP16_Q(0.57081025),
  DSP16_Q(-0.01998636),
  DSP16_Q(0.00729601),
  DSP16_Q(-0.00253882),
  DSP16_Q(0.00050324),
  DSP16_Q(0.00000102),
  DSP16_Q(-0.00070237),
  DSP16_Q(0.00325036),
  DSP16_Q(-0.00914563),
  DSP16_Q(0.02560811),
  DSP16_Q(0.57026552),
  DSP16_Q(-0.02287226),
  DSP16_Q(0.00836058),
  DSP16_Q(-0.00290452),
  DSP16_Q(0.00057192),
  DSP16_Q(0.00000151),
  DSP16_Q(-0.00080568),
  DSP16_Q(0.00370713),
  DSP16_Q(-0.01041637),
  DSP16_Q(0.02921935),
  DSP16_Q(0.56964338),
  DSP16_Q(-0.02570690),
  DSP16_Q(0.00940894),
  DSP16_Q(-0.00326335),
  DSP16_Q(0.00063828),
  DSP16_Q(0.00000214),
  DSP16_Q(-0.00091121),
  DSP16_Q(0.00416896),
  DSP16_Q(-0.01169794),
  DSP16_Q(0.03287529),
  DSP16_Q(0.56894400),
  DSP16_Q(-0.02849002),
  DSP16_Q(0.01044081),
  DSP16_Q(-0.00361523),
  DSP16_Q(0.00070233),
  DSP16_Q(0.00000292),
  DSP16_Q(-0.00101893),
  DSP16_Q(0.00463569),
  DSP16_Q(-0.01298993),
  DSP16_Q(0.03657540),
  DSP16_Q(0.56816756),
  DSP16_Q(-0.03122138),
  DSP16_Q(0.01145596),
  DSP16_Q(-0.00396008),
  DSP16_Q(0.00076408),
  DSP16_Q(0.00000387),
  DSP16_Q(-0.00112884),
  DSP16_Q(0.00510718),
  DSP16_Q(-0.01429191),
  DSP16_Q(0.04031911),
  DSP16_Q(0.56731426),
  DSP16_Q(-0.03390073),
  DSP16_Q(0.01245414),
  DSP16_Q(-0.00429784),
  DSP16_Q(0.00082353),
  DSP16_Q(0.00000500),
  DSP16_Q(-0.00124089),
  DSP16_Q(0.00558326),
  DSP16_Q(-0.01560345),
  DSP16_Q(0.04410583),
  DSP16_Q(0.56638432),
  DSP16_Q(-0.03652787),
  DSP16_Q(0.01343514),
  DSP16_Q(-0.00462845),
  DSP16_Q(0.00088071),
  DSP16_Q(0.00000633),
  DSP16_Q(-0.00135507),
  DSP16_Q(0.00606377),
  DSP16_Q(-0.01692411),
  DSP16_Q(0.04793497),
  DSP16_Q(0.56537800),
  DSP16_Q(-0.03910259),
  DSP16_Q(0.01439873),
  DSP16_Q(-0.00495184),
  DSP16_Q(0.00093561),
  DSP16_Q(0.00000789),
  DSP16_Q(-0.00147135),
  DSP16_Q(0.00654854),
  DSP16_Q(-0.01825343),
  DSP16_Q(0.05180592),
  DSP16_Q(0.56429555),
  DSP16_Q(-0.04162471),
  DSP16_Q(0.01534471),
  DSP16_Q(-0.00526797),
  DSP16_Q(0.00098827),
  DSP16_Q(0.00000967),
  DSP16_Q(-0.00158969),
  DSP16_Q(0.00703739),
  DSP16_Q(-0.01959096),
  DSP16_Q(0.05571805),
  DSP16_Q(0.56313725),
  DSP16_Q(-0.04409407),
  DSP16_Q(0.01627288),
  DSP16_Q(-0.00557678),
  DSP16_Q(0.00103869),
  DSP16_Q(0.00001170),
  DSP16_Q(-0.00171007),
  DSP16_Q(0.00753015),
  DSP16_Q(-0.02093622),
  DSP16_Q(0.05967073),
  DSP16_Q(0.56190342),
  DSP16_Q(-0.04651051),
  DSP16_Q(0.01718306),
  DSP16_Q(-0.00587823),
  DSP16_Q(0.00108689),
  DSP16_Q(0.00001400),
  DSP16_Q(-0.00183245),
  DSP16_Q(0.00802663),
  DSP16_Q(-0.02228875),
  DSP16_Q(0.06366328),
  DSP16_Q(0.56059437),
  DSP16_Q(-0.04887390),
  DSP16_Q(0.01807506),
  DSP16_Q(-0.00617229),
  DSP16_Q(0.00113289),
  DSP16_Q(0.00001657),
  DSP16_Q(-0.00195679),
  DSP16_Q(0.00852666),
  DSP16_Q(-0.02364804),
  DSP16_Q(0.06769505),
  DSP16_Q(0.55921044),
  DSP16_Q(-0.05118414),
  DSP16_Q(0.01894871),
  DSP16_Q(-0.00645891),
  DSP16_Q(0.00117671),
  DSP16_Q(0.00001944),
  DSP16_Q(-0.00208306),
  DSP16_Q(0.00903003),
  DSP16_Q(-0.02501362),
  DSP16_Q(0.07176534),
  DSP16_Q(0.55775201),
  DSP16_Q(-0.05344111),
  DSP16_Q(0.01980387),
  DSP16_Q(-0.00673805),
  DSP16_Q(0.00121836),
  DSP16_Q(0.00002261),
  DSP16_Q(-0.00221121),
  DSP16_Q(0.00953657),
  DSP16_Q(-0.02638498),
  DSP16_Q(0.07587345),
  DSP16_Q(0.55621945),
  DSP16_Q(-0.05564473),
  DSP16_Q(0.02064038),
  DSP16_Q(-0.00700971),
  DSP16_Q(0.00125788),
  DSP16_Q(0.00002611),
  DSP16_Q(-0.00234120),
  DSP16_Q(0.01004606),
  DSP16_Q(-0.02776161),
  DSP16_Q(0.08001867),
  DSP16_Q(0.55461316),
  DSP16_Q(-0.05779494),
  DSP16_Q(0.02145809),
  DSP16_Q(-0.00727384),
  DSP16_Q(0.00129529),
  DSP16_Q(0.00002994),
  DSP16_Q(-0.00247300),
  DSP16_Q(0.01055831),
  DSP16_Q(-0.02914299),
  DSP16_Q(0.08420026),
  DSP16_Q(0.55293356),
  DSP16_Q(-0.05989170),
  DSP16_Q(0.02225689),
  DSP16_Q(-0.00753043),
  DSP16_Q(0.00133060),
  DSP16_Q(0.00003411),
  DSP16_Q(-0.00260654),
  DSP16_Q(0.01107312),
  DSP16_Q(-0.03052861),
  DSP16_Q(0.08841748),
  DSP16_Q(0.55118109),
  DSP16_Q(-0.06193496),
  DSP16_Q(0.02303665),
  DSP16_Q(-0.00777947),
  DSP16_Q(0.00136385),
  DSP16_Q(0.00003865),
  DSP16_Q(-0.00274179),
  DSP16_Q(0.01159027),
  DSP16_Q(-0.03191792),
  DSP16_Q(0.09266956),
  DSP16_Q(0.54935622),
  DSP16_Q(-0.06392471),
  DSP16_Q(0.02379726),
  DSP16_Q(-0.00802094),
  DSP16_Q(0.00139506),
  DSP16_Q(0.00004356),
  DSP16_Q(-0.00287870),
  DSP16_Q(0.01210954),
  DSP16_Q(-0.03331039),
  DSP16_Q(0.09695574),
  DSP16_Q(0.54745940),
  DSP16_Q(-0.06586094),
  DSP16_Q(0.02453862),
  DSP16_Q(-0.00825484),
  DSP16_Q(0.00142426),
  DSP16_Q(0.00004886),
  DSP16_Q(-0.00301721),
  DSP16_Q(0.01263073),
  DSP16_Q(-0.03470547),
  DSP16_Q(0.10127523),
  DSP16_Q(0.54549115),
  DSP16_Q(-0.06774368),
  DSP16_Q(0.02526063),
  DSP16_Q(-0.00848116),
  DSP16_Q(0.00145148),
  DSP16_Q(0.00005455),
  DSP16_Q(-0.00315728),
  DSP16_Q(0.01315361),
  DSP16_Q(-0.03610261),
  DSP16_Q(0.10562723),
  DSP16_Q(0.54345196),
  DSP16_Q(-0.06957295),
  DSP16_Q(0.02596322),
  DSP16_Q(-0.00869990),
  DSP16_Q(0.00147674),
  DSP16_Q(0.00006065),
  DSP16_Q(-0.00329883),
  DSP16_Q(0.01367796),
  DSP16_Q(-0.03750124),
  DSP16_Q(0.11001092),
  DSP16_Q(0.54134239),
  DSP16_Q(-0.07134880),
  DSP16_Q(0.02664631),
  DSP16_Q(-0.00891107),
  DSP16_Q(0.00150007),
  DSP16_Q(0.00006717),
  DSP16_Q(-0.00344182),
  DSP16_Q(0.01420356),
  DSP16_Q(-0.03890081),
  DSP16_Q(0.11442548),
  DSP16_Q(0.53916296),
  DSP16_Q(-0.07307130),
  DSP16_Q(0.02730983),
  DSP16_Q(-0.00911467),
  DSP16_Q(0.00152151),
  DSP16_Q(0.00007411),
  DSP16_Q(-0.00358619),
  DSP16_Q(0.01473016),
  DSP16_Q(-0.04030073),
  DSP16_Q(0.11887007),
  DSP16_Q(0.53691426),
  DSP16_Q(-0.07474051),
  DSP16_Q(0.02795374),
  DSP16_Q(-0.00931072),
  DSP16_Q(0.00154110),
  DSP16_Q(0.00008150),
  DSP16_Q(-0.00373188),
  DSP16_Q(0.01525753),
  DSP16_Q(-0.04170042),
  DSP16_Q(0.12334383),
  DSP16_Q(0.53459686),
  DSP16_Q(-0.07635655),
  DSP16_Q(0.02857797),
  DSP16_Q(-0.00949923),
  DSP16_Q(0.00155885),
  DSP16_Q(0.00008933),
  DSP16_Q(-0.00387882),
  DSP16_Q(0.01578545),
  DSP16_Q(-0.04309930),
  DSP16_Q(0.12784590),
  DSP16_Q(0.53221137),
  DSP16_Q(-0.07791950),
  DSP16_Q(0.02918251),
  DSP16_Q(-0.00968023),
  DSP16_Q(0.00157480),
  DSP16_Q(0.00009761),
  DSP16_Q(-0.00402695),
  DSP16_Q(0.01631366),
  DSP16_Q(-0.04449678),
  DSP16_Q(0.13237540),
  DSP16_Q(0.52975841),
  DSP16_Q(-0.07942951),
  DSP16_Q(0.02976731),
  DSP16_Q(-0.00985372),
  DSP16_Q(0.00158899),
  DSP16_Q(0.00010636),
  DSP16_Q(-0.00417620),
  DSP16_Q(0.01684192),
  DSP16_Q(-0.04589225),
  DSP16_Q(0.13693145),
  DSP16_Q(0.52723861),
  DSP16_Q(-0.08088670),
  DSP16_Q(0.03033236),
  DSP16_Q(-0.01001975),
  DSP16_Q(0.00160146),
  DSP16_Q(0.00011558),
  DSP16_Q(-0.00432650),
  DSP16_Q(0.01736999),
  DSP16_Q(-0.04728511),
  DSP16_Q(0.14151314),
  DSP16_Q(0.52465262),
  DSP16_Q(-0.08229124),
  DSP16_Q(0.03087765),
  DSP16_Q(-0.01017833),
  DSP16_Q(0.00161223),
  DSP16_Q(0.00012528),
  DSP16_Q(-0.00447778),
  DSP16_Q(0.01789761),
  DSP16_Q(-0.04867475),
  DSP16_Q(0.14611956),
  DSP16_Q(0.52200112),
  DSP16_Q(-0.08364330),
  DSP16_Q(0.03140317),
  DSP16_Q(-0.01032951),
  DSP16_Q(0.00162134),
  DSP16_Q(0.00013546),
  DSP16_Q(-0.00462997),
  DSP16_Q(0.01842454),
  DSP16_Q(-0.05006055),
  DSP16_Q(0.15074978),
  DSP16_Q(0.51928480),
  DSP16_Q(-0.08494305),
  DSP16_Q(0.03190894),
  DSP16_Q(-0.01047332),
  DSP16_Q(0.00162883),
  DSP16_Q(0.00014612),
  DSP16_Q(-0.00478300),
  DSP16_Q(0.01895051),
  DSP16_Q(-0.05144190),
  DSP16_Q(0.15540288),
  DSP16_Q(0.51650435),
  DSP16_Q(-0.08619070),
  DSP16_Q(0.03239496),
  DSP16_Q(-0.01060980),
  DSP16_Q(0.00163474),
  DSP16_Q(0.00015728),
  DSP16_Q(-0.00493678),
  DSP16_Q(0.01947527),
  DSP16_Q(-0.05281817),
  DSP16_Q(0.16007790),
  DSP16_Q(0.51366049),
  DSP16_Q(-0.08738646),
  DSP16_Q(0.03286127),
  DSP16_Q(-0.01073899),
  DSP16_Q(0.00163910),
  DSP16_Q(0.00016894),
  DSP16_Q(-0.00509125),
  DSP16_Q(0.01999856),
  DSP16_Q(-0.05418871),
  DSP16_Q(0.16477388),
  DSP16_Q(0.51075396),
  DSP16_Q(-0.08853056),
  DSP16_Q(0.03330788),
  DSP16_Q(-0.01086094),
  DSP16_Q(0.00164195),
  DSP16_Q(0.00018109),
  DSP16_Q(-0.00524632),
  DSP16_Q(0.02052012),
  DSP16_Q(-0.05555291),
  DSP16_Q(0.16948987),
  DSP16_Q(0.50778551),
  DSP16_Q(-0.08962324),
  DSP16_Q(0.03373484),
  DSP16_Q(-0.01097569),
  DSP16_Q(0.00164333),
  DSP16_Q(0.00019375),
  DSP16_Q(-0.00540190),
  DSP16_Q(0.02103967),
  DSP16_Q(-0.05691012),
  DSP16_Q(0.17422489),
  DSP16_Q(0.50475590),
  DSP16_Q(-0.09066476),
  DSP16_Q(0.03414221),
  DSP16_Q(-0.01108331),
  DSP16_Q(0.00164328),
  DSP16_Q(0.00020691),
  DSP16_Q(-0.00555793),
  DSP16_Q(0.02155695),
  DSP16_Q(-0.05825969),
  DSP16_Q(0.17897794),
  DSP16_Q(0.50166590),
  DSP16_Q(-0.09165538),
  DSP16_Q(0.03453003),
  DSP16_Q(-0.01118384),
  DSP16_Q(0.00164183),
  DSP16_Q(0.00022057),
  DSP16_Q(-0.00571431),
  DSP16_Q(0.02207169),
  DSP16_Q(-0.05960097),
  DSP16_Q(0.18374804),
  DSP16_Q(0.49851633),
  DSP16_Q(-0.09259539),
  DSP16_Q(0.03489836),
  DSP16_Q(-0.01127735),
  DSP16_Q(0.00163902),
  DSP16_Q(0.00023475),
  DSP16_Q(-0.00587095),
  DSP16_Q(0.02258361),
  DSP16_Q(-0.06093332),
  DSP16_Q(0.18853417),
  DSP16_Q(0.49530798),
  DSP16_Q(-0.09348510),
  DSP16_Q(0.03524729),
  DSP16_Q(-0.01136389),
  DSP16_Q(0.00163491),
  DSP16_Q(0.00024942),
  DSP16_Q(-0.00602777),
  DSP16_Q(0.02309245),
  DSP16_Q(-0.06225607),
  DSP16_Q(0.19333533),
  DSP16_Q(0.49204167),
  DSP16_Q(-0.09432479),
  DSP16_Q(0.03557688),
  DSP16_Q(-0.01144353),
  DSP16_Q(0.00162951),
  DSP16_Q(0.00026460),
  DSP16_Q(-0.00618468),
  DSP16_Q(0.02359793),
  DSP16_Q(-0.06356857),
  DSP16_Q(0.19815049),
  DSP16_Q(0.48871825),
  DSP16_Q(-0.09511481),
  DSP16_Q(0.03588723),
  DSP16_Q(-0.01151633),
  DSP16_Q(0.00162288),
  DSP16_Q(0.00028029),
  DSP16_Q(-0.00634159),
  DSP16_Q(0.02409976),
  DSP16_Q(-0.06487015),
  DSP16_Q(0.20297862),
  DSP16_Q(0.48533856),
  DSP16_Q(-0.09585549),
  DSP16_Q(0.03617843),
  DSP16_Q(-0.01158238),
  DSP16_Q(0.00161505),
  DSP16_Q(0.00029647),
  DSP16_Q(-0.00649840),
  DSP16_Q(0.02459767),
  DSP16_Q(-0.06616015),
  DSP16_Q(0.20781869),
  DSP16_Q(0.48190347),
  DSP16_Q(-0.09654717),
  DSP16_Q(0.03645058),
  DSP16_Q(-0.01164172),
  DSP16_Q(0.00160606),
  DSP16_Q(0.00031315),
  DSP16_Q(-0.00665503),
  DSP16_Q(0.02509138),
  DSP16_Q(-0.06743790),
  DSP16_Q(0.21266963),
  DSP16_Q(0.47841386),
  DSP16_Q(-0.09719022),
  DSP16_Q(0.03670378),
  DSP16_Q(-0.01169445),
  DSP16_Q(0.00159595),
  DSP16_Q(0.00033032),
  DSP16_Q(-0.00681137),
  DSP16_Q(0.02558060),
  DSP16_Q(-0.06870272),
  DSP16_Q(0.21753041),
  DSP16_Q(0.47487061),
  DSP16_Q(-0.09778501),
  DSP16_Q(0.03693816),
  DSP16_Q(-0.01174064),
  DSP16_Q(0.00158477),
  DSP16_Q(0.00034798),
  DSP16_Q(-0.00696734),
  DSP16_Q(0.02606505),
  DSP16_Q(-0.06995395),
  DSP16_Q(0.22239996),
  DSP16_Q(0.47127462),
  DSP16_Q(-0.09833192),
  DSP16_Q(0.03715384),
  DSP16_Q(-0.01178037),
  DSP16_Q(0.00157255),
  DSP16_Q(0.00036611),
  DSP16_Q(-0.00712282),
  DSP16_Q(0.02654444),
  DSP16_Q(-0.07119090),
  DSP16_Q(0.22727720),
  DSP16_Q(0.46762682),
  DSP16_Q(-0.09883136),
  DSP16_Q(0.03735095),
  DSP16_Q(-0.01181371),
  DSP16_Q(0.00155934),
  DSP16_Q(0.00038472),
  DSP16_Q(-0.00727773),
  DSP16_Q(0.02701849),
  DSP16_Q(-0.07241290),
  DSP16_Q(0.23216107),
  DSP16_Q(0.46392813),
  DSP16_Q(-0.09928373),
  DSP16_Q(0.03752962),
  DSP16_Q(-0.01184076),
  DSP16_Q(0.00154517),
  DSP16_Q(0.00040380),
  DSP16_Q(-0.00743195),
  DSP16_Q(0.02748692),
  DSP16_Q(-0.07361928),
  DSP16_Q(0.23705049),
  DSP16_Q(0.46017948),
  DSP16_Q(-0.09968945),
  DSP16_Q(0.03768999),
  DSP16_Q(-0.01186160),
  DSP16_Q(0.00153008),
  DSP16_Q(0.00042333),
  DSP16_Q(-0.00758540),
  DSP16_Q(0.02794942),
  DSP16_Q(-0.07480934),
  DSP16_Q(0.24194437),
  DSP16_Q(0.45638182),
  DSP16_Q(-0.10004896),
  DSP16_Q(0.03783222),
  DSP16_Q(-0.01187631),
  DSP16_Q(0.00151412),
  DSP16_Q(0.00044332),
  DSP16_Q(-0.00773797),
  DSP16_Q(0.02840572),
  DSP16_Q(-0.07598240),
  DSP16_Q(0.24684161),
  DSP16_Q(0.45253612),
  DSP16_Q(-0.10036270),
  DSP16_Q(0.03795645),
  DSP16_Q(-0.01188499),
  DSP16_Q(0.00149731),
  DSP16_Q(0.00046374),
  DSP16_Q(-0.00788954),
  DSP16_Q(0.02885552),
  DSP16_Q(-0.07713779),
  DSP16_Q(0.25174111),
  DSP16_Q(0.44864335),
  DSP16_Q(-0.10063112),
  DSP16_Q(0.03806286),
  DSP16_Q(-0.01188773),
  DSP16_Q(0.00147972),
  DSP16_Q(0.00048459),
  DSP16_Q(-0.00804002),
  DSP16_Q(0.02929853),
  DSP16_Q(-0.07827482),
  DSP16_Q(0.25664179),
  DSP16_Q(0.44470448),
  DSP16_Q(-0.10085469),
  DSP16_Q(0.03815161),
  DSP16_Q(-0.01188462),
  DSP16_Q(0.00146136),
  DSP16_Q(0.00050585),
  DSP16_Q(-0.00818931),
  DSP16_Q(0.02973447),
  DSP16_Q(-0.07939281),
  DSP16_Q(0.26154252),
  DSP16_Q(0.44072051),
  DSP16_Q(-0.10103388),
  DSP16_Q(0.03822287),
  DSP16_Q(-0.01187576),
  DSP16_Q(0.00144228),
  DSP16_Q(0.00052752),
  DSP16_Q(-0.00833728),
  DSP16_Q(0.03016304),
  DSP16_Q(-0.08049106),
  DSP16_Q(0.26644219),
  DSP16_Q(0.43669245),
  DSP16_Q(-0.10116917),
  DSP16_Q(0.03827682),
  DSP16_Q(-0.01186124),
  DSP16_Q(0.00142253),
  DSP16_Q(0.00054958),
  DSP16_Q(-0.00848384),
  DSP16_Q(0.03058396),
  DSP16_Q(-0.08156890),
  DSP16_Q(0.27133970),
  DSP16_Q(0.43262129),
  DSP16_Q(-0.10126106),
  DSP16_Q(0.03831364),
  DSP16_Q(-0.01184117),
  DSP16_Q(0.00140213),
  DSP16_Q(0.00057201),
  DSP16_Q(-0.00862888),
  DSP16_Q(0.03099693),
  DSP16_Q(-0.08262565),
  DSP16_Q(0.27623391),
  DSP16_Q(0.42850806),
  DSP16_Q(-0.10131007),
  DSP16_Q(0.03833354),
  DSP16_Q(-0.01181564),
  DSP16_Q(0.00138113),
  DSP16_Q(0.00059480),
  DSP16_Q(-0.00877227),
  DSP16_Q(0.03140165),
  DSP16_Q(-0.08366061),
  DSP16_Q(0.28112372),
  DSP16_Q(0.42435379),
  DSP16_Q(-0.10131668),
  DSP16_Q(0.03833669),
  DSP16_Q(-0.01178475),
  DSP16_Q(0.00135957),
  DSP16_Q(0.00061794),
  DSP16_Q(-0.00891393),
  DSP16_Q(0.03179786),
  DSP16_Q(-0.08467310),
  DSP16_Q(0.28600799),
  DSP16_Q(0.42015952),
  DSP16_Q(-0.10128145),
  DSP16_Q(0.03832332),
  DSP16_Q(-0.01174862),
  DSP16_Q(0.00133748),
  DSP16_Q(0.00064140),
  DSP16_Q(-0.00905372),
  DSP16_Q(0.03218524),
  DSP16_Q(-0.08566245),
  DSP16_Q(0.29088559),
  DSP16_Q(0.41592629),
  DSP16_Q(-0.10120488),
  DSP16_Q(0.03829361),
  DSP16_Q(-0.01170734),
  DSP16_Q(0.00131489),
  DSP16_Q(0.00066517),
  DSP16_Q(-0.00919155),
  DSP16_Q(0.03256352),
  DSP16_Q(-0.08662797),
  DSP16_Q(0.29575540),
  DSP16_Q(0.41165515),
  DSP16_Q(-0.10108753),
  DSP16_Q(0.03824778),
  DSP16_Q(-0.01166102),
  DSP16_Q(0.00129186),
  DSP16_Q(0.00068923),
  DSP16_Q(-0.00932729),
  DSP16_Q(0.03293241),
  DSP16_Q(-0.08756899),
  DSP16_Q(0.30061628),
  DSP16_Q(0.40734716),
  DSP16_Q(-0.10092995),
  DSP16_Q(0.03818605),
  DSP16_Q(-0.01160976),
  DSP16_Q(0.00126841),
  DSP16_Q(0.00071357),
  DSP16_Q(-0.00946084),
  DSP16_Q(0.03329162),
  DSP16_Q(-0.08848482),
  DSP16_Q(0.30546709),
  DSP16_Q(0.40300340),
  DSP16_Q(-0.10073268),
  DSP16_Q(0.03810863),
  DSP16_Q(-0.01155369),
  DSP16_Q(0.00124457),
  DSP16_Q(0.00073815),
  DSP16_Q(-0.00959207),
  DSP16_Q(0.03364086),
  DSP16_Q(-0.08937479),
  DSP16_Q(0.31030672),
  DSP16_Q(0.39862493),
  DSP16_Q(-0.10049630),
  DSP16_Q(0.03801576),
  DSP16_Q(-0.01149289),
  DSP16_Q(0.00122040),
  DSP16_Q(0.00076297),
  DSP16_Q(-0.00972088),
  DSP16_Q(0.03397986),
  DSP16_Q(-0.09023823),
  DSP16_Q(0.31513400),
  DSP16_Q(0.39421284),
  DSP16_Q(-0.10022138),
  DSP16_Q(0.03790765),
  DSP16_Q(-0.01142749),
  DSP16_Q(0.00119591),
  DSP16_Q(0.00078799),
  DSP16_Q(-0.00984715),
  DSP16_Q(0.03430832),
  DSP16_Q(-0.09107447),
  DSP16_Q(0.31994782),
  DSP16_Q(0.38976821),
  DSP16_Q(-0.09990850),
  DSP16_Q(0.03778455),
  DSP16_Q(-0.01135759),
  DSP16_Q(0.00117114),
  DSP16_Q(0.00081320),
  DSP16_Q(-0.00997076),
  DSP16_Q(0.03462596),
  DSP16_Q(-0.09188283),
  DSP16_Q(0.32474703),
  DSP16_Q(0.38529214),
  DSP16_Q(-0.09955825),
  DSP16_Q(0.03764670),
  DSP16_Q(-0.01128331),
  DSP16_Q(0.00114613),
  DSP16_Q(0.00083857),
  DSP16_Q(-0.01009160),
  DSP16_Q(0.03493251),
  DSP16_Q(-0.09266266),
  DSP16_Q(0.32953050),
  DSP16_Q(0.38078571),
  DSP16_Q(-0.09917121),
  DSP16_Q(0.03749432),
  DSP16_Q(-0.01120477),
  DSP16_Q(0.00112091),
  DSP16_Q(0.00086408),
  DSP16_Q(-0.01020955),
  DSP16_Q(0.03522769),
  DSP16_Q(-0.09341330),
  DSP16_Q(0.33429709),
  DSP16_Q(0.37625005),
  DSP16_Q(-0.09874800),
  DSP16_Q(0.03732768),
  DSP16_Q(-0.01112206),
  DSP16_Q(0.00109552),
  DSP16_Q(0.00088971),
  DSP16_Q(-0.01032450),
  DSP16_Q(0.03551122),
  DSP16_Q(-0.09413407),
  DSP16_Q(0.33904566),
  DSP16_Q(0.37168625),
  DSP16_Q(-0.09828922),
  DSP16_Q(0.03714701),
  DSP16_Q(-0.01103531),
  DSP16_Q(0.00106998),
  DSP16_Q(0.00091542),
  DSP16_Q(-0.01043633),
  DSP16_Q(0.03578282),
  DSP16_Q(-0.09482434),
  DSP16_Q(0.34377509),
  DSP16_Q(0.36709542),
  DSP16_Q(-0.09779549),
  DSP16_Q(0.03695256),
  DSP16_Q(-0.01094463),
  DSP16_Q(0.00104433),
  DSP16_Q(0.00094119),
  DSP16_Q(-0.01054493),
  DSP16_Q(0.03604223),
  DSP16_Q(-0.09548346),
  DSP16_Q(0.34848423),
  DSP16_Q(0.36247868),
  DSP16_Q(-0.09726741),
  DSP16_Q(0.03674461),
  DSP16_Q(-0.01085014),
  DSP16_Q(0.00101859),
  DSP16_Q(0.00096699),
  DSP16_Q(-0.01065017),
  DSP16_Q(0.03628918),
  DSP16_Q(-0.09611076),
  DSP16_Q(0.35317197),
  DSP16_Q(0.35783716),
  DSP16_Q(-0.09670563),
  DSP16_Q(0.03652339),
  DSP16_Q(-0.01075195),
  DSP16_Q(0.00099281),
  DSP16_Q(0.00099281),
  DSP16_Q(-0.01075195),
  DSP16_Q(0.03652339),
  DSP16_Q(-0.09670563),
  DSP16_Q(0.35783716),
  DSP16_Q(0.35317197),
  DSP16_Q(-0.09611076),
  DSP16_Q(0.03628918),
  DSP16_Q(-0.01065017),
  DSP16_Q(0.00096699),
  DSP16_Q(0.00101859),
  DSP16_Q(-0.01085014),
  DSP16_Q(0.03674461),
  DSP16_Q(-0.09726741),
  DSP16_Q(0.36247868),
  DSP16_Q(0.34848423),
  DSP16_Q(-0.09548346),
  DSP16_Q(0.03604223),
  DSP16_Q(-0.01054493),
  DSP16_Q(0.00094119),
  DSP16_Q(0.00104433),
  DSP16_Q(-0.01094463),
  DSP16_Q(0.03695256),
  DSP16_Q(-0.09779549),
  DSP16_Q(0.36709542),
  DSP16_Q(0.34377509),
  DSP16_Q(-0.09482434),
  DSP16_Q(0.03578282),
  DSP16_Q(-0.01043633),
  DSP16_Q(0.00091542),
  DSP16_Q(0.00106998),
  DSP16_Q(-0.01103531),
  DSP16_Q(0.03714701),
  DSP16_Q(-0.09828922),
  DSP16_Q(0.37168625),
  DSP16_Q(0.33904566),
  DSP16_Q(-0.09413407),
  DSP16_Q(0.03551122),
  DSP16_Q(-0.01032450),
  DSP16_Q(0.00088971),
  DSP16_Q(0.00109552),
  DSP16_Q(-0.01112206),
  DSP16_Q(0.03732768),
  DSP16_Q(-0.09874800),
  DSP16_Q(0.37625005),
  DSP16_Q(0.33429709),
  DSP16_Q(-0.09341330),
  DSP16_Q(0.03522769),
  DSP16_Q(-0.01020955),
  DSP16_Q(0.00086408),
  DSP16_Q(0.00112091),
  DSP16_Q(-0.01120477),
  DSP16_Q(0.03749432),
  DSP16_Q(-0.09917121),
  DSP16_Q(0.38078571),
  DSP16_Q(0.32953050),
  DSP16_Q(-0.09266266),
  DSP16_Q(0.03493251),
  DSP16_Q(-0.01009160),
  DSP16_Q(0.00083857),
  DSP16_Q(0.00114613),
  DSP16_Q(-0.01128331),
  DSP16_Q(0.03764670),
  DSP16_Q(-0.09955825),
  DSP16_Q(0.38529214),
  DSP16_Q(0.32474703),
  DSP16_Q(-0.09188283),
  DSP16_Q(0.03462596),
  DSP16_Q(-0.00997076),
  DSP16_Q(0.00081320),
  DSP16_Q(0.00117114),
  DSP16_Q(-0.01135759),
  DSP16_Q(0.03778455),
  DSP16_Q(-0.09990850),
  DSP16_Q(0.38976821),
  DSP16_Q(0.31994782),
  DSP16_Q(-0.09107447),
  DSP16_Q(0.03430832),
  DSP16_Q(-0.00984715),
  DSP16_Q(0.00078799),
  DSP16_Q(0.00119591),
  DSP16_Q(-0.01142749),
  DSP16_Q(0.03790765),
  DSP16_Q(-0.10022138),
  DSP16_Q(0.39421284),
  DSP16_Q(0.31513400),
  DSP16_Q(-0.09023823),
  DSP16_Q(0.03397986),
  DSP16_Q(-0.00972088),
  DSP16_Q(0.00076297),
  DSP16_Q(0.00122040),
  DSP16_Q(-0.01149289),
  DSP16_Q(0.03801576),
  DSP16_Q(-0.10049630),
  DSP16_Q(0.39862493),
  DSP16_Q(0.31030672),
  DSP16_Q(-0.08937479),
  DSP16_Q(0.03364086),
  DSP16_Q(-0.00959207),
  DSP16_Q(0.00073815),
  DSP16_Q(0.00124457),
  DSP16_Q(-0.01155369),
  DSP16_Q(0.03810863),
  DSP16_Q(-0.10073268),
  DSP16_Q(0.40300340),
  DSP16_Q(0.30546709),
  DSP16_Q(-0.08848482),
  DSP16_Q(0.03329162),
  DSP16_Q(-0.00946084),
  DSP16_Q(0.00071357),
  DSP16_Q(0.00126841),
  DSP16_Q(-0.01160976),
  DSP16_Q(0.03818605),
  DSP16_Q(-0.10092995),
  DSP16_Q(0.40734716),
  DSP16_Q(0.30061628),
  DSP16_Q(-0.08756899),
  DSP16_Q(0.03293241),
  DSP16_Q(-0.00932729),
  DSP16_Q(0.00068923),
  DSP16_Q(0.00129186),
  DSP16_Q(-0.01166102),
  DSP16_Q(0.03824778),
  DSP16_Q(-0.10108753),
  DSP16_Q(0.41165515),
  DSP16_Q(0.29575540),
  DSP16_Q(-0.08662797),
  DSP16_Q(0.03256352),
  DSP16_Q(-0.00919155),
  DSP16_Q(0.00066517),
  DSP16_Q(0.00131489),
  DSP16_Q(-0.01170734),
  DSP16_Q(0.03829361),
  DSP16_Q(-0.10120488),
  DSP16_Q(0.41592629),
  DSP16_Q(0.29088559),
  DSP16_Q(-0.08566245),
  DSP16_Q(0.03218524),
  DSP16_Q(-0.00905372),
  DSP16_Q(0.00064140),
  DSP16_Q(0.00133748),
  DSP16_Q(-0.01174862),
  DSP16_Q(0.03832332),
  DSP16_Q(-0.10128145),
  DSP16_Q(0.42015952),
  DSP16_Q(0.28600799),
  DSP16_Q(-0.08467310),
  DSP16_Q(0.03179786),
  DSP16_Q(-0.00891393),
  DSP16_Q(0.00061794),
  DSP16_Q(0.00135957),
  DSP16_Q(-0.01178475),
  DSP16_Q(0.03833669),
  DSP16_Q(-0.10131668),
  DSP16_Q(0.42435379),
  DSP16_Q(0.28112372),
  DSP16_Q(-0.08366061),
  DSP16_Q(0.03140165),
  DSP16_Q(-0.00877227),
  DSP16_Q(0.00059480),
  DSP16_Q(0.00138113),
  DSP16_Q(-0.01181564),
  DSP16_Q(0.03833354),
  DSP16_Q(-0.10131007),
  DSP16_Q(0.42850806),
  DSP16_Q(0.27623391),
  DSP16_Q(-0.08262565),
  DSP16_Q(0.03099693),
  DSP16_Q(-0.00862888),
  DSP16_Q(0.00057201),
  DSP16_Q(0.00140213),
  DSP16_Q(-0.01184117),
  DSP16_Q(0.03831364),
  DSP16_Q(-0.10126106),
  DSP16_Q(0.43262129),
  DSP16_Q(0.27133970),
  DSP16_Q(-0.08156890),
  DSP16_Q(0.03058396),
  DSP16_Q(-0.00848384),
  DSP16_Q(0.00054958),
  DSP16_Q(0.00142253),
  DSP16_Q(-0.01186124),
  DSP16_Q(0.03827682),
  DSP16_Q(-0.10116917),
  DSP16_Q(0.43669245),
  DSP16_Q(0.26644219),
  DSP16_Q(-0.08049106),
  DSP16_Q(0.03016304),
  DSP16_Q(-0.00833728),
  DSP16_Q(0.00052752),
  DSP16_Q(0.00144228),
  DSP16_Q(-0.01187576),
  DSP16_Q(0.03822287),
  DSP16_Q(-0.10103388),
  DSP16_Q(0.44072051),
  DSP16_Q(0.26154252),
  DSP16_Q(-0.07939281),
  DSP16_Q(0.02973447),
  DSP16_Q(-0.00818931),
  DSP16_Q(0.00050585),
  DSP16_Q(0.00146136),
  DSP16_Q(-0.01188462),
  DSP16_Q(0.03815161),
  DSP16_Q(-0.10085469),
  DSP16_Q(0.44470448),
  DSP16_Q(0.25664179),
  DSP16_Q(-0.07827482),
  DSP16_Q(0.02929853),
  DSP16_Q(-0.00804002),
  DSP16_Q(0.00048459),
  DSP16_Q(0.00147972),
  DSP16_Q(-0.01188773),
  DSP16_Q(0.03806286),
  DSP16_Q(-0.10063112),
  DSP16_Q(0.44864335),
  DSP16_Q(0.25174111),
  DSP16_Q(-0.07713779),
  DSP16_Q(0.02885552),
  DSP16_Q(-0.00788954),
  DSP16_Q(0.00046374),
  DSP16_Q(0.00149731),
  DSP16_Q(-0.01188499),
  DSP16_Q(0.03795645),
  DSP16_Q(-0.10036270),
  DSP16_Q(0.45253612),
  DSP16_Q(0.24684161),
  DSP16_Q(-0.07598240),
  DSP16_Q(0.02840572),
  DSP16_Q(-0.00773797),
  DSP16_Q(0.00044332),
  DSP16_Q(0.00151412),
  DSP16_Q(-0.01187631),
  DSP16_Q(0.03783222),
  DSP16_Q(-0.10004896),
  DSP16_Q(0.45638182),
  DSP16_Q(0.24194437),
  DSP16_Q(-0.07480934),
  DSP16_Q(0.02794942),
  DSP16_Q(-0.00758540),
  DSP16_Q(0.00042333),
  DSP16_Q(0.00153008),
  DSP16_Q(-0.01186160),
  DSP16_Q(0.03768999),
  DSP16_Q(-0.09968945),
  DSP16_Q(0.46017948),
  DSP16_Q(0.23705049),
  DSP16_Q(-0.07361928),
  DSP16_Q(0.02748692),
  DSP16_Q(-0.00743195),
  DSP16_Q(0.00040380),
  DSP16_Q(0.00154517),
  DSP16_Q(-0.01184076),
  DSP16_Q(0.03752962),
  DSP16_Q(-0.09928373),
  DSP16_Q(0.46392813),
  DSP16_Q(0.23216107),
  DSP16_Q(-0.07241290),
  DSP16_Q(0.02701849),
  DSP16_Q(-0.00727773),
  DSP16_Q(0.00038472),
  DSP16_Q(0.00155934),
  DSP16_Q(-0.01181371),
  DSP16_Q(0.03735095),
  DSP16_Q(-0.09883136),
  DSP16_Q(0.46762682),
  DSP16_Q(0.22727720),
  DSP16_Q(-0.07119090),
  DSP16_Q(0.02654444),
  DSP16_Q(-0.00712282),
  DSP16_Q(0.00036611),
  DSP16_Q(0.00157255),
  DSP16_Q(-0.01178037),
  DSP16_Q(0.03715384),
  DSP16_Q(-0.09833192),
  DSP16_Q(0.47127462),
  DSP16_Q(0.22239996),
  DSP16_Q(-0.06995395),
  DSP16_Q(0.02606505),
  DSP16_Q(-0.00696734),
  DSP16_Q(0.00034798),
  DSP16_Q(0.00158477),
  DSP16_Q(-0.01174064),
  DSP16_Q(0.03693816),
  DSP16_Q(-0.09778501),
  DSP16_Q(0.47487061),
  DSP16_Q(0.21753041),
  DSP16_Q(-0.06870272),
  DSP16_Q(0.02558060),
  DSP16_Q(-0.00681137),
  DSP16_Q(0.00033032),
  DSP16_Q(0.00159595),
  DSP16_Q(-0.01169445),
  DSP16_Q(0.03670378),
  DSP16_Q(-0.09719022),
  DSP16_Q(0.47841386),
  DSP16_Q(0.21266963),
  DSP16_Q(-0.06743790),
  DSP16_Q(0.02509138),
  DSP16_Q(-0.00665503),
  DSP16_Q(0.00031315),
  DSP16_Q(0.00160606),
  DSP16_Q(-0.01164172),
  DSP16_Q(0.03645058),
  DSP16_Q(-0.09654717),
  DSP16_Q(0.48190347),
  DSP16_Q(0.20781869),
  DSP16_Q(-0.06616015),
  DSP16_Q(0.02459767),
  DSP16_Q(-0.00649840),
  DSP16_Q(0.00029647),
  DSP16_Q(0.00161505),
  DSP16_Q(-0.01158238),
  DSP16_Q(0.03617843),
  DSP16_Q(-0.09585549),
  DSP16_Q(0.48533856),
  DSP16_Q(0.20297862),
  DSP16_Q(-0.06487015),
  DSP16_Q(0.02409976),
  DSP16_Q(-0.00634159),
  DSP16_Q(0.00028029),
  DSP16_Q(0.00162288),
  DSP16_Q(-0.01151633),
  DSP16_Q(0.03588723),
  DSP16_Q(-0.09511481),
  DSP16_Q(0.48871825),
  DSP16_Q(0.19815049),
  DSP16_Q(-0.06356857),
  DSP16_Q(0.02359793),
  DSP16_Q(-0.00618468),
  DSP16_Q(0.00026460),
  DSP16_Q(0.00162951),
  DSP16_Q(-0.01144353),
  DSP16_Q(0.03557688),
  DSP16_Q(-0.09432479),
  DSP16_Q(0.49204167),
  DSP16_Q(0.19333533),
  DSP16_Q(-0.06225607),
  DSP16_Q(0.02309245),
  DSP16_Q(-0.00602777),
  DSP16_Q(0.00024942),
  DSP16_Q(0.00163491),
  DSP16_Q(-0.01136389),
  DSP16_Q(0.03524729),
  DSP16_Q(-0.09348510),
  DSP16_Q(0.49530798),
  DSP16_Q(0.18853417),
  DSP16_Q(-0.06093332),
  DSP16_Q(0.02258361),
  DSP16_Q(-0.00587095),
  DSP16_Q(0.00023475),
  DSP16_Q(0.00163902),
  DSP16_Q(-0.01127735),
  DSP16_Q(0.03489836),
  DSP16_Q(-0.09259539),
  DSP16_Q(0.49851633),
  DSP16_Q(0.18374804),
  DSP16_Q(-0.05960097),
  DSP16_Q(0.02207169),
  DSP16_Q(-0.00571431),
  DSP16_Q(0.00022057),
  DSP16_Q(0.00164183),
  DSP16_Q(-0.01118384),
  DSP16_Q(0.03453003),
  DSP16_Q(-0.09165538),
  DSP16_Q(0.50166590),
  DSP16_Q(0.17897794),
  DSP16_Q(-0.05825969),
  DSP16_Q(0.02155695),
  DSP16_Q(-0.00555793),
  DSP16_Q(0.00020691),
  DSP16_Q(0.00164328),
  DSP16_Q(-0.01108331),
  DSP16_Q(0.03414221),
  DSP16_Q(-0.09066476),
  DSP16_Q(0.50475590),
  DSP16_Q(0.17422489),
  DSP16_Q(-0.05691012),
  DSP16_Q(0.02103967),
  DSP16_Q(-0.00540190),
  DSP16_Q(0.00019375),
  DSP16_Q(0.00164333),
  DSP16_Q(-0.01097569),
  DSP16_Q(0.03373484),
  DSP16_Q(-0.08962324),
  DSP16_Q(0.50778551),
  DSP16_Q(0.16948987),
  DSP16_Q(-0.05555291),
  DSP16_Q(0.02052012),
  DSP16_Q(-0.00524632),
  DSP16_Q(0.00018109),
  DSP16_Q(0.00164195),
  DSP16_Q(-0.01086094),
  DSP16_Q(0.03330788),
  DSP16_Q(-0.08853056),
  DSP16_Q(0.51075396),
  DSP16_Q(0.16477388),
  DSP16_Q(-0.05418871),
  DSP16_Q(0.01999856),
  DSP16_Q(-0.00509125),
  DSP16_Q(0.00016894),
  DSP16_Q(0.00163910),
  DSP16_Q(-0.01073899),
  DSP16_Q(0.03286127),
  DSP16_Q(-0.08738646),
  DSP16_Q(0.51366049),
  DSP16_Q(0.16007790),
  DSP16_Q(-0.05281817),
  DSP16_Q(0.01947527),
  DSP16_Q(-0.00493678),
  DSP16_Q(0.00015728),
  DSP16_Q(0.00163474),
  DSP16_Q(-0.01060980),
  DSP16_Q(0.03239496),
  DSP16_Q(-0.08619070),
  DSP16_Q(0.51650435),
  DSP16_Q(0.15540288),
  DSP16_Q(-0.05144190),
  DSP16_Q(0.01895051),
  DSP16_Q(-0.00478300),
  DSP16_Q(0.00014612),
  DSP16_Q(0.00162883),
  DSP16_Q(-0.01047332),
  DSP16_Q(0.03190894),
  DSP16_Q(-0.08494305),
  DSP16_Q(0.51928480),
  DSP16_Q(0.15074978),
  DSP16_Q(-0.05006055),
  DSP16_Q(0.01842454),
  DSP16_Q(-0.00462997),
  DSP16_Q(0.00013546),
  DSP16_Q(0.00162134),
  DSP16_Q(-0.01032951),
  DSP16_Q(0.03140317),
  DSP16_Q(-0.08364330),
  DSP16_Q(0.52200112),
  DSP16_Q(0.14611956),
  DSP16_Q(-0.04867475),
  DSP16_Q(0.01789761),
  DSP16_Q(-0.00447778),
  DSP16_Q(0.00012528),
  DSP16_Q(0.00161223),
  DSP16_Q(-0.01017833),
  DSP16_Q(0.03087765),
  DSP16_Q(-0.08229124),
  DSP16_Q(0.52465262),
  DSP16_Q(0.14151314),
  DSP16_Q(-0.04728511),
  DSP16_Q(0.01736999),
  DSP16_Q(-0.00432650),
  DSP16_Q(0.00011558),
  DSP16_Q(0.00160146),
  DSP16_Q(-0.01001975),
  DSP16_Q(0.03033236),
  DSP16_Q(-0.08088670),
  DSP16_Q(0.52723861),
  DSP16_Q(0.13693145),
  DSP16_Q(-0.04589225),
  DSP16_Q(0.01684192),
  DSP16_Q(-0.00417620),
  DSP16_Q(0.00010636),
  DSP16_Q(0.00158899),
  DSP16_Q(-0.00985372),
  DSP16_Q(0.02976731),
  DSP16_Q(-0.07942951),
  DSP16_Q(0.52975841),
  DSP16_Q(0.13237540),
  DSP16_Q(-0.04449678),
  DSP16_Q(0.01631366),
  DSP16_Q(-0.00402695),
  DSP16_Q(0.00009761),
  DSP16_Q(0.00157480),
  DSP16_Q(-0.00968023),
  DSP16_Q(0.02918251),
  DSP16_Q(-0.07791950),
  DSP16_Q(0.53221137),
  DSP16_Q(0.12784590),
  DSP16_Q(-0.04309930),
  DSP16_Q(0.01578545),
  DSP16_Q(-0.00387882),
  DSP16_Q(0.00008933),
  DSP16_Q(0.00155885),
  DSP16_Q(-0.00949923),
  DSP16_Q(0.02857797),
  DSP16_Q(-0.07635655),
  DSP16_Q(0.53459686),
  DSP16_Q(0.12334383),
  DSP16_Q(-0.04170042),
  DSP16_Q(0.01525753),
  DSP16_Q(-0.00373188),
  DSP16_Q(0.00008150),
  DSP16_Q(0.00154110),
  DSP16_Q(-0.00931072),
  DSP16_Q(0.02795374),
  DSP16_Q(-0.07474051),
  DSP16_Q(0.53691426),
  DSP16_Q(0.11887007),
  DSP16_Q(-0.04030073),
  DSP16_Q(0.01473016),
  DSP16_Q(-0.00358619),
  DSP16_Q(0.00007411),
  DSP16_Q(0.00152151),
  DSP16_Q(-0.00911467),
  DSP16_Q(0.02730983),
  DSP16_Q(-0.07307130),
  DSP16_Q(0.53916296),
  DSP16_Q(0.11442548),
  DSP16_Q(-0.03890081),
  DSP16_Q(0.01420356),
  DSP16_Q(-0.00344182),
  DSP16_Q(0.00006717),
  DSP16_Q(0.00150007),
  DSP16_Q(-0.00891107),
  DSP16_Q(0.02664631),
  DSP16_Q(-0.07134880),
  DSP16_Q(0.54134239),
  DSP16_Q(0.11001092),
  DSP16_Q(-0.03750124),
  DSP16_Q(0.01367796),
  DSP16_Q(-0.00329883),
  DSP16_Q(0.00006065),
  DSP16_Q(0.00147674),
  DSP16_Q(-0.00869990),
  DSP16_Q(0.02596322),
  DSP16_Q(-0.06957295),
  DSP16_Q(0.54345196),
  DSP16_Q(0.10562723),
  DSP16_Q(-0.03610261),
  DSP16_Q(0.01315361),
  DSP16_Q(-0.00315728),
  DSP16_Q(0.00005455),
  DSP16_Q(0.00145148),
  DSP16_Q(-0.00848116),
  DSP16_Q(0.02526063),
  DSP16_Q(-0.06774368),
  DSP16_Q(0.54549115),
  DSP16_Q(0.10127523),
  DSP16_Q(-0.03470547),
  DSP16_Q(0.01263073),
  DSP16_Q(-0.00301721),
  DSP16_Q(0.00004886),
  DSP16_Q(0.00142426),
  DSP16_Q(-0.00825484),
  DSP16_Q(0.02453862),
  DSP16_Q(-0.06586094),
  DSP16_Q(0.54745940),
  DSP16_Q(0.09695574),
  DSP16_Q(-0.03331039),
  DSP16_Q(0.01210954),
  DSP16_Q(-0.00287870),
  DSP16_Q(0.00004356),
  DSP16_Q(0.00139506),
  DSP16_Q(-0.00802094),
  DSP16_Q(0.02379726),
  DSP16_Q(-0.06392471),
  DSP16_Q(0.54935622),
  DSP16_Q(0.09266956),
  DSP16_Q(-0.03191792),
  DSP16_Q(0.01159027),
  DSP16_Q(-0.00274179),
  DSP16_Q(0.00003865),
  DSP16_Q(0.00136385),
  DSP16_Q(-0.00777947),
  DSP16_Q(0.02303665),
  DSP16_Q(-0.06193496),
  DSP16_Q(0.55118109),
  DSP16_Q(0.08841748),
  DSP16_Q(-0.03052861),
  DSP16_Q(0.01107312),
  DSP16_Q(-0.00260654),
  DSP16_Q(0.00003411),
  DSP16_Q(0.00133060),
  DSP16_Q(-0.00753043),
  DSP16_Q(0.02225689),
  DSP16_Q(-0.05989170),
  DSP16_Q(0.55293356),
  DSP16_Q(0.08420026),
  DSP16_Q(-0.02914299),
  DSP16_Q(0.01055831),
  DSP16_Q(-0.00247300),
  DSP16_Q(0.00002994),
  DSP16_Q(0.00129529),
  DSP16_Q(-0.00727384),
  DSP16_Q(0.02145809),
  DSP16_Q(-0.05779494),
  DSP16_Q(0.55461316),
  DSP16_Q(0.08001867),
  DSP16_Q(-0.02776161),
  DSP16_Q(0.01004606),
  DSP16_Q(-0.00234120),
  DSP16_Q(0.00002611),
  DSP16_Q(0.00125788),
  DSP16_Q(-0.00700971),
  DSP16_Q(0.02064038),
  DSP16_Q(-0.05564473),
  DSP16_Q(0.55621945),
  DSP16_Q(0.07587345),
  DSP16_Q(-0.02638498),
  DSP16_Q(0.00953657),
  DSP16_Q(-0.00221121),
  DSP16_Q(0.00002261),
  DSP16_Q(0.00121836),
  DSP16_Q(-0.00673805),
  DSP16_Q(0.01980387),
  DSP16_Q(-0.05344111),
  DSP16_Q(0.55775201),
  DSP16_Q(0.07176534),
  DSP16_Q(-0.02501362),
  DSP16_Q(0.00903003),
  DSP16_Q(-0.00208306),
  DSP16_Q(0.00001944),
  DSP16_Q(0.00117671),
  DSP16_Q(-0.00645891),
  DSP16_Q(0.01894871),
  DSP16_Q(-0.05118414),
  DSP16_Q(0.55921044),
  DSP16_Q(0.06769505),
  DSP16_Q(-0.02364804),
  DSP16_Q(0.00852666),
  DSP16_Q(-0.00195679),
  DSP16_Q(0.00001657),
  DSP16_Q(0.00113289),
  DSP16_Q(-0.00617229),
  DSP16_Q(0.01807506),
  DSP16_Q(-0.04887390),
  DSP16_Q(0.56059437),
  DSP16_Q(0.06366328),
  DSP16_Q(-0.02228875),
  DSP16_Q(0.00802663),
  DSP16_Q(-0.00183245),
  DSP16_Q(0.00001400),
  DSP16_Q(0.00108689),
  DSP16_Q(-0.00587823),
  DSP16_Q(0.01718306),
  DSP16_Q(-0.04651051),
  DSP16_Q(0.56190342),
  DSP16_Q(0.05967073),
  DSP16_Q(-0.02093622),
  DSP16_Q(0.00753015),
  DSP16_Q(-0.00171007),
  DSP16_Q(0.00001170),
  DSP16_Q(0.00103869),
  DSP16_Q(-0.00557678),
  DSP16_Q(0.01627288),
  DSP16_Q(-0.04409407),
  DSP16_Q(0.56313725),
  DSP16_Q(0.05571805),
  DSP16_Q(-0.01959096),
  DSP16_Q(0.00703739),
  DSP16_Q(-0.00158969),
  DSP16_Q(0.00000967),
  DSP16_Q(0.00098827),
  DSP16_Q(-0.00526797),
  DSP16_Q(0.01534471),
  DSP16_Q(-0.04162471),
  DSP16_Q(0.56429555),
  DSP16_Q(0.05180592),
  DSP16_Q(-0.01825343),
  DSP16_Q(0.00654854),
  DSP16_Q(-0.00147135),
  DSP16_Q(0.00000789),
  DSP16_Q(0.00093561),
  DSP16_Q(-0.00495184),
  DSP16_Q(0.01439873),
  DSP16_Q(-0.03910259),
  DSP16_Q(0.56537800),
  DSP16_Q(0.04793497),
  DSP16_Q(-0.01692411),
  DSP16_Q(0.00606377),
  DSP16_Q(-0.00135507),
  DSP16_Q(0.00000633),
  DSP16_Q(0.00088071),
  DSP16_Q(-0.00462845),
  DSP16_Q(0.01343514),
  DSP16_Q(-0.03652787),
  DSP16_Q(0.56638432),
  DSP16_Q(0.04410583),
  DSP16_Q(-0.01560345),
  DSP16_Q(0.00558326),
  DSP16_Q(-0.00124089),
  DSP16_Q(0.00000500),
  DSP16_Q(0.00082353),
  DSP16_Q(-0.00429784),
  DSP16_Q(0.01245414),
  DSP16_Q(-0.03390073),
  DSP16_Q(0.56731426),
  DSP16_Q(0.04031911),
  DSP16_Q(-0.01429191),
  DSP16_Q(0.00510718),
  DSP16_Q(-0.00112884),
  DSP16_Q(0.00000387),
  DSP16_Q(0.00076408),
  DSP16_Q(-0.00396008),
  DSP16_Q(0.01145596),
  DSP16_Q(-0.03122138),
  DSP16_Q(0.56816756),
  DSP16_Q(0.03657540),
  DSP16_Q(-0.01298993),
  DSP16_Q(0.00463569),
  DSP16_Q(-0.00101893),
  DSP16_Q(0.00000292),
  DSP16_Q(0.00070233),
  DSP16_Q(-0.00361523),
  DSP16_Q(0.01044081),
  DSP16_Q(-0.02849002),
  DSP16_Q(0.56894400),
  DSP16_Q(0.03287529),
  DSP16_Q(-0.01169794),
  DSP16_Q(0.00416896),
  DSP16_Q(-0.00091121),
  DSP16_Q(0.00000214),
  DSP16_Q(0.00063828),
  DSP16_Q(-0.00326335),
  DSP16_Q(0.00940894),
  DSP16_Q(-0.02570690),
  DSP16_Q(0.56964338),
  DSP16_Q(0.02921935),
  DSP16_Q(-0.01041637),
  DSP16_Q(0.00370713),
  DSP16_Q(-0.00080568),
  DSP16_Q(0.00000151),
  DSP16_Q(0.00057192),
  DSP16_Q(-0.00290452),
  DSP16_Q(0.00836058),
  DSP16_Q(-0.02287226),
  DSP16_Q(0.57026552),
  DSP16_Q(0.02560811),
  DSP16_Q(-0.00914563),
  DSP16_Q(0.00325036),
  DSP16_Q(-0.00070237),
  DSP16_Q(0.00000102),
  DSP16_Q(0.00050324),
  DSP16_Q(-0.00253882),
  DSP16_Q(0.00729601),
  DSP16_Q(-0.01998636),
  DSP16_Q(0.57081025),
  DSP16_Q(0.02204211),
  DSP16_Q(-0.00788613),
  DSP16_Q(0.00279880),
  DSP16_Q(-0.00060130),
  DSP16_Q(0.00000065),
  DSP16_Q(0.00043223),
  DSP16_Q(-0.00216631),
  DSP16_Q(0.00621547),
  DSP16_Q(-0.01704950),
  DSP16_Q(0.57127742),
  DSP16_Q(0.01852187),
  DSP16_Q(-0.00663827),
  DSP16_Q(0.00235259),
  DSP16_Q(-0.00050250),
  DSP16_Q(0.00000038),
  DSP16_Q(0.00035889),
  DSP16_Q(-0.00178709),
  DSP16_Q(0.00511924),
  DSP16_Q(-0.01406198),
  DSP16_Q(0.57166692),
  DSP16_Q(0.01504789),
  DSP16_Q(-0.00540244),
  DSP16_Q(0.00191186),
  DSP16_Q(-0.00040596),
  DSP16_Q(0.00000020),
  DSP16_Q(0.00028322),
  DSP16_Q(-0.00140124),
  DSP16_Q(0.00400762),
  DSP16_Q(-0.01102410),
  DSP16_Q(0.57197864),
  DSP16_Q(0.01162065),
  DSP16_Q(-0.00417901),
  DSP16_Q(0.00147676),
  DSP16_Q(-0.00031171),
  DSP16_Q(0.00000009),
  DSP16_Q(0.00020522),
  DSP16_Q(-0.00100886),
  DSP16_Q(0.00288089),
  DSP16_Q(-0.00793621),
  DSP16_Q(0.57221251),
  DSP16_Q(0.00824062),
  DSP16_Q(-0.00296837),
  DSP16_Q(0.00104741),
  DSP16_Q(-0.00021976),
  DSP16_Q(0.00000003),
  DSP16_Q(0.00012488),
  DSP16_Q(-0.00061005),
  DSP16_Q(0.00173936),
  DSP16_Q(-0.00479865),
  DSP16_Q(0.57236845),
  DSP16_Q(0.00490825),
  DSP16_Q(-0.00177086),
  DSP16_Q(0.00062393),
  DSP16_Q(-0.00013012),
  DSP16_Q(0.00000000),
  DSP16_Q(0.00004221),
  DSP16_Q(-0.00020491),
  DSP16_Q(0.00058334),
  DSP16_Q(-0.00161179),
  DSP16_Q(0.57244643),
  DSP16_Q(0.00162397),
  DSP16_Q(-0.00058684),
  DSP16_Q(0.00020645),
  DSP16_Q(-0.00004279),
  DSP16_Q(0.00000000)
};
