/*****************************************************************************
 *
 * \file
 *
 * \brief FIR coefficients for the dsp16_resampling function from the DPSLib.
 *        These coefficients have the following caracterizations:
 *          - Input sampling frequency: 48000 Hz
 *          - Output sampling frequency: 44100 Hz
 *          - Re-sampling order: 30
 *          - Coefficients are normalized
 *          - Memory foot print: 8820 bytes
 *         It matches the following parameters:
 *         (dsp16_resampling_options_t::dsp16_custom_filter)
 *          - Cut-off frequency (fc_hz): 22050
 *          - Sampling frequency (fs_hz): ******
 *          - Actual FIR filter order (order): 4410
 *
 * Copyright (c) 2010 Atmel Corporation. All rights reserved.
 *
 * \asf_license_start
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 *    Atmel microcontroller product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * \asf_license_stop
 *
 ******************************************************************************/

A_ALIGNED static const dsp16_t dsp16_resampling_fircoef_ord30_48000_44100_norm[] = {
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00005142),
  DSP16_Q(-0.00009503),
  DSP16_Q(-0.00008421),
  DSP16_Q(0.00073778),
  DSP16_Q(-0.00210883),
  DSP16_Q(0.00438334),
  DSP16_Q(-0.00764618),
  DSP16_Q(0.01185025),
  DSP16_Q(-0.01680516),
  DSP16_Q(0.02218949),
  DSP16_Q(-0.02758714),
  DSP16_Q(0.03254840),
  DSP16_Q(-0.03669104),
  DSP16_Q(0.04003968),
  DSP16_Q(0.44445332),
  DSP16_Q(0.03687874),
  DSP16_Q(-0.03529575),
  DSP16_Q(0.03180344),
  DSP16_Q(-0.02719359),
  DSP16_Q(0.02200960),
  DSP16_Q(-0.01675581),
  DSP16_Q(0.01187460),
  DSP16_Q(-0.00770430),
  DSP16_Q(0.00444839),
  DSP16_Q(-0.00216490),
  DSP16_Q(0.00077780),
  DSP16_Q(-0.00010767),
  DSP16_Q(-0.00008451),
  DSP16_Q(0.00004858),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00005430),
  DSP16_Q(-0.00010565),
  DSP16_Q(-0.00006047),
  DSP16_Q(0.00069716),
  DSP16_Q(-0.00205157),
  DSP16_Q(0.00431620),
  DSP16_Q(-0.00758478),
  DSP16_Q(0.01182114),
  DSP16_Q(-0.01684815),
  DSP16_Q(0.02236149),
  DSP16_Q(-0.02797176),
  DSP16_Q(0.03328474),
  DSP16_Q(-0.03808239),
  DSP16_Q(0.04322935),
  DSP16_Q(0.44439575),
  DSP16_Q(0.03374708),
  DSP16_Q(-0.03389709),
  DSP16_Q(0.03105020),
  DSP16_Q(-0.02679132),
  DSP16_Q(0.02182193),
  DSP16_Q(-0.01670015),
  DSP16_Q(0.01189420),
  DSP16_Q(-0.00775910),
  DSP16_Q(0.00451133),
  DSP16_Q(-0.00221975),
  DSP16_Q(0.00081720),
  DSP16_Q(-0.00013086),
  DSP16_Q(-0.00007410),
  DSP16_Q(0.00004580),
  DSP16_Q(-0.00000001),
  DSP16_Q(0.00005722),
  DSP16_Q(-0.00011638),
  DSP16_Q(-0.00003647),
  DSP16_Q(0.00065594),
  DSP16_Q(-0.00199312),
  DSP16_Q(0.00424698),
  DSP16_Q(-0.00752008),
  DSP16_Q(0.01178726),
  DSP16_Q(-0.01688473),
  DSP16_Q(0.02252552),
  DSP16_Q(-0.02834727),
  DSP16_Q(0.03401215),
  DSP16_Q(-0.03946928),
  DSP16_Q(0.04644721),
  DSP16_Q(0.44428063),
  DSP16_Q(0.03064522),
  DSP16_Q(-0.03249557),
  DSP16_Q(0.03028901),
  DSP16_Q(-0.02638052),
  DSP16_Q(0.02162660),
  DSP16_Q(-0.01663821),
  DSP16_Q(0.01190907),
  DSP16_Q(-0.00781060),
  DSP16_Q(0.00457215),
  DSP16_Q(-0.00227337),
  DSP16_Q(0.00085596),
  DSP16_Q(-0.00015377),
  DSP16_Q(-0.00006381),
  DSP16_Q(0.00004306),
  DSP16_Q(-0.00000003),
  DSP16_Q(0.00006019),
  DSP16_Q(-0.00012722),
  DSP16_Q(-0.00001222),
  DSP16_Q(0.00061414),
  DSP16_Q(-0.00193351),
  DSP16_Q(0.00417571),
  DSP16_Q(-0.00745211),
  DSP16_Q(0.01174860),
  DSP16_Q(-0.01691487),
  DSP16_Q(0.02268146),
  DSP16_Q(-0.02871348),
  DSP16_Q(0.03473029),
  DSP16_Q(-0.04085115),
  DSP16_Q(0.04969271),
  DSP16_Q(0.44410799),
  DSP16_Q(0.02757369),
  DSP16_Q(-0.03109174),
  DSP16_Q(0.02952020),
  DSP16_Q(-0.02596138),
  DSP16_Q(0.02142370),
  DSP16_Q(-0.01657007),
  DSP16_Q(0.01191922),
  DSP16_Q(-0.00785879),
  DSP16_Q(0.00463084),
  DSP16_Q(-0.00232576),
  DSP16_Q(0.00089408),
  DSP16_Q(-0.00017639),
  DSP16_Q(-0.00005364),
  DSP16_Q(0.00004037),
  DSP16_Q(-0.00000006),
  DSP16_Q(0.00006320),
  DSP16_Q(-0.00013815),
  DSP16_Q(0.00001228),
  DSP16_Q(0.00057177),
  DSP16_Q(-0.00187275),
  DSP16_Q(0.00410239),
  DSP16_Q(-0.00738088),
  DSP16_Q(0.01170516),
  DSP16_Q(-0.01693852),
  DSP16_Q(0.02282923),
  DSP16_Q(-0.02907020),
  DSP16_Q(0.03543883),
  DSP16_Q(-0.04222747),
  DSP16_Q(0.05296527),
  DSP16_Q(0.44387786),
  DSP16_Q(0.02453300),
  DSP16_Q(-0.02968613),
  DSP16_Q(0.02874411),
  DSP16_Q(-0.02553410),
  DSP16_Q(0.02121336),
  DSP16_Q(-0.01649576),
  DSP16_Q(0.01192467),
  DSP16_Q(-0.00790366),
  DSP16_Q(0.00468738),
  DSP16_Q(-0.00237688),
  DSP16_Q(0.00093155),
  DSP16_Q(-0.00019870),
  DSP16_Q(-0.00004360),
  DSP16_Q(0.00003772),
  DSP16_Q(-0.00000009),
  DSP16_Q(0.00006625),
  DSP16_Q(-0.00014917),
  DSP16_Q(0.00003701),
  DSP16_Q(0.00052885),
  DSP16_Q(-0.00181085),
  DSP16_Q(0.00402705),
  DSP16_Q(-0.00730639),
  DSP16_Q(0.01165693),
  DSP16_Q(-0.01695564),
  DSP16_Q(0.02296873),
  DSP16_Q(-0.02941726),
  DSP16_Q(0.03613746),
  DSP16_Q(-0.04359768),
  DSP16_Q(0.05626431),
  DSP16_Q(0.44359030),
  DSP16_Q(0.02152364),
  DSP16_Q(-0.02827927),
  DSP16_Q(0.02796107),
  DSP16_Q(-0.02509890),
  DSP16_Q(0.02099568),
  DSP16_Q(-0.01641534),
  DSP16_Q(0.01192543),
  DSP16_Q(-0.00794522),
  DSP16_Q(0.00474177),
  DSP16_Q(-0.00242674),
  DSP16_Q(0.00096836),
  DSP16_Q(-0.00022071),
  DSP16_Q(-0.00003368),
  DSP16_Q(0.00003513),
  DSP16_Q(-0.00000014),
  DSP16_Q(0.00006934),
  DSP16_Q(-0.00016029),
  DSP16_Q(0.00006197),
  DSP16_Q(0.00048538),
  DSP16_Q(-0.00174785),
  DSP16_Q(0.00394970),
  DSP16_Q(-0.00722865),
  DSP16_Q(0.01160390),
  DSP16_Q(-0.01696620),
  DSP16_Q(0.02309986),
  DSP16_Q(-0.02975447),
  DSP16_Q(0.03682585),
  DSP16_Q(-0.04496122),
  DSP16_Q(0.05958926),
  DSP16_Q(0.44324537),
  DSP16_Q(0.01854610),
  DSP16_Q(-0.02687168),
  DSP16_Q(0.02717141),
  DSP16_Q(-0.02465596),
  DSP16_Q(0.02077078),
  DSP16_Q(-0.01632888),
  DSP16_Q(0.01192154),
  DSP16_Q(-0.00798345),
  DSP16_Q(0.00479399),
  DSP16_Q(-0.00247532),
  DSP16_Q(0.00100449),
  DSP16_Q(-0.00024241),
  DSP16_Q(-0.00002389),
  DSP16_Q(0.00003259),
  DSP16_Q(-0.00000019),
  DSP16_Q(0.00007247),
  DSP16_Q(-0.00017148),
  DSP16_Q(0.00008715),
  DSP16_Q(0.00044139),
  DSP16_Q(-0.00168375),
  DSP16_Q(0.00387037),
  DSP16_Q(-0.00714770),
  DSP16_Q(0.01154609),
  DSP16_Q(-0.01697016),
  DSP16_Q(0.02322255),
  DSP16_Q(-0.03008165),
  DSP16_Q(0.03750369),
  DSP16_Q(-0.04631756),
  DSP16_Q(0.06293952),
  DSP16_Q(0.44284317),
  DSP16_Q(0.01560087),
  DSP16_Q(-0.02546389),
  DSP16_Q(0.02637547),
  DSP16_Q(-0.02420550),
  DSP16_Q(0.02053878),
  DSP16_Q(-0.01623643),
  DSP16_Q(0.01191300),
  DSP16_Q(-0.00801837),
  DSP16_Q(0.00484404),
  DSP16_Q(-0.00252260),
  DSP16_Q(0.00103993),
  DSP16_Q(-0.00026379),
  DSP16_Q(-0.00001423),
  DSP16_Q(0.00003010),
  DSP16_Q(-0.00000025),
  DSP16_Q(0.00007564),
  DSP16_Q(-0.00018276),
  DSP16_Q(0.00011254),
  DSP16_Q(0.00039688),
  DSP16_Q(-0.00161857),
  DSP16_Q(0.00378908),
  DSP16_Q(-0.00706353),
  DSP16_Q(0.01148348),
  DSP16_Q(-0.01696751),
  DSP16_Q(0.02333671),
  DSP16_Q(-0.03039864),
  DSP16_Q(0.03817066),
  DSP16_Q(-0.04766613),
  DSP16_Q(0.06631449),
  DSP16_Q(0.44238378),
  DSP16_Q(0.01268842),
  DSP16_Q(-0.02405641),
  DSP16_Q(0.02557359),
  DSP16_Q(-0.02374773),
  DSP16_Q(0.02029980),
  DSP16_Q(-0.01613805),
  DSP16_Q(0.01189985),
  DSP16_Q(-0.00804998),
  DSP16_Q(0.00489190),
  DSP16_Q(-0.00256858),
  DSP16_Q(0.00107469),
  DSP16_Q(-0.00028485),
  DSP16_Q(-0.00000471),
  DSP16_Q(0.00002766),
  DSP16_Q(-0.00000033),
  DSP16_Q(0.00007884),
  DSP16_Q(-0.00019412),
  DSP16_Q(0.00013814),
  DSP16_Q(0.00035187),
  DSP16_Q(-0.00155234),
  DSP16_Q(0.00370584),
  DSP16_Q(-0.00697618),
  DSP16_Q(0.01141609),
  DSP16_Q(-0.01695820),
  DSP16_Q(0.02344225),
  DSP16_Q(-0.03070526),
  DSP16_Q(0.03882643),
  DSP16_Q(-0.04900638),
  DSP16_Q(0.06971355),
  DSP16_Q(0.44186730),
  DSP16_Q(0.00980919),
  DSP16_Q(-0.02264975),
  DSP16_Q(0.02476610),
  DSP16_Q(-0.02328285),
  DSP16_Q(0.02005396),
  DSP16_Q(-0.01603381),
  DSP16_Q(0.01188210),
  DSP16_Q(-0.00807827),
  DSP16_Q(0.00493757),
  DSP16_Q(-0.00261325),
  DSP16_Q(0.00110874),
  DSP16_Q(-0.00030557),
  DSP16_Q(0.00000467),
  DSP16_Q(0.00002527),
  DSP16_Q(-0.00000041),
  DSP16_Q(0.00008208),
  DSP16_Q(-0.00020554),
  DSP16_Q(0.00016392),
  DSP16_Q(0.00030638),
  DSP16_Q(-0.00148507),
  DSP16_Q(0.00362069),
  DSP16_Q(-0.00688565),
  DSP16_Q(0.01134392),
  DSP16_Q(-0.01694222),
  DSP16_Q(0.02353909),
  DSP16_Q(-0.03100134),
  DSP16_Q(0.03947071),
  DSP16_Q(-0.05033775),
  DSP16_Q(0.07313609),
  DSP16_Q(0.44129387),
  DSP16_Q(0.00696365),
  DSP16_Q(-0.02124444),
  DSP16_Q(0.02395334),
  DSP16_Q(-0.02281109),
  DSP16_Q(0.01980139),
  DSP16_Q(-0.01592377),
  DSP16_Q(0.01185980),
  DSP16_Q(-0.00810326),
  DSP16_Q(0.00498105),
  DSP16_Q(-0.00265659),
  DSP16_Q(0.00114207),
  DSP16_Q(-0.00032596),
  DSP16_Q(0.00001392),
  DSP16_Q(0.00002294),
  DSP16_Q(-0.00000050),
  DSP16_Q(0.00008535),
  DSP16_Q(-0.00021703),
  DSP16_Q(0.00018989),
  DSP16_Q(0.00026042),
  DSP16_Q(-0.00141679),
  DSP16_Q(0.00353364),
  DSP16_Q(-0.00679198),
  DSP16_Q(0.01126697),
  DSP16_Q(-0.01691954),
  DSP16_Q(0.02362717),
  DSP16_Q(-0.03128673),
  DSP16_Q(0.04010318),
  DSP16_Q(-0.05165969),
  DSP16_Q(0.07658148),
  DSP16_Q(0.44066362),
  DSP16_Q(0.00415223),
  DSP16_Q(-0.01984098),
  DSP16_Q(0.02313565),
  DSP16_Q(-0.02233264),
  DSP16_Q(0.01954222),
  DSP16_Q(-0.01580801),
  DSP16_Q(0.01183296),
  DSP16_Q(-0.00812495),
  DSP16_Q(0.00502232),
  DSP16_Q(-0.00269860),
  DSP16_Q(0.00117469),
  DSP16_Q(-0.00034601),
  DSP16_Q(0.00002301),
  DSP16_Q(0.00002065),
  DSP16_Q(-0.00000061),
  DSP16_Q(0.00008865),
  DSP16_Q(-0.00022859),
  DSP16_Q(0.00021603),
  DSP16_Q(0.00021401),
  DSP16_Q(-0.00134752),
  DSP16_Q(0.00344473),
  DSP16_Q(-0.00669517),
  DSP16_Q(0.01118526),
  DSP16_Q(-0.01689014),
  DSP16_Q(0.02370641),
  DSP16_Q(-0.03156126),
  DSP16_Q(0.04072353),
  DSP16_Q(-0.05297163),
  DSP16_Q(0.08004908),
  DSP16_Q(0.43997670),
  DSP16_Q(0.00137535),
  DSP16_Q(-0.01843987),
  DSP16_Q(0.02231337),
  DSP16_Q(-0.02184773),
  DSP16_Q(0.01927657),
  DSP16_Q(-0.01568658),
  DSP16_Q(0.01180162),
  DSP16_Q(-0.00814334),
  DSP16_Q(0.00506139),
  DSP16_Q(-0.00273927),
  DSP16_Q(0.00120658),
  DSP16_Q(-0.00036570),
  DSP16_Q(0.00003197),
  DSP16_Q(0.00001843),
  DSP16_Q(-0.00000072),
  DSP16_Q(0.00009198),
  DSP16_Q(-0.00024020),
  DSP16_Q(0.00024233),
  DSP16_Q(0.00016717),
  DSP16_Q(-0.00127728),
  DSP16_Q(0.00335397),
  DSP16_Q(-0.00659526),
  DSP16_Q(0.01109878),
  DSP16_Q(-0.01685400),
  DSP16_Q(0.02377673),
  DSP16_Q(-0.03182476),
  DSP16_Q(0.04133146),
  DSP16_Q(-0.05427303),
  DSP16_Q(0.08353825),
  DSP16_Q(0.43923326),
  DSP16_Q(-0.00136656),
  DSP16_Q(-0.01704161),
  DSP16_Q(0.02148683),
  DSP16_Q(-0.02135658),
  DSP16_Q(0.01900458),
  DSP16_Q(-0.01555957),
  DSP16_Q(0.01176581),
  DSP16_Q(-0.00815846),
  DSP16_Q(0.00509824),
  DSP16_Q(-0.00277858),
  DSP16_Q(0.00123773),
  DSP16_Q(-0.00038505),
  DSP16_Q(0.00004077),
  DSP16_Q(0.00001625),
  DSP16_Q(-0.00000085),
  DSP16_Q(0.00009534),
  DSP16_Q(-0.00025186),
  DSP16_Q(0.00026878),
  DSP16_Q(0.00011990),
  DSP16_Q(-0.00120609),
  DSP16_Q(0.00326139),
  DSP16_Q(-0.00649227),
  DSP16_Q(0.01100757),
  DSP16_Q(-0.01681111),
  DSP16_Q(0.02383807),
  DSP16_Q(-0.03207710),
  DSP16_Q(0.04192666),
  DSP16_Q(-0.05556332),
  DSP16_Q(0.08704833),
  DSP16_Q(0.43843349),
  DSP16_Q(-0.00407310),
  DSP16_Q(-0.01564669),
  DSP16_Q(0.02065637),
  DSP16_Q(-0.02085939),
  DSP16_Q(0.01872638),
  DSP16_Q(-0.01542705),
  DSP16_Q(0.01172557),
  DSP16_Q(-0.00817029),
  DSP16_Q(0.00513289),
  DSP16_Q(-0.00281655),
  DSP16_Q(0.00126814),
  DSP16_Q(-0.00040403),
  DSP16_Q(0.00004942),
  DSP16_Q(0.00001414),
  DSP16_Q(-0.00000099),
  DSP16_Q(0.00009873),
  DSP16_Q(-0.00026357),
  DSP16_Q(0.00029538),
  DSP16_Q(0.00007223),
  DSP16_Q(-0.00113397),
  DSP16_Q(0.00316702),
  DSP16_Q(-0.00638623),
  DSP16_Q(0.01091163),
  DSP16_Q(-0.01676146),
  DSP16_Q(0.02389038),
  DSP16_Q(-0.03231811),
  DSP16_Q(0.04250885),
  DSP16_Q(-0.05684193),
  DSP16_Q(0.09057868),
  DSP16_Q(0.43757756),
  DSP16_Q(-0.00674388),
  DSP16_Q(-0.01425561),
  DSP16_Q(0.01982232),
  DSP16_Q(-0.02035640),
  DSP16_Q(0.01844210),
  DSP16_Q(-0.01528909),
  DSP16_Q(0.01168092),
  DSP16_Q(-0.00817887),
  DSP16_Q(0.00516531),
  DSP16_Q(-0.00285314),
  DSP16_Q(0.00129780),
  DSP16_Q(-0.00042266),
  DSP16_Q(0.00005792),
  DSP16_Q(0.00001207),
  DSP16_Q(-0.00000114),
  DSP16_Q(0.00010214),
  DSP16_Q(-0.00027533),
  DSP16_Q(0.00032211),
  DSP16_Q(0.00002417),
  DSP16_Q(-0.00106095),
  DSP16_Q(0.00307089),
  DSP16_Q(-0.00627716),
  DSP16_Q(0.01081098),
  DSP16_Q(-0.01670504),
  DSP16_Q(0.02393358),
  DSP16_Q(-0.03254766),
  DSP16_Q(0.04307773),
  DSP16_Q(-0.05810833),
  DSP16_Q(0.09412862),
  DSP16_Q(0.43666569),
  DSP16_Q(-0.00937851),
  DSP16_Q(-0.01286885),
  DSP16_Q(0.01898504),
  DSP16_Q(-0.01984782),
  DSP16_Q(0.01815188),
  DSP16_Q(-0.01514577),
  DSP16_Q(0.01163192),
  DSP16_Q(-0.00818420),
  DSP16_Q(0.00519552),
  DSP16_Q(-0.00288837),
  DSP16_Q(0.00132670),
  DSP16_Q(-0.00044091),
  DSP16_Q(0.00006626),
  DSP16_Q(0.00001006),
  DSP16_Q(-0.00000130),
  DSP16_Q(0.00010558),
  DSP16_Q(-0.00028712),
  DSP16_Q(0.00034896),
  DSP16_Q(-0.00002426),
  DSP16_Q(-0.00098706),
  DSP16_Q(0.00297303),
  DSP16_Q(-0.00616509),
  DSP16_Q(0.01070563),
  DSP16_Q(-0.01664183),
  DSP16_Q(0.02396762),
  DSP16_Q(-0.03276560),
  DSP16_Q(0.04363299),
  DSP16_Q(-0.05936193),
  DSP16_Q(0.09769747),
  DSP16_Q(0.43569808),
  DSP16_Q(-0.01197662),
  DSP16_Q(-0.01148689),
  DSP16_Q(0.01814484),
  DSP16_Q(-0.01933388),
  DSP16_Q(0.01785586),
  DSP16_Q(-0.01499717),
  DSP16_Q(0.01157859),
  DSP16_Q(-0.00818629),
  DSP16_Q(0.00522352),
  DSP16_Q(-0.00292222),
  DSP16_Q(0.00135483),
  DSP16_Q(-0.00045879),
  DSP16_Q(0.00007445),
  DSP16_Q(0.00000811),
  DSP16_Q(-0.00000148),
  DSP16_Q(0.00010904),
  DSP16_Q(-0.00029894),
  DSP16_Q(0.00037593),
  DSP16_Q(-0.00007304),
  DSP16_Q(-0.00091231),
  DSP16_Q(0.00287346),
  DSP16_Q(-0.00605005),
  DSP16_Q(0.01059562),
  DSP16_Q(-0.01657184),
  DSP16_Q(0.02399245),
  DSP16_Q(-0.03297178),
  DSP16_Q(0.04417437),
  DSP16_Q(-0.06060219),
  DSP16_Q(0.10128456),
  DSP16_Q(0.43467497),
  DSP16_Q(-0.01453784),
  DSP16_Q(-0.01011021),
  DSP16_Q(0.01730206),
  DSP16_Q(-0.01881479),
  DSP16_Q(0.01755418),
  DSP16_Q(-0.01484336),
  DSP16_Q(0.01152098),
  DSP16_Q(-0.00818515),
  DSP16_Q(0.00524930),
  DSP16_Q(-0.00295469),
  DSP16_Q(0.00138220),
  DSP16_Q(-0.00047630),
  DSP16_Q(0.00008247),
  DSP16_Q(0.00000621),
  DSP16_Q(-0.00000167),
  DSP16_Q(0.00011251),
  DSP16_Q(-0.00031078),
  DSP16_Q(0.00040299),
  DSP16_Q(-0.00012215),
  DSP16_Q(-0.00083674),
  DSP16_Q(0.00277223),
  DSP16_Q(-0.00593208),
  DSP16_Q(0.01048095),
  DSP16_Q(-0.01649506),
  DSP16_Q(0.02400802),
  DSP16_Q(-0.03316608),
  DSP16_Q(0.04470156),
  DSP16_Q(-0.06182854),
  DSP16_Q(0.10488921),
  DSP16_Q(0.43359659),
  DSP16_Q(-0.01706183),
  DSP16_Q(-0.00873928),
  DSP16_Q(0.01645705),
  DSP16_Q(-0.01829078),
  DSP16_Q(0.01724699),
  DSP16_Q(-0.01468444),
  DSP16_Q(0.01145912),
  DSP16_Q(-0.00818082),
  DSP16_Q(0.00527287),
  DSP16_Q(-0.00298577),
  DSP16_Q(0.00140879),
  DSP16_Q(-0.00049343),
  DSP16_Q(0.00009034),
  DSP16_Q(0.00000437),
  DSP16_Q(-0.00000187),
  DSP16_Q(0.00011601),
  DSP16_Q(-0.00032265),
  DSP16_Q(0.00043015),
  DSP16_Q(-0.00017158),
  DSP16_Q(-0.00076037),
  DSP16_Q(0.00266935),
  DSP16_Q(-0.00581120),
  DSP16_Q(0.01036166),
  DSP16_Q(-0.01641150),
  DSP16_Q(0.02401429),
  DSP16_Q(-0.03334836),
  DSP16_Q(0.04521430),
  DSP16_Q(-0.06304043),
  DSP16_Q(0.10851070),
  DSP16_Q(0.43246320),
  DSP16_Q(-0.01954824),
  DSP16_Q(-0.00737456),
  DSP16_Q(0.01561013),
  DSP16_Q(-0.01776207),
  DSP16_Q(0.01693441),
  DSP16_Q(-0.01452049),
  DSP16_Q(0.01139307),
  DSP16_Q(-0.00817329),
  DSP16_Q(0.00529422),
  DSP16_Q(-0.00301546),
  DSP16_Q(0.00143461),
  DSP16_Q(-0.00051017),
  DSP16_Q(0.00009804),
  DSP16_Q(0.00000258),
  DSP16_Q(-0.00000208),
  DSP16_Q(0.00011952),
  DSP16_Q(-0.00033454),
  DSP16_Q(0.00045738),
  DSP16_Q(-0.00022131),
  DSP16_Q(-0.00068321),
  DSP16_Q(0.00256486),
  DSP16_Q(-0.00568745),
  DSP16_Q(0.01023776),
  DSP16_Q(-0.01632115),
  DSP16_Q(0.02401120),
  DSP16_Q(-0.03351850),
  DSP16_Q(0.04571230),
  DSP16_Q(-0.06423730),
  DSP16_Q(0.11214835),
  DSP16_Q(0.43127506),
  DSP16_Q(-0.02199676),
  DSP16_Q(-0.00601652),
  DSP16_Q(0.01476163),
  DSP16_Q(-0.01722889),
  DSP16_Q(0.01661661),
  DSP16_Q(-0.01435159),
  DSP16_Q(0.01132287),
  DSP16_Q(-0.00816260),
  DSP16_Q(0.00531337),
  DSP16_Q(-0.00304377),
  DSP16_Q(0.00145963),
  DSP16_Q(-0.00052653),
  DSP16_Q(0.00010558),
  DSP16_Q(0.00000085),
  DSP16_Q(-0.00000230),
  DSP16_Q(0.00012305),
  DSP16_Q(-0.00034643),
  DSP16_Q(0.00048468),
  DSP16_Q(-0.00027132),
  DSP16_Q(-0.00060532),
  DSP16_Q(0.00245880),
  DSP16_Q(-0.00556086),
  DSP16_Q(0.01010930),
  DSP16_Q(-0.01622402),
  DSP16_Q(0.02399872),
  DSP16_Q(-0.03367637),
  DSP16_Q(0.04619529),
  DSP16_Q(-0.06541860),
  DSP16_Q(0.11580144),
  DSP16_Q(0.43003245),
  DSP16_Q(-0.02440705),
  DSP16_Q(-0.00466561),
  DSP16_Q(0.01391189),
  DSP16_Q(-0.01669147),
  DSP16_Q(0.01629371),
  DSP16_Q(-0.01417783),
  DSP16_Q(0.01124856),
  DSP16_Q(-0.00814876),
  DSP16_Q(0.00533032),
  DSP16_Q(-0.00307067),
  DSP16_Q(0.00148387),
  DSP16_Q(-0.00054249),
  DSP16_Q(0.00011295),
  DSP16_Q(-0.00000083),
  DSP16_Q(-0.00000254),
  DSP16_Q(0.00012659),
  DSP16_Q(-0.00035833),
  DSP16_Q(0.00051204),
  DSP16_Q(-0.00032159),
  DSP16_Q(-0.00052669),
  DSP16_Q(0.00235120),
  DSP16_Q(-0.00543148),
  DSP16_Q(0.00997630),
  DSP16_Q(-0.01612013),
  DSP16_Q(0.02397681),
  DSP16_Q(-0.03382185),
  DSP16_Q(0.04666301),
  DSP16_Q(-0.06658376),
  DSP16_Q(0.11946927),
  DSP16_Q(0.42873567),
  DSP16_Q(-0.02677882),
  DSP16_Q(-0.00332227),
  DSP16_Q(0.01306124),
  DSP16_Q(-0.01615004),
  DSP16_Q(0.01596589),
  DSP16_Q(-0.01399930),
  DSP16_Q(0.01117020),
  DSP16_Q(-0.00813178),
  DSP16_Q(0.00534507),
  DSP16_Q(-0.00309618),
  DSP16_Q(0.00150732),
  DSP16_Q(-0.00055806),
  DSP16_Q(0.00012015),
  DSP16_Q(-0.00000245),
  DSP16_Q(-0.00000279),
  DSP16_Q(0.00013013),
  DSP16_Q(-0.00037023),
  DSP16_Q(0.00053944),
  DSP16_Q(-0.00037210),
  DSP16_Q(-0.00044738),
  DSP16_Q(0.00224210),
  DSP16_Q(-0.00529934),
  DSP16_Q(0.00983879),
  DSP16_Q(-0.01600948),
  DSP16_Q(0.02394544),
  DSP16_Q(-0.03395483),
  DSP16_Q(0.04711518),
  DSP16_Q(-0.06773224),
  DSP16_Q(0.12315110),
  DSP16_Q(0.42738501),
  DSP16_Q(-0.02911177),
  DSP16_Q(-0.00198696),
  DSP16_Q(0.01221001),
  DSP16_Q(-0.01560481),
  DSP16_Q(0.01563327),
  DSP16_Q(-0.01381608),
  DSP16_Q(0.01108782),
  DSP16_Q(-0.00811171),
  DSP16_Q(0.00535763),
  DSP16_Q(-0.00312029),
  DSP16_Q(0.00152997),
  DSP16_Q(-0.00057323),
  DSP16_Q(0.00012719),
  DSP16_Q(-0.00000402),
  DSP16_Q(-0.00000306),
  DSP16_Q(0.00013369),
  DSP16_Q(-0.00038212),
  DSP16_Q(0.00056688),
  DSP16_Q(-0.00042284),
  DSP16_Q(-0.00036740),
  DSP16_Q(0.00213152),
  DSP16_Q(-0.00516448),
  DSP16_Q(0.00969680),
  DSP16_Q(-0.01589209),
  DSP16_Q(0.02390458),
  DSP16_Q(-0.03407520),
  DSP16_Q(0.04755155),
  DSP16_Q(-0.06886349),
  DSP16_Q(0.12684622),
  DSP16_Q(0.42598080),
  DSP16_Q(-0.03140561),
  DSP16_Q(-0.00066012),
  DSP16_Q(0.01135852),
  DSP16_Q(-0.01505602),
  DSP16_Q(0.01529601),
  DSP16_Q(-0.01362828),
  DSP16_Q(0.01100149),
  DSP16_Q(-0.00808854),
  DSP16_Q(0.00536800),
  DSP16_Q(-0.00314300),
  DSP16_Q(0.00155182),
  DSP16_Q(-0.00058801),
  DSP16_Q(0.00013405),
  DSP16_Q(-0.00000553),
  DSP16_Q(-0.00000333),
  DSP16_Q(0.00013725),
  DSP16_Q(-0.00039399),
  DSP16_Q(0.00059434),
  DSP16_Q(-0.00047377),
  DSP16_Q(-0.00028678),
  DSP16_Q(0.00201951),
  DSP16_Q(-0.00502693),
  DSP16_Q(0.00955038),
  DSP16_Q(-0.01576797),
  DSP16_Q(0.02385420),
  DSP16_Q(-0.03418285),
  DSP16_Q(0.04797185),
  DSP16_Q(-0.06997694),
  DSP16_Q(0.13055389),
  DSP16_Q(0.42452337),
  DSP16_Q(-0.03366009),
  DSP16_Q(0.00065784),
  DSP16_Q(0.01050710),
  DSP16_Q(-0.01450389),
  DSP16_Q(0.01495426),
  DSP16_Q(-0.01343598),
  DSP16_Q(0.01091125),
  DSP16_Q(-0.00806232),
  DSP16_Q(0.00537620),
  DSP16_Q(-0.00316431),
  DSP16_Q(0.00157286),
  DSP16_Q(-0.00060238),
  DSP16_Q(0.00014075),
  DSP16_Q(-0.00000699),
  DSP16_Q(-0.00000362),
  DSP16_Q(0.00014082),
  DSP16_Q(-0.00040585),
  DSP16_Q(0.00062181),
  DSP16_Q(-0.00052489),
  DSP16_Q(-0.00020555),
  DSP16_Q(0.00190610),
  DSP16_Q(-0.00488675),
  DSP16_Q(0.00939955),
  DSP16_Q(-0.01563714),
  DSP16_Q(0.02379429),
  DSP16_Q(-0.03427767),
  DSP16_Q(0.04837585),
  DSP16_Q(-0.07107206),
  DSP16_Q(0.13427338),
  DSP16_Q(0.42301304),
  DSP16_Q(-0.03587493),
  DSP16_Q(0.00196647),
  DSP16_Q(0.00965607),
  DSP16_Q(-0.01394866),
  DSP16_Q(0.01460818),
  DSP16_Q(-0.01323928),
  DSP16_Q(0.01081715),
  DSP16_Q(-0.00803307),
  DSP16_Q(0.00538223),
  DSP16_Q(-0.00318422),
  DSP16_Q(0.00159310),
  DSP16_Q(-0.00061634),
  DSP16_Q(0.00014727),
  DSP16_Q(-0.00000839),
  DSP16_Q(-0.00000392),
  DSP16_Q(0.00014439),
  DSP16_Q(-0.00041769),
  DSP16_Q(0.00064928),
  DSP16_Q(-0.00057618),
  DSP16_Q(-0.00012374),
  DSP16_Q(0.00179134),
  DSP16_Q(-0.00474397),
  DSP16_Q(0.00924436),
  DSP16_Q(-0.01549963),
  DSP16_Q(0.02372482),
  DSP16_Q(-0.03435958),
  DSP16_Q(0.04876329),
  DSP16_Q(-0.07214829),
  DSP16_Q(0.13800393),
  DSP16_Q(0.42145019),
  DSP16_Q(-0.03804989),
  DSP16_Q(0.00326536),
  DSP16_Q(0.00880576),
  DSP16_Q(-0.01339055),
  DSP16_Q(0.01425791),
  DSP16_Q(-0.01303828),
  DSP16_Q(0.01071926),
  DSP16_Q(-0.00800081),
  DSP16_Q(0.00538611),
  DSP16_Q(-0.00320274),
  DSP16_Q(0.00161253),
  DSP16_Q(-0.00062990),
  DSP16_Q(0.00015362),
  DSP16_Q(-0.00000974),
  DSP16_Q(-0.00000424),
  DSP16_Q(0.00014795),
  DSP16_Q(-0.00042949),
  DSP16_Q(0.00067673),
  DSP16_Q(-0.00062761),
  DSP16_Q(-0.00004138),
  DSP16_Q(0.00167525),
  DSP16_Q(-0.00459864),
  DSP16_Q(0.00908486),
  DSP16_Q(-0.01535546),
  DSP16_Q(0.02364577),
  DSP16_Q(-0.03442847),
  DSP16_Q(0.04913393),
  DSP16_Q(-0.07320510),
  DSP16_Q(0.14174481),
  DSP16_Q(0.41983517),
  DSP16_Q(-0.04018474),
  DSP16_Q(0.00455410),
  DSP16_Q(0.00795649),
  DSP16_Q(-0.01282979),
  DSP16_Q(0.01390362),
  DSP16_Q(-0.01283306),
  DSP16_Q(0.01061762),
  DSP16_Q(-0.00796557),
  DSP16_Q(0.00538783),
  DSP16_Q(-0.00321985),
  DSP16_Q(0.00163115),
  DSP16_Q(-0.00064305),
  DSP16_Q(0.00015980),
  DSP16_Q(-0.00001103),
  DSP16_Q(-0.00000456),
  DSP16_Q(0.00015151),
  DSP16_Q(-0.00044125),
  DSP16_Q(0.00070416),
  DSP16_Q(-0.00067916),
  DSP16_Q(0.00004150),
  DSP16_Q(0.00155789),
  DSP16_Q(-0.00445080),
  DSP16_Q(0.00892108),
  DSP16_Q(-0.01520466),
  DSP16_Q(0.02355715),
  DSP16_Q(-0.03448426),
  DSP16_Q(0.04948754),
  DSP16_Q(-0.07424194),
  DSP16_Q(0.14549527),
  DSP16_Q(0.41816837),
  DSP16_Q(-0.04227924),
  DSP16_Q(0.00583227),
  DSP16_Q(0.00710857),
  DSP16_Q(-0.01226661),
  DSP16_Q(0.01354545),
  DSP16_Q(-0.01262374),
  DSP16_Q(0.01051229),
  DSP16_Q(-0.00792737),
  DSP16_Q(0.00538742),
  DSP16_Q(-0.00323557),
  DSP16_Q(0.00164897),
  DSP16_Q(-0.00065579),
  DSP16_Q(0.00016581),
  DSP16_Q(-0.00001227),
  DSP16_Q(-0.00000490),
  DSP16_Q(0.00015507),
  DSP16_Q(-0.00045298),
  DSP16_Q(0.00073155),
  DSP16_Q(-0.00073081),
  DSP16_Q(0.00012487),
  DSP16_Q(0.00143928),
  DSP16_Q(-0.00430051),
  DSP16_Q(0.00875306),
  DSP16_Q(-0.01504725),
  DSP16_Q(0.02345893),
  DSP16_Q(-0.03452686),
  DSP16_Q(0.04982387),
  DSP16_Q(-0.07525826),
  DSP16_Q(0.14925453),
  DSP16_Q(0.41645017),
  DSP16_Q(-0.04433320),
  DSP16_Q(0.00709947),
  DSP16_Q(0.00626232),
  DSP16_Q(-0.01170124),
  DSP16_Q(0.01318356),
  DSP16_Q(-0.01241040),
  DSP16_Q(0.01040334),
  DSP16_Q(-0.00788626),
  DSP16_Q(0.00538488),
  DSP16_Q(-0.00324990),
  DSP16_Q(0.00166596),
  DSP16_Q(-0.00066812),
  DSP16_Q(0.00017163),
  DSP16_Q(-0.00001346),
  DSP16_Q(-0.00000525),
  DSP16_Q(0.00015862),
  DSP16_Q(-0.00046465),
  DSP16_Q(0.00075890),
  DSP16_Q(-0.00078255),
  DSP16_Q(0.00020870),
  DSP16_Q(0.00131948),
  DSP16_Q(-0.00414780),
  DSP16_Q(0.00858087),
  DSP16_Q(-0.01488328),
  DSP16_Q(0.02335112),
  DSP16_Q(-0.03455620),
  DSP16_Q(0.05014271),
  DSP16_Q(-0.07625354),
  DSP16_Q(0.15302185),
  DSP16_Q(0.41468097),
  DSP16_Q(-0.04634639),
  DSP16_Q(0.00835532),
  DSP16_Q(0.00541806),
  DSP16_Q(-0.01113390),
  DSP16_Q(0.01281811),
  DSP16_Q(-0.01219316),
  DSP16_Q(0.01029081),
  DSP16_Q(-0.00784225),
  DSP16_Q(0.00538023),
  DSP16_Q(-0.00326284),
  DSP16_Q(0.00168215),
  DSP16_Q(-0.00068004),
  DSP16_Q(0.00017729),
  DSP16_Q(-0.00001459),
  DSP16_Q(-0.00000562),
  DSP16_Q(0.00016216),
  DSP16_Q(-0.00047627),
  DSP16_Q(0.00078618),
  DSP16_Q(-0.00083435),
  DSP16_Q(0.00029296),
  DSP16_Q(0.00119852),
  DSP16_Q(-0.00399273),
  DSP16_Q(0.00840454),
  DSP16_Q(-0.01471278),
  DSP16_Q(0.02323371),
  DSP16_Q(-0.03457219),
  DSP16_Q(0.05044384),
  DSP16_Q(-0.07722724),
  DSP16_Q(0.15679645),
  DSP16_Q(0.41286119),
  DSP16_Q(-0.04831864),
  DSP16_Q(0.00959941),
  DSP16_Q(0.00457609),
  DSP16_Q(-0.01056482),
  DSP16_Q(0.01244926),
  DSP16_Q(-0.01197211),
  DSP16_Q(0.01017478),
  DSP16_Q(-0.00779539),
  DSP16_Q(0.00537349),
  DSP16_Q(-0.00327439),
  DSP16_Q(0.00169752),
  DSP16_Q(-0.00069154),
  DSP16_Q(0.00018277),
  DSP16_Q(-0.00001568),
  DSP16_Q(-0.00000599),
  DSP16_Q(0.00016569),
  DSP16_Q(-0.00048783),
  DSP16_Q(0.00081338),
  DSP16_Q(-0.00088618),
  DSP16_Q(0.00037761),
  DSP16_Q(0.00107644),
  DSP16_Q(-0.00383534),
  DSP16_Q(0.00822413),
  DSP16_Q(-0.01453578),
  DSP16_Q(0.02310671),
  DSP16_Q(-0.03457477),
  DSP16_Q(0.05072702),
  DSP16_Q(-0.07817883),
  DSP16_Q(0.16057757),
  DSP16_Q(0.41099125),
  DSP16_Q(-0.05024977),
  DSP16_Q(0.01083138),
  DSP16_Q(0.00373673),
  DSP16_Q(-0.00999423),
  DSP16_Q(0.01207716),
  DSP16_Q(-0.01174735),
  DSP16_Q(0.01005530),
  DSP16_Q(-0.00774570),
  DSP16_Q(0.00536466),
  DSP16_Q(-0.00328456),
  DSP16_Q(0.00171208),
  DSP16_Q(-0.00070263),
  DSP16_Q(0.00018807),
  DSP16_Q(-0.00001670),
  DSP16_Q(-0.00000638),
  DSP16_Q(0.00016920),
  DSP16_Q(-0.00049932),
  DSP16_Q(0.00084050),
  DSP16_Q(-0.00093804),
  DSP16_Q(0.00046262),
  DSP16_Q(0.00095329),
  DSP16_Q(-0.00367570),
  DSP16_Q(0.00803968),
  DSP16_Q(-0.01435233),
  DSP16_Q(0.02297013),
  DSP16_Q(-0.03456388),
  DSP16_Q(0.05099206),
  DSP16_Q(-0.07910777),
  DSP16_Q(0.16436442),
  DSP16_Q(0.40907159),
  DSP16_Q(-0.05213961),
  DSP16_Q(0.01205084),
  DSP16_Q(0.00290028),
  DSP16_Q(-0.00942237),
  DSP16_Q(0.01170197),
  DSP16_Q(-0.01151899),
  DSP16_Q(0.00993244),
  DSP16_Q(-0.00769321),
  DSP16_Q(0.00535376),
  DSP16_Q(-0.00329335),
  DSP16_Q(0.00172583),
  DSP16_Q(-0.00071330),
  DSP16_Q(0.00019320),
  DSP16_Q(-0.00001768),
  DSP16_Q(-0.00000677),
  DSP16_Q(0.00017270),
  DSP16_Q(-0.00051074),
  DSP16_Q(0.00086752),
  DSP16_Q(-0.00098989),
  DSP16_Q(0.00054797),
  DSP16_Q(0.00082911),
  DSP16_Q(-0.00351385),
  DSP16_Q(0.00785127),
  DSP16_Q(-0.01416246),
  DSP16_Q(0.02282397),
  DSP16_Q(-0.03453945),
  DSP16_Q(0.05123875),
  DSP16_Q(-0.08001355),
  DSP16_Q(0.16815624),
  DSP16_Q(0.40710265),
  DSP16_Q(-0.05398801),
  DSP16_Q(0.01325742),
  DSP16_Q(0.00206704),
  DSP16_Q(-0.00884944),
  DSP16_Q(0.01132386),
  DSP16_Q(-0.01128713),
  DSP16_Q(0.00980625),
  DSP16_Q(-0.00763797),
  DSP16_Q(0.00534080),
  DSP16_Q(-0.00330078),
  DSP16_Q(0.00173876),
  DSP16_Q(-0.00072355),
  DSP16_Q(0.00019815),
  DSP16_Q(-0.00001861),
  DSP16_Q(-0.00000718),
  DSP16_Q(0.00017617),
  DSP16_Q(-0.00052207),
  DSP16_Q(0.00089443),
  DSP16_Q(-0.00104172),
  DSP16_Q(0.00063362),
  DSP16_Q(0.00070395),
  DSP16_Q(-0.00334984),
  DSP16_Q(0.00765893),
  DSP16_Q(-0.01396624),
  DSP16_Q(0.02266826),
  DSP16_Q(-0.03450143),
  DSP16_Q(0.05146689),
  DSP16_Q(-0.08089565),
  DSP16_Q(0.17195223),
  DSP16_Q(0.40508490),
  DSP16_Q(-0.05579482),
  DSP16_Q(0.01445077),
  DSP16_Q(0.00123733),
  DSP16_Q(-0.00827568),
  DSP16_Q(0.01094297),
  DSP16_Q(-0.01105189),
  DSP16_Q(0.00967681),
  DSP16_Q(-0.00758001),
  DSP16_Q(0.00532581),
  DSP16_Q(-0.00330683),
  DSP16_Q(0.00175088),
  DSP16_Q(-0.00073339),
  DSP16_Q(0.00020293),
  DSP16_Q(-0.00001949),
  DSP16_Q(-0.00000760),
  DSP16_Q(0.00017962),
  DSP16_Q(-0.00053332),
  DSP16_Q(0.00092121),
  DSP16_Q(-0.00109351),
  DSP16_Q(0.00071953),
  DSP16_Q(0.00057785),
  DSP16_Q(-0.00318373),
  DSP16_Q(0.00746273),
  DSP16_Q(-0.01376370),
  DSP16_Q(0.02250300),
  DSP16_Q(-0.03444976),
  DSP16_Q(0.05167628),
  DSP16_Q(-0.08175355),
  DSP16_Q(0.17575161),
  DSP16_Q(0.40301881),
  DSP16_Q(-0.05755991),
  DSP16_Q(0.01563053),
  DSP16_Q(0.00041143),
  DSP16_Q(-0.00770132),
  DSP16_Q(0.01055948),
  DSP16_Q(-0.01081336),
  DSP16_Q(0.00954417),
  DSP16_Q(-0.00751935),
  DSP16_Q(0.00530881),
  DSP16_Q(-0.00331153),
  DSP16_Q(0.00176219),
  DSP16_Q(-0.00074281),
  DSP16_Q(0.00020753),
  DSP16_Q(-0.00002031),
  DSP16_Q(-0.00000802),
  DSP16_Q(0.00018305),
  DSP16_Q(-0.00054448),
  DSP16_Q(0.00094786),
  DSP16_Q(-0.00114523),
  DSP16_Q(0.00080568),
  DSP16_Q(0.00045086),
  DSP16_Q(-0.00301558),
  DSP16_Q(0.00726274),
  DSP16_Q(-0.01355490),
  DSP16_Q(0.02232822),
  DSP16_Q(-0.03438441),
  DSP16_Q(0.05186674),
  DSP16_Q(-0.08258673),
  DSP16_Q(0.17955359),
  DSP16_Q(0.40090485),
  DSP16_Q(-0.05928317),
  DSP16_Q(0.01679634),
  DSP16_Q(-0.00041036),
  DSP16_Q(-0.00712658),
  DSP16_Q(0.01017353),
  DSP16_Q(-0.01057165),
  DSP16_Q(0.00940841),
  DSP16_Q(-0.00745605),
  DSP16_Q(0.00528980),
  DSP16_Q(-0.00331487),
  DSP16_Q(0.00177270),
  DSP16_Q(-0.00075182),
  DSP16_Q(0.00021196),
  DSP16_Q(-0.00002109),
  DSP16_Q(-0.00000846),
  DSP16_Q(0.00018645),
  DSP16_Q(-0.00055553),
  DSP16_Q(0.00097435),
  DSP16_Q(-0.00119685),
  DSP16_Q(0.00089203),
  DSP16_Q(0.00032301),
  DSP16_Q(-0.00284543),
  DSP16_Q(0.00705900),
  DSP16_Q(-0.01333990),
  DSP16_Q(0.02214395),
  DSP16_Q(-0.03430532),
  DSP16_Q(0.05203808),
  DSP16_Q(-0.08339469),
  DSP16_Q(0.18335739),
  DSP16_Q(0.39874352),
  DSP16_Q(-0.06096448),
  DSP16_Q(0.01794788),
  DSP16_Q(-0.00122775),
  DSP16_Q(-0.00655168),
  DSP16_Q(0.00978530),
  DSP16_Q(-0.01032688),
  DSP16_Q(0.00926960),
  DSP16_Q(-0.00739014),
  DSP16_Q(0.00526880),
  DSP16_Q(-0.00331687),
  DSP16_Q(0.00178239),
  DSP16_Q(-0.00076041),
  DSP16_Q(0.00021621),
  DSP16_Q(-0.00002182),
  DSP16_Q(-0.00000891),
  DSP16_Q(0.00018982),
  DSP16_Q(-0.00056648),
  DSP16_Q(0.00100069),
  DSP16_Q(-0.00124837),
  DSP16_Q(0.00097854),
  DSP16_Q(0.00019437),
  DSP16_Q(-0.00267336),
  DSP16_Q(0.00685159),
  DSP16_Q(-0.01311875),
  DSP16_Q(0.02195022),
  DSP16_Q(-0.03421247),
  DSP16_Q(0.05219012),
  DSP16_Q(-0.08417692),
  DSP16_Q(0.18716221),
  DSP16_Q(0.39653532),
  DSP16_Q(-0.06260376),
  DSP16_Q(0.01908481),
  DSP16_Q(-0.00204044),
  DSP16_Q(-0.00597684),
  DSP16_Q(0.00939494),
  DSP16_Q(-0.01007914),
  DSP16_Q(0.00912780),
  DSP16_Q(-0.00732165),
  DSP16_Q(0.00524585),
  DSP16_Q(-0.00331753),
  DSP16_Q(0.00179128),
  DSP16_Q(-0.00076858),
  DSP16_Q(0.00022029),
  DSP16_Q(-0.00002250),
  DSP16_Q(-0.00000936),
  DSP16_Q(0.00019315),
  DSP16_Q(-0.00057732),
  DSP16_Q(0.00102685),
  DSP16_Q(-0.00129975),
  DSP16_Q(0.00106518),
  DSP16_Q(0.00006497),
  DSP16_Q(-0.00249942),
  DSP16_Q(0.00664057),
  DSP16_Q(-0.01289150),
  DSP16_Q(0.02174706),
  DSP16_Q(-0.03410582),
  DSP16_Q(0.05232270),
  DSP16_Q(-0.08493292),
  DSP16_Q(0.19096724),
  DSP16_Q(0.39428077),
  DSP16_Q(-0.06420092),
  DSP16_Q(0.02020680),
  DSP16_Q(-0.00284815),
  DSP16_Q(-0.00540229),
  DSP16_Q(0.00900262),
  DSP16_Q(-0.00982856),
  DSP16_Q(0.00898307),
  DSP16_Q(-0.00725064),
  DSP16_Q(0.00522095),
  DSP16_Q(-0.00331686),
  DSP16_Q(0.00179937),
  DSP16_Q(-0.00077634),
  DSP16_Q(0.00022419),
  DSP16_Q(-0.00002314),
  DSP16_Q(-0.00000982),
  DSP16_Q(0.00019646),
  DSP16_Q(-0.00058804),
  DSP16_Q(0.00105281),
  DSP16_Q(-0.00135098),
  DSP16_Q(0.00115192),
  DSP16_Q(-0.00006514),
  DSP16_Q(-0.00232367),
  DSP16_Q(0.00642600),
  DSP16_Q(-0.01265823),
  DSP16_Q(0.02153450),
  DSP16_Q(-0.03398535),
  DSP16_Q(0.05243565),
  DSP16_Q(-0.08566220),
  DSP16_Q(0.19477169),
  DSP16_Q(0.39198038),
  DSP16_Q(-0.06575588),
  DSP16_Q(0.02131354),
  DSP16_Q(-0.00365061),
  DSP16_Q(-0.00482825),
  DSP16_Q(0.00860848),
  DSP16_Q(-0.00957524),
  DSP16_Q(0.00883550),
  DSP16_Q(-0.00717713),
  DSP16_Q(0.00519413),
  DSP16_Q(-0.00331488),
  DSP16_Q(0.00180667),
  DSP16_Q(-0.00078368),
  DSP16_Q(0.00022792),
  DSP16_Q(-0.00002373),
  DSP16_Q(-0.00001029),
  DSP16_Q(0.00019972),
  DSP16_Q(-0.00059864),
  DSP16_Q(0.00107858),
  DSP16_Q(-0.00140203),
  DSP16_Q(0.00123873),
  DSP16_Q(-0.00019590),
  DSP16_Q(-0.00214617),
  DSP16_Q(0.00620796),
  DSP16_Q(-0.01241900),
  DSP16_Q(0.02131260),
  DSP16_Q(-0.03385104),
  DSP16_Q(0.05252882),
  DSP16_Q(-0.08636427),
  DSP16_Q(0.19857476),
  DSP16_Q(0.38963469),
  DSP16_Q(-0.06726858),
  DSP16_Q(0.02240470),
  DSP16_Q(-0.00444752),
  DSP16_Q(-0.00425494),
  DSP16_Q(0.00821271),
  DSP16_Q(-0.00931928),
  DSP16_Q(0.00868515),
  DSP16_Q(-0.00710117),
  DSP16_Q(0.00516540),
  DSP16_Q(-0.00331158),
  DSP16_Q(0.00181316),
  DSP16_Q(-0.00079061),
  DSP16_Q(0.00023148),
  DSP16_Q(-0.00002427),
  DSP16_Q(-0.00001077),
  DSP16_Q(0.00020294),
  DSP16_Q(-0.00060910),
  DSP16_Q(0.00110414),
  DSP16_Q(-0.00145288),
  DSP16_Q(0.00132556),
  DSP16_Q(-0.00032727),
  DSP16_Q(-0.00196698),
  DSP16_Q(0.00598652),
  DSP16_Q(-0.01217387),
  DSP16_Q(0.02108139),
  DSP16_Q(-0.03370286),
  DSP16_Q(0.05260204),
  DSP16_Q(-0.08703864),
  DSP16_Q(0.20237565),
  DSP16_Q(0.38724424),
  DSP16_Q(-0.06873898),
  DSP16_Q(0.02348000),
  DSP16_Q(-0.00523861),
  DSP16_Q(-0.00368257),
  DSP16_Q(0.00781545),
  DSP16_Q(-0.00906081),
  DSP16_Q(0.00853210),
  DSP16_Q(-0.00702280),
  DSP16_Q(0.00513480),
  DSP16_Q(-0.00330698),
  DSP16_Q(0.00181887),
  DSP16_Q(-0.00079713),
  DSP16_Q(0.00023486),
  DSP16_Q(-0.00002477),
  DSP16_Q(-0.00001126),
  DSP16_Q(0.00020612),
  DSP16_Q(-0.00061942),
  DSP16_Q(0.00112946),
  DSP16_Q(-0.00150351),
  DSP16_Q(0.00141239),
  DSP16_Q(-0.00045921),
  DSP16_Q(-0.00178617),
  DSP16_Q(0.00576175),
  DSP16_Q(-0.01192292),
  DSP16_Q(0.02084092),
  DSP16_Q(-0.03354082),
  DSP16_Q(0.05265518),
  DSP16_Q(-0.08768482),
  DSP16_Q(0.20617354),
  DSP16_Q(0.38480959),
  DSP16_Q(-0.07016704),
  DSP16_Q(0.02453913),
  DSP16_Q(-0.00602362),
  DSP16_Q(-0.00311136),
  DSP16_Q(0.00741686),
  DSP16_Q(-0.00879994),
  DSP16_Q(0.00837641),
  DSP16_Q(-0.00694207),
  DSP16_Q(0.00510235),
  DSP16_Q(-0.00330109),
  DSP16_Q(0.00182378),
  DSP16_Q(-0.00080323),
  DSP16_Q(0.00023807),
  DSP16_Q(-0.00002523),
  DSP16_Q(-0.00001175),
  DSP16_Q(0.00020925),
  DSP16_Q(-0.00062960),
  DSP16_Q(0.00115455),
  DSP16_Q(-0.00155389),
  DSP16_Q(0.00149917),
  DSP16_Q(-0.00059165),
  DSP16_Q(-0.00160379),
  DSP16_Q(0.00553372),
  DSP16_Q(-0.01166622),
  DSP16_Q(0.02059125),
  DSP16_Q(-0.03336491),
  DSP16_Q(0.05268810),
  DSP16_Q(-0.08830236),
  DSP16_Q(0.20996764),
  DSP16_Q(0.38233131),
  DSP16_Q(-0.07155273),
  DSP16_Q(0.02558181),
  DSP16_Q(-0.00680226),
  DSP16_Q(-0.00254152),
  DSP16_Q(0.00701712),
  DSP16_Q(-0.00853677),
  DSP16_Q(0.00821816),
  DSP16_Q(-0.00685902),
  DSP16_Q(0.00506806),
  DSP16_Q(-0.00329392),
  DSP16_Q(0.00182792),
  DSP16_Q(-0.00080893),
  DSP16_Q(0.00024112),
  DSP16_Q(-0.00002564),
  DSP16_Q(-0.00001225),
  DSP16_Q(0.00021233),
  DSP16_Q(-0.00063963),
  DSP16_Q(0.00117938),
  DSP16_Q(-0.00160400),
  DSP16_Q(0.00158588),
  DSP16_Q(-0.00072455),
  DSP16_Q(-0.00141992),
  DSP16_Q(0.00530250),
  DSP16_Q(-0.01140385),
  DSP16_Q(0.02033242),
  DSP16_Q(-0.03317512),
  DSP16_Q(0.05270067),
  DSP16_Q(-0.08889076),
  DSP16_Q(0.21375713),
  DSP16_Q(0.37980996),
  DSP16_Q(-0.07289604),
  DSP16_Q(0.02660775),
  DSP16_Q(-0.00757429),
  DSP16_Q(-0.00197328),
  DSP16_Q(0.00661637),
  DSP16_Q(-0.00827142),
  DSP16_Q(0.00805743),
  DSP16_Q(-0.00677369),
  DSP16_Q(0.00503196),
  DSP16_Q(-0.00328549),
  DSP16_Q(0.00183127),
  DSP16_Q(-0.00081422),
  DSP16_Q(0.00024399),
  DSP16_Q(-0.00002601),
  DSP16_Q(-0.00001275),
  DSP16_Q(0.00021536),
  DSP16_Q(-0.00064950),
  DSP16_Q(0.00120395),
  DSP16_Q(-0.00165383),
  DSP16_Q(0.00167247),
  DSP16_Q(-0.00085787),
  DSP16_Q(-0.00123462),
  DSP16_Q(0.00506818),
  DSP16_Q(-0.01113588),
  DSP16_Q(0.02006451),
  DSP16_Q(-0.03297147),
  DSP16_Q(0.05269275),
  DSP16_Q(-0.08944958),
  DSP16_Q(0.21754121),
  DSP16_Q(0.37724612),
  DSP16_Q(-0.07419697),
  DSP16_Q(0.02761668),
  DSP16_Q(-0.00833943),
  DSP16_Q(-0.00140684),
  DSP16_Q(0.00621478),
  DSP16_Q(-0.00800401),
  DSP16_Q(0.00789428),
  DSP16_Q(-0.00668613),
  DSP16_Q(0.00499408),
  DSP16_Q(-0.00327579),
  DSP16_Q(0.00183385),
  DSP16_Q(-0.00081911),
  DSP16_Q(0.00024670),
  DSP16_Q(-0.00002634),
  DSP16_Q(-0.00001325),
  DSP16_Q(0.00021833),
  DSP16_Q(-0.00065920),
  DSP16_Q(0.00122824),
  DSP16_Q(-0.00170334),
  DSP16_Q(0.00175892),
  DSP16_Q(-0.00099154),
  DSP16_Q(-0.00104796),
  DSP16_Q(0.00483083),
  DSP16_Q(-0.01086239),
  DSP16_Q(0.01978758),
  DSP16_Q(-0.03275396),
  DSP16_Q(0.05266424),
  DSP16_Q(-0.08997836),
  DSP16_Q(0.22131906),
  DSP16_Q(0.37464040),
  DSP16_Q(-0.07545552),
  DSP16_Q(0.02860834),
  DSP16_Q(-0.00909743),
  DSP16_Q(-0.00084241),
  DSP16_Q(0.00581250),
  DSP16_Q(-0.00773464),
  DSP16_Q(0.00772880),
  DSP16_Q(-0.00659638),
  DSP16_Q(0.00495444),
  DSP16_Q(-0.00326486),
  DSP16_Q(0.00183566),
  DSP16_Q(-0.00082359),
  DSP16_Q(0.00024924),
  DSP16_Q(-0.00002662),
  DSP16_Q(-0.00001376),
  DSP16_Q(0.00022125),
  DSP16_Q(-0.00066874),
  DSP16_Q(0.00125223),
  DSP16_Q(-0.00175251),
  DSP16_Q(0.00184518),
  DSP16_Q(-0.00112551),
  DSP16_Q(-0.00086000),
  DSP16_Q(0.00459054),
  DSP16_Q(-0.01058347),
  DSP16_Q(0.01950169),
  DSP16_Q(-0.03252262),
  DSP16_Q(0.05261501),
  DSP16_Q(-0.09047663),
  DSP16_Q(0.22508988),
  DSP16_Q(0.37199338),
  DSP16_Q(-0.07667172),
  DSP16_Q(0.02958247),
  DSP16_Q(-0.00984804),
  DSP16_Q(-0.00028020),
  DSP16_Q(0.00540971),
  DSP16_Q(-0.00746343),
  DSP16_Q(0.00756106),
  DSP16_Q(-0.00650450),
  DSP16_Q(0.00491306),
  DSP16_Q(-0.00325269),
  DSP16_Q(0.00183671),
  DSP16_Q(-0.00082767),
  DSP16_Q(0.00025161),
  DSP16_Q(-0.00002687),
  DSP16_Q(-0.00001427),
  DSP16_Q(0.00022411),
  DSP16_Q(-0.00067809),
  DSP16_Q(0.00127593),
  DSP16_Q(-0.00180133),
  DSP16_Q(0.00193122),
  DSP16_Q(-0.00125974),
  DSP16_Q(-0.00067082),
  DSP16_Q(0.00434737),
  DSP16_Q(-0.01029920),
  DSP16_Q(0.01920691),
  DSP16_Q(-0.03227745),
  DSP16_Q(0.05254497),
  DSP16_Q(-0.09094396),
  DSP16_Q(0.22885285),
  DSP16_Q(0.36930569),
  DSP16_Q(-0.07784559),
  DSP16_Q(0.03053882),
  DSP16_Q(-0.01059100),
  DSP16_Q(0.00027957),
  DSP16_Q(0.00500654),
  DSP16_Q(-0.00719050),
  DSP16_Q(0.00739113),
  DSP16_Q(-0.00641052),
  DSP16_Q(0.00486998),
  DSP16_Q(-0.00323930),
  DSP16_Q(0.00183699),
  DSP16_Q(-0.00083135),
  DSP16_Q(0.00025382),
  DSP16_Q(-0.00002708),
  DSP16_Q(-0.00001479),
  DSP16_Q(0.00022690),
  DSP16_Q(-0.00068727),
  DSP16_Q(0.00129930),
  DSP16_Q(-0.00184976),
  DSP16_Q(0.00201700),
  DSP16_Q(-0.00139418),
  DSP16_Q(-0.00048047),
  DSP16_Q(0.00410143),
  DSP16_Q(-0.01000967),
  DSP16_Q(0.01890332),
  DSP16_Q(-0.03201849),
  DSP16_Q(0.05245402),
  DSP16_Q(-0.09137991),
  DSP16_Q(0.23260716),
  DSP16_Q(0.36657793),
  DSP16_Q(-0.07897718),
  DSP16_Q(0.03147714),
  DSP16_Q(-0.01132607),
  DSP16_Q(0.00083671),
  DSP16_Q(0.00460318),
  DSP16_Q(-0.00691596),
  DSP16_Q(0.00721909),
  DSP16_Q(-0.00631450),
  DSP16_Q(0.00482522),
  DSP16_Q(-0.00322471),
  DSP16_Q(0.00183653),
  DSP16_Q(-0.00083464),
  DSP16_Q(0.00025586),
  DSP16_Q(-0.00002726),
  DSP16_Q(-0.00001531),
  DSP16_Q(0.00022963),
  DSP16_Q(-0.00069625),
  DSP16_Q(0.00132235),
  DSP16_Q(-0.00189779),
  DSP16_Q(0.00210249),
  DSP16_Q(-0.00152876),
  DSP16_Q(-0.00028904),
  DSP16_Q(0.00385278),
  DSP16_Q(-0.00971498),
  DSP16_Q(0.01859100),
  DSP16_Q(-0.03174578),
  DSP16_Q(0.05234207),
  DSP16_Q(-0.09178404),
  DSP16_Q(0.23635200),
  DSP16_Q(0.36381074),
  DSP16_Q(-0.08006655),
  DSP16_Q(0.03239722),
  DSP16_Q(-0.01205302),
  DSP16_Q(0.00139102),
  DSP16_Q(0.00419976),
  DSP16_Q(-0.00663992),
  DSP16_Q(0.00704502),
  DSP16_Q(-0.00621648),
  DSP16_Q(0.00477881),
  DSP16_Q(-0.00320893),
  DSP16_Q(0.00183532),
  DSP16_Q(-0.00083753),
  DSP16_Q(0.00025775),
  DSP16_Q(-0.00002739),
  DSP16_Q(-0.00001582),
  DSP16_Q(0.00023229),
  DSP16_Q(-0.00070503),
  DSP16_Q(0.00134505),
  DSP16_Q(-0.00194540),
  DSP16_Q(0.00218766),
  DSP16_Q(-0.00166344),
  DSP16_Q(-0.00009659),
  DSP16_Q(0.00360153),
  DSP16_Q(-0.00941520),
  DSP16_Q(0.01827003),
  DSP16_Q(-0.03145934),
  DSP16_Q(0.05220902),
  DSP16_Q(-0.09215593),
  DSP16_Q(0.24008657),
  DSP16_Q(0.36100476),
  DSP16_Q(-0.08111375),
  DSP16_Q(0.03329880),
  DSP16_Q(-0.01277160),
  DSP16_Q(0.00194229),
  DSP16_Q(0.00379645),
  DSP16_Q(-0.00636249),
  DSP16_Q(0.00686900),
  DSP16_Q(-0.00611651),
  DSP16_Q(0.00473077),
  DSP16_Q(-0.00319197),
  DSP16_Q(0.00183337),
  DSP16_Q(-0.00084003),
  DSP16_Q(0.00025947),
  DSP16_Q(-0.00002749),
  DSP16_Q(-0.00001634),
  DSP16_Q(0.00023488),
  DSP16_Q(-0.00071362),
  DSP16_Q(0.00136739),
  DSP16_Q(-0.00199256),
  DSP16_Q(0.00227245),
  DSP16_Q(-0.00179817),
  DSP16_Q(0.00009681),
  DSP16_Q(0.00334774),
  DSP16_Q(-0.00911045),
  DSP16_Q(0.01794050),
  DSP16_Q(-0.03115923),
  DSP16_Q(0.05205482),
  DSP16_Q(-0.09249515),
  DSP16_Q(0.24381004),
  DSP16_Q(0.35816062),
  DSP16_Q(-0.08211887),
  DSP16_Q(0.03418169),
  DSP16_Q(-0.01348158),
  DSP16_Q(0.00249032),
  DSP16_Q(0.00339341),
  DSP16_Q(-0.00608380),
  DSP16_Q(0.00669111),
  DSP16_Q(-0.00601464),
  DSP16_Q(0.00468114),
  DSP16_Q(-0.00317384),
  DSP16_Q(0.00183069),
  DSP16_Q(-0.00084214),
  DSP16_Q(0.00026104),
  DSP16_Q(-0.00002756),
  DSP16_Q(-0.00001686),
  DSP16_Q(0.00023739),
  DSP16_Q(-0.00072199),
  DSP16_Q(0.00138937),
  DSP16_Q(-0.00203924),
  DSP16_Q(0.00235685),
  DSP16_Q(-0.00193288),
  DSP16_Q(0.00029109),
  DSP16_Q(0.00309152),
  DSP16_Q(-0.00880082),
  DSP16_Q(0.01760250),
  DSP16_Q(-0.03084549),
  DSP16_Q(0.05187939),
  DSP16_Q(-0.09280130),
  DSP16_Q(0.24752161),
  DSP16_Q(0.35527898),
  DSP16_Q(-0.08308200),
  DSP16_Q(0.03504567),
  DSP16_Q(-0.01418273),
  DSP16_Q(0.00303491),
  DSP16_Q(0.00299079),
  DSP16_Q(-0.00580395),
  DSP16_Q(0.00651142),
  DSP16_Q(-0.00591093),
  DSP16_Q(0.00462994),
  DSP16_Q(-0.00315457),
  DSP16_Q(0.00182729),
  DSP16_Q(-0.00084387),
  DSP16_Q(0.00026244),
  DSP16_Q(-0.00002759),
  DSP16_Q(-0.00001737),
  DSP16_Q(0.00023983),
  DSP16_Q(-0.00073015),
  DSP16_Q(0.00141097),
  DSP16_Q(-0.00208543),
  DSP16_Q(0.00244081),
  DSP16_Q(-0.00206753),
  DSP16_Q(0.00048616),
  DSP16_Q(0.00283296),
  DSP16_Q(-0.00848640),
  DSP16_Q(0.01725612),
  DSP16_Q(-0.03051818),
  DSP16_Q(0.05168266),
  DSP16_Q(-0.09307397),
  DSP16_Q(0.25122048),
  DSP16_Q(0.35236050),
  DSP16_Q(-0.08400323),
  DSP16_Q(0.03589054),
  DSP16_Q(-0.01487484),
  DSP16_Q(0.00357587),
  DSP16_Q(0.00258875),
  DSP16_Q(-0.00552307),
  DSP16_Q(0.00633001),
  DSP16_Q(-0.00580542),
  DSP16_Q(0.00457720),
  DSP16_Q(-0.00313417),
  DSP16_Q(0.00182316),
  DSP16_Q(-0.00084522),
  DSP16_Q(0.00026370),
  DSP16_Q(-0.00002759),
  DSP16_Q(-0.00001789),
  DSP16_Q(0.00024218),
  DSP16_Q(-0.00073808),
  DSP16_Q(0.00143217),
  DSP16_Q(-0.00213110),
  DSP16_Q(0.00252429),
  DSP16_Q(-0.00220207),
  DSP16_Q(0.00068196),
  DSP16_Q(0.00257213),
  DSP16_Q(-0.00816730),
  DSP16_Q(0.01690145),
  DSP16_Q(-0.03017734),
  DSP16_Q(0.05146458),
  DSP16_Q(-0.09331275),
  DSP16_Q(0.25490582),
  DSP16_Q(0.34940584),
  DSP16_Q(-0.08488267),
  DSP16_Q(0.03671611),
  DSP16_Q(-0.01555768),
  DSP16_Q(0.00411301),
  DSP16_Q(0.00218743),
  DSP16_Q(-0.00524126),
  DSP16_Q(0.00614697),
  DSP16_Q(-0.00569816),
  DSP16_Q(0.00452295),
  DSP16_Q(-0.00311266),
  DSP16_Q(0.00181833),
  DSP16_Q(-0.00084619),
  DSP16_Q(0.00026480),
  DSP16_Q(-0.00002755),
  DSP16_Q(-0.00001840),
  DSP16_Q(0.00024446),
  DSP16_Q(-0.00074579),
  DSP16_Q(0.00145297),
  DSP16_Q(-0.00217624),
  DSP16_Q(0.00260726),
  DSP16_Q(-0.00233643),
  DSP16_Q(0.00087842),
  DSP16_Q(0.00230915),
  DSP16_Q(-0.00784362),
  DSP16_Q(0.01653861),
  DSP16_Q(-0.02982306),
  DSP16_Q(0.05122512),
  DSP16_Q(-0.09351727),
  DSP16_Q(0.25857684),
  DSP16_Q(0.34641569),
  DSP16_Q(-0.08572044),
  DSP16_Q(0.03752219),
  DSP16_Q(-0.01623103),
  DSP16_Q(0.00464614),
  DSP16_Q(0.00178699),
  DSP16_Q(-0.00495864),
  DSP16_Q(0.00596237),
  DSP16_Q(-0.00558921),
  DSP16_Q(0.00446723),
  DSP16_Q(-0.00309004),
  DSP16_Q(0.00181279),
  DSP16_Q(-0.00084679),
  DSP16_Q(0.00026575),
  DSP16_Q(-0.00002749),
  DSP16_Q(-0.00001890),
  DSP16_Q(0.00024664),
  DSP16_Q(-0.00075326),
  DSP16_Q(0.00147335),
  DSP16_Q(-0.00222081),
  DSP16_Q(0.00268968),
  DSP16_Q(-0.00247056),
  DSP16_Q(0.00107546),
  DSP16_Q(0.00204409),
  DSP16_Q(-0.00751548),
  DSP16_Q(0.01616769),
  DSP16_Q(-0.02945540),
  DSP16_Q(0.05096422),
  DSP16_Q(-0.09368713),
  DSP16_Q(0.26223274),
  DSP16_Q(0.34339073),
  DSP16_Q(-0.08651667),
  DSP16_Q(0.03830859),
  DSP16_Q(-0.01689469),
  DSP16_Q(0.00517507),
  DSP16_Q(0.00138759),
  DSP16_Q(-0.00467532),
  DSP16_Q(0.00577629),
  DSP16_Q(-0.00547861),
  DSP16_Q(0.00441005),
  DSP16_Q(-0.00306634),
  DSP16_Q(0.00180656),
  DSP16_Q(-0.00084702),
  DSP16_Q(0.00026655),
  DSP16_Q(-0.00002740),
  DSP16_Q(-0.00001940),
  DSP16_Q(0.00024874),
  DSP16_Q(-0.00076049),
  DSP16_Q(0.00149329),
  DSP16_Q(-0.00226480),
  DSP16_Q(0.00277152),
  DSP16_Q(-0.00260441),
  DSP16_Q(0.00127300),
  DSP16_Q(0.00177706),
  DSP16_Q(-0.00718297),
  DSP16_Q(0.01578880),
  DSP16_Q(-0.02907444),
  DSP16_Q(0.05068185),
  DSP16_Q(-0.09382196),
  DSP16_Q(0.26587270),
  DSP16_Q(0.34033164),
  DSP16_Q(-0.08727151),
  DSP16_Q(0.03907517),
  DSP16_Q(-0.01754846),
  DSP16_Q(0.00569961),
  DSP16_Q(0.00098938),
  DSP16_Q(-0.00439142),
  DSP16_Q(0.00558881),
  DSP16_Q(-0.00536642),
  DSP16_Q(0.00435146),
  DSP16_Q(-0.00304157),
  DSP16_Q(0.00179965),
  DSP16_Q(-0.00084688),
  DSP16_Q(0.00026720),
  DSP16_Q(-0.00002727),
  DSP16_Q(-0.00001990),
  DSP16_Q(0.00025075),
  DSP16_Q(-0.00076747),
  DSP16_Q(0.00151280),
  DSP16_Q(-0.00230818),
  DSP16_Q(0.00285274),
  DSP16_Q(-0.00273793),
  DSP16_Q(0.00147097),
  DSP16_Q(0.00150815),
  DSP16_Q(-0.00684621),
  DSP16_Q(0.01540206),
  DSP16_Q(-0.02868025),
  DSP16_Q(0.05037800),
  DSP16_Q(-0.09392139),
  DSP16_Q(0.26949593),
  DSP16_Q(0.33723912),
  DSP16_Q(-0.08798511),
  DSP16_Q(0.03982174),
  DSP16_Q(-0.01819212),
  DSP16_Q(0.00621958),
  DSP16_Q(0.00059250),
  DSP16_Q(-0.00410705),
  DSP16_Q(0.00540001),
  DSP16_Q(-0.00525269),
  DSP16_Q(0.00429149),
  DSP16_Q(-0.00301576),
  DSP16_Q(0.00179205),
  DSP16_Q(-0.00084637),
  DSP16_Q(0.00026770),
  DSP16_Q(-0.00002712),
  DSP16_Q(-0.00002039),
  DSP16_Q(0.00025267),
  DSP16_Q(-0.00077420),
  DSP16_Q(0.00153185),
  DSP16_Q(-0.00235094),
  DSP16_Q(0.00293330),
  DSP16_Q(-0.00287106),
  DSP16_Q(0.00166929),
  DSP16_Q(0.00123747),
  DSP16_Q(-0.00650532),
  DSP16_Q(0.01500757),
  DSP16_Q(-0.02827292),
  DSP16_Q(0.05005265),
  DSP16_Q(-0.09398507),
  DSP16_Q(0.27310162),
  DSP16_Q(0.33411388),
  DSP16_Q(-0.08865763),
  DSP16_Q(0.04054817),
  DSP16_Q(-0.01882550),
  DSP16_Q(0.00673480),
  DSP16_Q(0.00019710),
  DSP16_Q(-0.00382233),
  DSP16_Q(0.00520997),
  DSP16_Q(-0.00513747),
  DSP16_Q(0.00423017),
  DSP16_Q(-0.00298891),
  DSP16_Q(0.00178379),
  DSP16_Q(-0.00084551),
  DSP16_Q(0.00026807),
  DSP16_Q(-0.00002695),
  DSP16_Q(-0.00002087),
  DSP16_Q(0.00025449),
  DSP16_Q(-0.00078067),
  DSP16_Q(0.00155043),
  DSP16_Q(-0.00239305),
  DSP16_Q(0.00301317),
  DSP16_Q(-0.00300374),
  DSP16_Q(0.00186789),
  DSP16_Q(0.00096509),
  DSP16_Q(-0.00616041),
  DSP16_Q(0.01460546),
  DSP16_Q(-0.02785255),
  DSP16_Q(0.04970578),
  DSP16_Q(-0.09401263),
  DSP16_Q(0.27668898),
  DSP16_Q(0.33095663),
  DSP16_Q(-0.08928924),
  DSP16_Q(0.04125430),
  DSP16_Q(-0.01944838),
  DSP16_Q(0.00724509),
  DSP16_Q(-0.00019667),
  DSP16_Q(-0.00353736),
  DSP16_Q(0.00501878),
  DSP16_Q(-0.00502082),
  DSP16_Q(0.00416752),
  DSP16_Q(-0.00296105),
  DSP16_Q(0.00177486),
  DSP16_Q(-0.00084430),
  DSP16_Q(0.00026829),
  DSP16_Q(-0.00002674),
  DSP16_Q(-0.00002134),
  DSP16_Q(0.00025621),
  DSP16_Q(-0.00078687),
  DSP16_Q(0.00156853),
  DSP16_Q(-0.00243448),
  DSP16_Q(0.00309231),
  DSP16_Q(-0.00313591),
  DSP16_Q(0.00206668),
  DSP16_Q(0.00069114),
  DSP16_Q(-0.00581159),
  DSP16_Q(0.01419586),
  DSP16_Q(-0.02741924),
  DSP16_Q(0.04933741),
  DSP16_Q(-0.09400375),
  DSP16_Q(0.28025723),
  DSP16_Q(0.32776808),
  DSP16_Q(-0.08988013),
  DSP16_Q(0.04194000),
  DSP16_Q(-0.02006060),
  DSP16_Q(0.00775028),
  DSP16_Q(-0.00058866),
  DSP16_Q(-0.00325226),
  DSP16_Q(0.00482651),
  DSP16_Q(-0.00490279),
  DSP16_Q(0.00410359),
  DSP16_Q(-0.00293219),
  DSP16_Q(0.00176529),
  DSP16_Q(-0.00084274),
  DSP16_Q(0.00026837),
  DSP16_Q(-0.00002652),
  DSP16_Q(-0.00002180),
  DSP16_Q(0.00025782),
  DSP16_Q(-0.00079281),
  DSP16_Q(0.00158615),
  DSP16_Q(-0.00247522),
  DSP16_Q(0.00317068),
  DSP16_Q(-0.00326754),
  DSP16_Q(0.00226560),
  DSP16_Q(0.00041571),
  DSP16_Q(-0.00545899),
  DSP16_Q(0.01377888),
  DSP16_Q(-0.02697308),
  DSP16_Q(0.04894753),
  DSP16_Q(-0.09395807),
  DSP16_Q(0.28380555),
  DSP16_Q(0.32454896),
  DSP16_Q(-0.09043050),
  DSP16_Q(0.04260514),
  DSP16_Q(-0.02066197),
  DSP16_Q(0.00825019),
  DSP16_Q(-0.00097873),
  DSP16_Q(-0.00296714),
  DSP16_Q(0.00463324),
  DSP16_Q(-0.00478343),
  DSP16_Q(0.00403840),
  DSP16_Q(-0.00290236),
  DSP16_Q(0.00175507),
  DSP16_Q(-0.00084083),
  DSP16_Q(0.00026831),
  DSP16_Q(-0.00002627),
  DSP16_Q(-0.00002225),
  DSP16_Q(0.00025933),
  DSP16_Q(-0.00079847),
  DSP16_Q(0.00160326),
  DSP16_Q(-0.00251525),
  DSP16_Q(0.00324825),
  DSP16_Q(-0.00339854),
  DSP16_Q(0.00246456),
  DSP16_Q(0.00013889),
  DSP16_Q(-0.00510273),
  DSP16_Q(0.01335465),
  DSP16_Q(-0.02651418),
  DSP16_Q(0.04853615),
  DSP16_Q(-0.09387528),
  DSP16_Q(0.28733318),
  DSP16_Q(0.32129999),
  DSP16_Q(-0.09094054),
  DSP16_Q(0.04324960),
  DSP16_Q(-0.02125231),
  DSP16_Q(0.00874466),
  DSP16_Q(-0.00136674),
  DSP16_Q(-0.00268212),
  DSP16_Q(0.00443906),
  DSP16_Q(-0.00466280),
  DSP16_Q(0.00397199),
  DSP16_Q(-0.00287157),
  DSP16_Q(0.00174423),
  DSP16_Q(-0.00083858),
  DSP16_Q(0.00026812),
  DSP16_Q(-0.00002599),
  DSP16_Q(-0.00002270),
  DSP16_Q(0.00026074),
  DSP16_Q(-0.00080384),
  DSP16_Q(0.00161985),
  DSP16_Q(-0.00255454),
  DSP16_Q(0.00332498),
  DSP16_Q(-0.00352889),
  DSP16_Q(0.00266348),
  DSP16_Q(-0.00013920),
  DSP16_Q(-0.00474293),
  DSP16_Q(0.01292331),
  DSP16_Q(-0.02604266),
  DSP16_Q(0.04810332),
  DSP16_Q(-0.09375505),
  DSP16_Q(0.29083931),
  DSP16_Q(0.31802192),
  DSP16_Q(-0.09141048),
  DSP16_Q(0.04387326),
  DSP16_Q(-0.02183145),
  DSP16_Q(0.00923352),
  DSP16_Q(-0.00175253),
  DSP16_Q(-0.00239729),
  DSP16_Q(0.00424404),
  DSP16_Q(-0.00454095),
  DSP16_Q(0.00390439),
  DSP16_Q(-0.00283984),
  DSP16_Q(0.00173276),
  DSP16_Q(-0.00083599),
  DSP16_Q(0.00026780),
  DSP16_Q(-0.00002570),
  DSP16_Q(-0.00002313),
  DSP16_Q(0.00026203),
  DSP16_Q(-0.00080893),
  DSP16_Q(0.00163592),
  DSP16_Q(-0.00259307),
  DSP16_Q(0.00340084),
  DSP16_Q(-0.00365851),
  DSP16_Q(0.00286229),
  DSP16_Q(-0.00041846),
  DSP16_Q(-0.00437972),
  DSP16_Q(0.01248500),
  DSP16_Q(-0.02555864),
  DSP16_Q(0.04764905),
  DSP16_Q(-0.09359709),
  DSP16_Q(0.29432318),
  DSP16_Q(0.31471547),
  DSP16_Q(-0.09184053),
  DSP16_Q(0.04447603),
  DSP16_Q(-0.02239923),
  DSP16_Q(0.00971660),
  DSP16_Q(-0.00213599),
  DSP16_Q(-0.00211279),
  DSP16_Q(0.00404827),
  DSP16_Q(-0.00441794),
  DSP16_Q(0.00383564),
  DSP16_Q(-0.00280719),
  DSP16_Q(0.00172067),
  DSP16_Q(-0.00083308),
  DSP16_Q(0.00026735),
  DSP16_Q(-0.00002538),
  DSP16_Q(-0.00002354),
  DSP16_Q(0.00026322),
  DSP16_Q(-0.00081372),
  DSP16_Q(0.00165145),
  DSP16_Q(-0.00263082),
  DSP16_Q(0.00347579),
  DSP16_Q(-0.00378735),
  DSP16_Q(0.00306090),
  DSP16_Q(-0.00069880),
  DSP16_Q(-0.00401321),
  DSP16_Q(0.01203984),
  DSP16_Q(-0.02506223),
  DSP16_Q(0.04717338),
  DSP16_Q(-0.09340108),
  DSP16_Q(0.29778400),
  DSP16_Q(0.31138141),
  DSP16_Q(-0.09223093),
  DSP16_Q(0.04505781),
  DSP16_Q(-0.02295549),
  DSP16_Q(0.01019374),
  DSP16_Q(-0.00251695),
  DSP16_Q(-0.00182871),
  DSP16_Q(0.00385182),
  DSP16_Q(-0.00429382),
  DSP16_Q(0.00376577),
  DSP16_Q(-0.00277363),
  DSP16_Q(0.00170799),
  DSP16_Q(-0.00082984),
  DSP16_Q(0.00026677),
  DSP16_Q(-0.00002505),
  DSP16_Q(-0.00002394),
  DSP16_Q(0.00026428),
  DSP16_Q(-0.00081821),
  DSP16_Q(0.00166644),
  DSP16_Q(-0.00266777),
  DSP16_Q(0.00354979),
  DSP16_Q(-0.00391535),
  DSP16_Q(0.00325924),
  DSP16_Q(-0.00098010),
  DSP16_Q(-0.00364355),
  DSP16_Q(0.01158799),
  DSP16_Q(-0.02455358),
  DSP16_Q(0.04667636),
  DSP16_Q(-0.09316673),
  DSP16_Q(0.30122100),
  DSP16_Q(0.30802047),
  DSP16_Q(-0.09258193),
  DSP16_Q(0.04561851),
  DSP16_Q(-0.02350006),
  DSP16_Q(0.01066479),
  DSP16_Q(-0.00289529),
  DSP16_Q(-0.00154516),
  DSP16_Q(0.00365478),
  DSP16_Q(-0.00416865),
  DSP16_Q(0.00369482),
  DSP16_Q(-0.00273920),
  DSP16_Q(0.00169472),
  DSP16_Q(-0.00082628),
  DSP16_Q(0.00026606),
  DSP16_Q(-0.00002470),
  DSP16_Q(-0.00002433),
  DSP16_Q(0.00026523),
  DSP16_Q(-0.00082240),
  DSP16_Q(0.00168086),
  DSP16_Q(-0.00270391),
  DSP16_Q(0.00362281),
  DSP16_Q(-0.00404247),
  DSP16_Q(0.00345723),
  DSP16_Q(-0.00126225),
  DSP16_Q(-0.00327087),
  DSP16_Q(0.01112959),
  DSP16_Q(-0.02403281),
  DSP16_Q(0.04615805),
  DSP16_Q(-0.09289378),
  DSP16_Q(0.30463341),
  DSP16_Q(0.30463341),
  DSP16_Q(-0.09289378),
  DSP16_Q(0.04615805),
  DSP16_Q(-0.02403281),
  DSP16_Q(0.01112959),
  DSP16_Q(-0.00327087),
  DSP16_Q(-0.00126225),
  DSP16_Q(0.00345723),
  DSP16_Q(-0.00404247),
  DSP16_Q(0.00362281),
  DSP16_Q(-0.00270391),
  DSP16_Q(0.00168086),
  DSP16_Q(-0.00082240),
  DSP16_Q(0.00026523),
  DSP16_Q(-0.00002433),
  DSP16_Q(-0.00002470),
  DSP16_Q(0.00026606),
  DSP16_Q(-0.00082628),
  DSP16_Q(0.00169472),
  DSP16_Q(-0.00273920),
  DSP16_Q(0.00369482),
  DSP16_Q(-0.00416865),
  DSP16_Q(0.00365478),
  DSP16_Q(-0.00154516),
  DSP16_Q(-0.00289529),
  DSP16_Q(0.01066479),
  DSP16_Q(-0.02350006),
  DSP16_Q(0.04561851),
  DSP16_Q(-0.09258193),
  DSP16_Q(0.30802047),
  DSP16_Q(0.30122100),
  DSP16_Q(-0.09316673),
  DSP16_Q(0.04667636),
  DSP16_Q(-0.02455358),
  DSP16_Q(0.01158799),
  DSP16_Q(-0.00364355),
  DSP16_Q(-0.00098010),
  DSP16_Q(0.00325924),
  DSP16_Q(-0.00391535),
  DSP16_Q(0.00354979),
  DSP16_Q(-0.00266777),
  DSP16_Q(0.00166644),
  DSP16_Q(-0.00081821),
  DSP16_Q(0.00026428),
  DSP16_Q(-0.00002394),
  DSP16_Q(-0.00002505),
  DSP16_Q(0.00026677),
  DSP16_Q(-0.00082984),
  DSP16_Q(0.00170799),
  DSP16_Q(-0.00277363),
  DSP16_Q(0.00376577),
  DSP16_Q(-0.00429382),
  DSP16_Q(0.00385182),
  DSP16_Q(-0.00182871),
  DSP16_Q(-0.00251695),
  DSP16_Q(0.01019374),
  DSP16_Q(-0.02295549),
  DSP16_Q(0.04505781),
  DSP16_Q(-0.09223093),
  DSP16_Q(0.31138141),
  DSP16_Q(0.29778400),
  DSP16_Q(-0.09340108),
  DSP16_Q(0.04717338),
  DSP16_Q(-0.02506223),
  DSP16_Q(0.01203984),
  DSP16_Q(-0.00401321),
  DSP16_Q(-0.00069880),
  DSP16_Q(0.00306090),
  DSP16_Q(-0.00378735),
  DSP16_Q(0.00347579),
  DSP16_Q(-0.00263082),
  DSP16_Q(0.00165145),
  DSP16_Q(-0.00081372),
  DSP16_Q(0.00026322),
  DSP16_Q(-0.00002354),
  DSP16_Q(-0.00002538),
  DSP16_Q(0.00026735),
  DSP16_Q(-0.00083308),
  DSP16_Q(0.00172067),
  DSP16_Q(-0.00280719),
  DSP16_Q(0.00383564),
  DSP16_Q(-0.00441794),
  DSP16_Q(0.00404827),
  DSP16_Q(-0.00211279),
  DSP16_Q(-0.00213599),
  DSP16_Q(0.00971660),
  DSP16_Q(-0.02239923),
  DSP16_Q(0.04447603),
  DSP16_Q(-0.09184053),
  DSP16_Q(0.31471547),
  DSP16_Q(0.29432318),
  DSP16_Q(-0.09359709),
  DSP16_Q(0.04764905),
  DSP16_Q(-0.02555864),
  DSP16_Q(0.01248500),
  DSP16_Q(-0.00437972),
  DSP16_Q(-0.00041846),
  DSP16_Q(0.00286229),
  DSP16_Q(-0.00365851),
  DSP16_Q(0.00340084),
  DSP16_Q(-0.00259307),
  DSP16_Q(0.00163592),
  DSP16_Q(-0.00080893),
  DSP16_Q(0.00026203),
  DSP16_Q(-0.00002313),
  DSP16_Q(-0.00002570),
  DSP16_Q(0.00026780),
  DSP16_Q(-0.00083599),
  DSP16_Q(0.00173276),
  DSP16_Q(-0.00283984),
  DSP16_Q(0.00390439),
  DSP16_Q(-0.00454095),
  DSP16_Q(0.00424404),
  DSP16_Q(-0.00239729),
  DSP16_Q(-0.00175253),
  DSP16_Q(0.00923352),
  DSP16_Q(-0.02183145),
  DSP16_Q(0.04387326),
  DSP16_Q(-0.09141048),
  DSP16_Q(0.31802192),
  DSP16_Q(0.29083931),
  DSP16_Q(-0.09375505),
  DSP16_Q(0.04810332),
  DSP16_Q(-0.02604266),
  DSP16_Q(0.01292331),
  DSP16_Q(-0.00474293),
  DSP16_Q(-0.00013920),
  DSP16_Q(0.00266348),
  DSP16_Q(-0.00352889),
  DSP16_Q(0.00332498),
  DSP16_Q(-0.00255454),
  DSP16_Q(0.00161985),
  DSP16_Q(-0.00080384),
  DSP16_Q(0.00026074),
  DSP16_Q(-0.00002270),
  DSP16_Q(-0.00002599),
  DSP16_Q(0.00026812),
  DSP16_Q(-0.00083858),
  DSP16_Q(0.00174423),
  DSP16_Q(-0.00287157),
  DSP16_Q(0.00397199),
  DSP16_Q(-0.00466280),
  DSP16_Q(0.00443906),
  DSP16_Q(-0.00268212),
  DSP16_Q(-0.00136674),
  DSP16_Q(0.00874466),
  DSP16_Q(-0.02125231),
  DSP16_Q(0.04324960),
  DSP16_Q(-0.09094054),
  DSP16_Q(0.32129999),
  DSP16_Q(0.28733318),
  DSP16_Q(-0.09387528),
  DSP16_Q(0.04853615),
  DSP16_Q(-0.02651418),
  DSP16_Q(0.01335465),
  DSP16_Q(-0.00510273),
  DSP16_Q(0.00013889),
  DSP16_Q(0.00246456),
  DSP16_Q(-0.00339854),
  DSP16_Q(0.00324825),
  DSP16_Q(-0.00251525),
  DSP16_Q(0.00160326),
  DSP16_Q(-0.00079847),
  DSP16_Q(0.00025933),
  DSP16_Q(-0.00002225),
  DSP16_Q(-0.00002627),
  DSP16_Q(0.00026831),
  DSP16_Q(-0.00084083),
  DSP16_Q(0.00175507),
  DSP16_Q(-0.00290236),
  DSP16_Q(0.00403840),
  DSP16_Q(-0.00478343),
  DSP16_Q(0.00463324),
  DSP16_Q(-0.00296714),
  DSP16_Q(-0.00097873),
  DSP16_Q(0.00825019),
  DSP16_Q(-0.02066197),
  DSP16_Q(0.04260514),
  DSP16_Q(-0.09043050),
  DSP16_Q(0.32454896),
  DSP16_Q(0.28380555),
  DSP16_Q(-0.09395807),
  DSP16_Q(0.04894753),
  DSP16_Q(-0.02697308),
  DSP16_Q(0.01377888),
  DSP16_Q(-0.00545899),
  DSP16_Q(0.00041571),
  DSP16_Q(0.00226560),
  DSP16_Q(-0.00326754),
  DSP16_Q(0.00317068),
  DSP16_Q(-0.00247522),
  DSP16_Q(0.00158615),
  DSP16_Q(-0.00079281),
  DSP16_Q(0.00025782),
  DSP16_Q(-0.00002180),
  DSP16_Q(-0.00002652),
  DSP16_Q(0.00026837),
  DSP16_Q(-0.00084274),
  DSP16_Q(0.00176529),
  DSP16_Q(-0.00293219),
  DSP16_Q(0.00410359),
  DSP16_Q(-0.00490279),
  DSP16_Q(0.00482651),
  DSP16_Q(-0.00325226),
  DSP16_Q(-0.00058866),
  DSP16_Q(0.00775028),
  DSP16_Q(-0.02006060),
  DSP16_Q(0.04194000),
  DSP16_Q(-0.08988013),
  DSP16_Q(0.32776808),
  DSP16_Q(0.28025723),
  DSP16_Q(-0.09400375),
  DSP16_Q(0.04933741),
  DSP16_Q(-0.02741924),
  DSP16_Q(0.01419586),
  DSP16_Q(-0.00581159),
  DSP16_Q(0.00069114),
  DSP16_Q(0.00206668),
  DSP16_Q(-0.00313591),
  DSP16_Q(0.00309231),
  DSP16_Q(-0.00243448),
  DSP16_Q(0.00156853),
  DSP16_Q(-0.00078687),
  DSP16_Q(0.00025621),
  DSP16_Q(-0.00002134),
  DSP16_Q(-0.00002674),
  DSP16_Q(0.00026829),
  DSP16_Q(-0.00084430),
  DSP16_Q(0.00177486),
  DSP16_Q(-0.00296105),
  DSP16_Q(0.00416752),
  DSP16_Q(-0.00502082),
  DSP16_Q(0.00501878),
  DSP16_Q(-0.00353736),
  DSP16_Q(-0.00019667),
  DSP16_Q(0.00724509),
  DSP16_Q(-0.01944838),
  DSP16_Q(0.04125430),
  DSP16_Q(-0.08928924),
  DSP16_Q(0.33095663),
  DSP16_Q(0.27668898),
  DSP16_Q(-0.09401263),
  DSP16_Q(0.04970578),
  DSP16_Q(-0.02785255),
  DSP16_Q(0.01460546),
  DSP16_Q(-0.00616041),
  DSP16_Q(0.00096509),
  DSP16_Q(0.00186789),
  DSP16_Q(-0.00300374),
  DSP16_Q(0.00301317),
  DSP16_Q(-0.00239305),
  DSP16_Q(0.00155043),
  DSP16_Q(-0.00078067),
  DSP16_Q(0.00025449),
  DSP16_Q(-0.00002087),
  DSP16_Q(-0.00002695),
  DSP16_Q(0.00026807),
  DSP16_Q(-0.00084551),
  DSP16_Q(0.00178379),
  DSP16_Q(-0.00298891),
  DSP16_Q(0.00423017),
  DSP16_Q(-0.00513747),
  DSP16_Q(0.00520997),
  DSP16_Q(-0.00382233),
  DSP16_Q(0.00019710),
  DSP16_Q(0.00673480),
  DSP16_Q(-0.01882550),
  DSP16_Q(0.04054817),
  DSP16_Q(-0.08865763),
  DSP16_Q(0.33411388),
  DSP16_Q(0.27310162),
  DSP16_Q(-0.09398507),
  DSP16_Q(0.05005265),
  DSP16_Q(-0.02827292),
  DSP16_Q(0.01500757),
  DSP16_Q(-0.00650532),
  DSP16_Q(0.00123747),
  DSP16_Q(0.00166929),
  DSP16_Q(-0.00287106),
  DSP16_Q(0.00293330),
  DSP16_Q(-0.00235094),
  DSP16_Q(0.00153185),
  DSP16_Q(-0.00077420),
  DSP16_Q(0.00025267),
  DSP16_Q(-0.00002039),
  DSP16_Q(-0.00002712),
  DSP16_Q(0.00026770),
  DSP16_Q(-0.00084637),
  DSP16_Q(0.00179205),
  DSP16_Q(-0.00301576),
  DSP16_Q(0.00429149),
  DSP16_Q(-0.00525269),
  DSP16_Q(0.00540001),
  DSP16_Q(-0.00410705),
  DSP16_Q(0.00059250),
  DSP16_Q(0.00621958),
  DSP16_Q(-0.01819212),
  DSP16_Q(0.03982174),
  DSP16_Q(-0.08798511),
  DSP16_Q(0.33723912),
  DSP16_Q(0.26949593),
  DSP16_Q(-0.09392139),
  DSP16_Q(0.05037800),
  DSP16_Q(-0.02868025),
  DSP16_Q(0.01540206),
  DSP16_Q(-0.00684621),
  DSP16_Q(0.00150815),
  DSP16_Q(0.00147097),
  DSP16_Q(-0.00273793),
  DSP16_Q(0.00285274),
  DSP16_Q(-0.00230818),
  DSP16_Q(0.00151280),
  DSP16_Q(-0.00076747),
  DSP16_Q(0.00025075),
  DSP16_Q(-0.00001990),
  DSP16_Q(-0.00002727),
  DSP16_Q(0.00026720),
  DSP16_Q(-0.00084688),
  DSP16_Q(0.00179965),
  DSP16_Q(-0.00304157),
  DSP16_Q(0.00435146),
  DSP16_Q(-0.00536642),
  DSP16_Q(0.00558881),
  DSP16_Q(-0.00439142),
  DSP16_Q(0.00098938),
  DSP16_Q(0.00569961),
  DSP16_Q(-0.01754846),
  DSP16_Q(0.03907517),
  DSP16_Q(-0.08727151),
  DSP16_Q(0.34033164),
  DSP16_Q(0.26587270),
  DSP16_Q(-0.09382196),
  DSP16_Q(0.05068185),
  DSP16_Q(-0.02907444),
  DSP16_Q(0.01578880),
  DSP16_Q(-0.00718297),
  DSP16_Q(0.00177706),
  DSP16_Q(0.00127300),
  DSP16_Q(-0.00260441),
  DSP16_Q(0.00277152),
  DSP16_Q(-0.00226480),
  DSP16_Q(0.00149329),
  DSP16_Q(-0.00076049),
  DSP16_Q(0.00024874),
  DSP16_Q(-0.00001940),
  DSP16_Q(-0.00002740),
  DSP16_Q(0.00026655),
  DSP16_Q(-0.00084702),
  DSP16_Q(0.00180656),
  DSP16_Q(-0.00306634),
  DSP16_Q(0.00441005),
  DSP16_Q(-0.00547861),
  DSP16_Q(0.00577629),
  DSP16_Q(-0.00467532),
  DSP16_Q(0.00138759),
  DSP16_Q(0.00517507),
  DSP16_Q(-0.01689469),
  DSP16_Q(0.03830859),
  DSP16_Q(-0.08651667),
  DSP16_Q(0.34339073),
  DSP16_Q(0.26223274),
  DSP16_Q(-0.09368713),
  DSP16_Q(0.05096422),
  DSP16_Q(-0.02945540),
  DSP16_Q(0.01616769),
  DSP16_Q(-0.00751548),
  DSP16_Q(0.00204409),
  DSP16_Q(0.00107546),
  DSP16_Q(-0.00247056),
  DSP16_Q(0.00268968),
  DSP16_Q(-0.00222081),
  DSP16_Q(0.00147335),
  DSP16_Q(-0.00075326),
  DSP16_Q(0.00024664),
  DSP16_Q(-0.00001890),
  DSP16_Q(-0.00002749),
  DSP16_Q(0.00026575),
  DSP16_Q(-0.00084679),
  DSP16_Q(0.00181279),
  DSP16_Q(-0.00309004),
  DSP16_Q(0.00446723),
  DSP16_Q(-0.00558921),
  DSP16_Q(0.00596237),
  DSP16_Q(-0.00495864),
  DSP16_Q(0.00178699),
  DSP16_Q(0.00464614),
  DSP16_Q(-0.01623103),
  DSP16_Q(0.03752219),
  DSP16_Q(-0.08572044),
  DSP16_Q(0.34641569),
  DSP16_Q(0.25857684),
  DSP16_Q(-0.09351727),
  DSP16_Q(0.05122512),
  DSP16_Q(-0.02982306),
  DSP16_Q(0.01653861),
  DSP16_Q(-0.00784362),
  DSP16_Q(0.00230915),
  DSP16_Q(0.00087842),
  DSP16_Q(-0.00233643),
  DSP16_Q(0.00260726),
  DSP16_Q(-0.00217624),
  DSP16_Q(0.00145297),
  DSP16_Q(-0.00074579),
  DSP16_Q(0.00024446),
  DSP16_Q(-0.00001840),
  DSP16_Q(-0.00002755),
  DSP16_Q(0.00026480),
  DSP16_Q(-0.00084619),
  DSP16_Q(0.00181833),
  DSP16_Q(-0.00311266),
  DSP16_Q(0.00452295),
  DSP16_Q(-0.00569816),
  DSP16_Q(0.00614697),
  DSP16_Q(-0.00524126),
  DSP16_Q(0.00218743),
  DSP16_Q(0.00411301),
  DSP16_Q(-0.01555768),
  DSP16_Q(0.03671611),
  DSP16_Q(-0.08488267),
  DSP16_Q(0.34940584),
  DSP16_Q(0.25490582),
  DSP16_Q(-0.09331275),
  DSP16_Q(0.05146458),
  DSP16_Q(-0.03017734),
  DSP16_Q(0.01690145),
  DSP16_Q(-0.00816730),
  DSP16_Q(0.00257213),
  DSP16_Q(0.00068196),
  DSP16_Q(-0.00220207),
  DSP16_Q(0.00252429),
  DSP16_Q(-0.00213110),
  DSP16_Q(0.00143217),
  DSP16_Q(-0.00073808),
  DSP16_Q(0.00024218),
  DSP16_Q(-0.00001789),
  DSP16_Q(-0.00002759),
  DSP16_Q(0.00026370),
  DSP16_Q(-0.00084522),
  DSP16_Q(0.00182316),
  DSP16_Q(-0.00313417),
  DSP16_Q(0.00457720),
  DSP16_Q(-0.00580542),
  DSP16_Q(0.00633001),
  DSP16_Q(-0.00552307),
  DSP16_Q(0.00258875),
  DSP16_Q(0.00357587),
  DSP16_Q(-0.01487484),
  DSP16_Q(0.03589054),
  DSP16_Q(-0.08400323),
  DSP16_Q(0.35236050),
  DSP16_Q(0.25122048),
  DSP16_Q(-0.09307397),
  DSP16_Q(0.05168266),
  DSP16_Q(-0.03051818),
  DSP16_Q(0.01725612),
  DSP16_Q(-0.00848640),
  DSP16_Q(0.00283296),
  DSP16_Q(0.00048616),
  DSP16_Q(-0.00206753),
  DSP16_Q(0.00244081),
  DSP16_Q(-0.00208543),
  DSP16_Q(0.00141097),
  DSP16_Q(-0.00073015),
  DSP16_Q(0.00023983),
  DSP16_Q(-0.00001737),
  DSP16_Q(-0.00002759),
  DSP16_Q(0.00026244),
  DSP16_Q(-0.00084387),
  DSP16_Q(0.00182729),
  DSP16_Q(-0.00315457),
  DSP16_Q(0.00462994),
  DSP16_Q(-0.00591093),
  DSP16_Q(0.00651142),
  DSP16_Q(-0.00580395),
  DSP16_Q(0.00299079),
  DSP16_Q(0.00303491),
  DSP16_Q(-0.01418273),
  DSP16_Q(0.03504567),
  DSP16_Q(-0.08308200),
  DSP16_Q(0.35527898),
  DSP16_Q(0.24752161),
  DSP16_Q(-0.09280130),
  DSP16_Q(0.05187939),
  DSP16_Q(-0.03084549),
  DSP16_Q(0.01760250),
  DSP16_Q(-0.00880082),
  DSP16_Q(0.00309152),
  DSP16_Q(0.00029109),
  DSP16_Q(-0.00193288),
  DSP16_Q(0.00235685),
  DSP16_Q(-0.00203924),
  DSP16_Q(0.00138937),
  DSP16_Q(-0.00072199),
  DSP16_Q(0.00023739),
  DSP16_Q(-0.00001686),
  DSP16_Q(-0.00002756),
  DSP16_Q(0.00026104),
  DSP16_Q(-0.00084214),
  DSP16_Q(0.00183069),
  DSP16_Q(-0.00317384),
  DSP16_Q(0.00468114),
  DSP16_Q(-0.00601464),
  DSP16_Q(0.00669111),
  DSP16_Q(-0.00608380),
  DSP16_Q(0.00339341),
  DSP16_Q(0.00249032),
  DSP16_Q(-0.01348158),
  DSP16_Q(0.03418169),
  DSP16_Q(-0.08211887),
  DSP16_Q(0.35816062),
  DSP16_Q(0.24381004),
  DSP16_Q(-0.09249515),
  DSP16_Q(0.05205482),
  DSP16_Q(-0.03115923),
  DSP16_Q(0.01794050),
  DSP16_Q(-0.00911045),
  DSP16_Q(0.00334774),
  DSP16_Q(0.00009681),
  DSP16_Q(-0.00179817),
  DSP16_Q(0.00227245),
  DSP16_Q(-0.00199256),
  DSP16_Q(0.00136739),
  DSP16_Q(-0.00071362),
  DSP16_Q(0.00023488),
  DSP16_Q(-0.00001634),
  DSP16_Q(-0.00002749),
  DSP16_Q(0.00025947),
  DSP16_Q(-0.00084003),
  DSP16_Q(0.00183337),
  DSP16_Q(-0.00319197),
  DSP16_Q(0.00473077),
  DSP16_Q(-0.00611651),
  DSP16_Q(0.00686900),
  DSP16_Q(-0.00636249),
  DSP16_Q(0.00379645),
  DSP16_Q(0.00194229),
  DSP16_Q(-0.01277160),
  DSP16_Q(0.03329880),
  DSP16_Q(-0.08111375),
  DSP16_Q(0.36100476),
  DSP16_Q(0.24008657),
  DSP16_Q(-0.09215593),
  DSP16_Q(0.05220902),
  DSP16_Q(-0.03145934),
  DSP16_Q(0.01827003),
  DSP16_Q(-0.00941520),
  DSP16_Q(0.00360153),
  DSP16_Q(-0.00009659),
  DSP16_Q(-0.00166344),
  DSP16_Q(0.00218766),
  DSP16_Q(-0.00194540),
  DSP16_Q(0.00134505),
  DSP16_Q(-0.00070503),
  DSP16_Q(0.00023229),
  DSP16_Q(-0.00001582),
  DSP16_Q(-0.00002739),
  DSP16_Q(0.00025775),
  DSP16_Q(-0.00083753),
  DSP16_Q(0.00183532),
  DSP16_Q(-0.00320893),
  DSP16_Q(0.00477881),
  DSP16_Q(-0.00621648),
  DSP16_Q(0.00704502),
  DSP16_Q(-0.00663992),
  DSP16_Q(0.00419976),
  DSP16_Q(0.00139102),
  DSP16_Q(-0.01205302),
  DSP16_Q(0.03239722),
  DSP16_Q(-0.08006655),
  DSP16_Q(0.36381074),
  DSP16_Q(0.23635200),
  DSP16_Q(-0.09178404),
  DSP16_Q(0.05234207),
  DSP16_Q(-0.03174578),
  DSP16_Q(0.01859100),
  DSP16_Q(-0.00971498),
  DSP16_Q(0.00385278),
  DSP16_Q(-0.00028904),
  DSP16_Q(-0.00152876),
  DSP16_Q(0.00210249),
  DSP16_Q(-0.00189779),
  DSP16_Q(0.00132235),
  DSP16_Q(-0.00069625),
  DSP16_Q(0.00022963),
  DSP16_Q(-0.00001531),
  DSP16_Q(-0.00002726),
  DSP16_Q(0.00025586),
  DSP16_Q(-0.00083464),
  DSP16_Q(0.00183653),
  DSP16_Q(-0.00322471),
  DSP16_Q(0.00482522),
  DSP16_Q(-0.00631450),
  DSP16_Q(0.00721909),
  DSP16_Q(-0.00691596),
  DSP16_Q(0.00460318),
  DSP16_Q(0.00083671),
  DSP16_Q(-0.01132607),
  DSP16_Q(0.03147714),
  DSP16_Q(-0.07897718),
  DSP16_Q(0.36657793),
  DSP16_Q(0.23260716),
  DSP16_Q(-0.09137991),
  DSP16_Q(0.05245402),
  DSP16_Q(-0.03201849),
  DSP16_Q(0.01890332),
  DSP16_Q(-0.01000967),
  DSP16_Q(0.00410143),
  DSP16_Q(-0.00048047),
  DSP16_Q(-0.00139418),
  DSP16_Q(0.00201700),
  DSP16_Q(-0.00184976),
  DSP16_Q(0.00129930),
  DSP16_Q(-0.00068727),
  DSP16_Q(0.00022690),
  DSP16_Q(-0.00001479),
  DSP16_Q(-0.00002708),
  DSP16_Q(0.00025382),
  DSP16_Q(-0.00083135),
  DSP16_Q(0.00183699),
  DSP16_Q(-0.00323930),
  DSP16_Q(0.00486998),
  DSP16_Q(-0.00641052),
  DSP16_Q(0.00739113),
  DSP16_Q(-0.00719050),
  DSP16_Q(0.00500654),
  DSP16_Q(0.00027957),
  DSP16_Q(-0.01059100),
  DSP16_Q(0.03053882),
  DSP16_Q(-0.07784559),
  DSP16_Q(0.36930569),
  DSP16_Q(0.22885285),
  DSP16_Q(-0.09094396),
  DSP16_Q(0.05254497),
  DSP16_Q(-0.03227745),
  DSP16_Q(0.01920691),
  DSP16_Q(-0.01029920),
  DSP16_Q(0.00434737),
  DSP16_Q(-0.00067082),
  DSP16_Q(-0.00125974),
  DSP16_Q(0.00193122),
  DSP16_Q(-0.00180133),
  DSP16_Q(0.00127593),
  DSP16_Q(-0.00067809),
  DSP16_Q(0.00022411),
  DSP16_Q(-0.00001427),
  DSP16_Q(-0.00002687),
  DSP16_Q(0.00025161),
  DSP16_Q(-0.00082767),
  DSP16_Q(0.00183671),
  DSP16_Q(-0.00325269),
  DSP16_Q(0.00491306),
  DSP16_Q(-0.00650450),
  DSP16_Q(0.00756106),
  DSP16_Q(-0.00746343),
  DSP16_Q(0.00540971),
  DSP16_Q(-0.00028020),
  DSP16_Q(-0.00984804),
  DSP16_Q(0.02958247),
  DSP16_Q(-0.07667172),
  DSP16_Q(0.37199338),
  DSP16_Q(0.22508988),
  DSP16_Q(-0.09047663),
  DSP16_Q(0.05261501),
  DSP16_Q(-0.03252262),
  DSP16_Q(0.01950169),
  DSP16_Q(-0.01058347),
  DSP16_Q(0.00459054),
  DSP16_Q(-0.00086000),
  DSP16_Q(-0.00112551),
  DSP16_Q(0.00184518),
  DSP16_Q(-0.00175251),
  DSP16_Q(0.00125223),
  DSP16_Q(-0.00066874),
  DSP16_Q(0.00022125),
  DSP16_Q(-0.00001376),
  DSP16_Q(-0.00002662),
  DSP16_Q(0.00024924),
  DSP16_Q(-0.00082359),
  DSP16_Q(0.00183566),
  DSP16_Q(-0.00326486),
  DSP16_Q(0.00495444),
  DSP16_Q(-0.00659638),
  DSP16_Q(0.00772880),
  DSP16_Q(-0.00773464),
  DSP16_Q(0.00581250),
  DSP16_Q(-0.00084241),
  DSP16_Q(-0.00909743),
  DSP16_Q(0.02860834),
  DSP16_Q(-0.07545552),
  DSP16_Q(0.37464040),
  DSP16_Q(0.22131906),
  DSP16_Q(-0.08997836),
  DSP16_Q(0.05266424),
  DSP16_Q(-0.03275396),
  DSP16_Q(0.01978758),
  DSP16_Q(-0.01086239),
  DSP16_Q(0.00483083),
  DSP16_Q(-0.00104796),
  DSP16_Q(-0.00099154),
  DSP16_Q(0.00175892),
  DSP16_Q(-0.00170334),
  DSP16_Q(0.00122824),
  DSP16_Q(-0.00065920),
  DSP16_Q(0.00021833),
  DSP16_Q(-0.00001325),
  DSP16_Q(-0.00002634),
  DSP16_Q(0.00024670),
  DSP16_Q(-0.00081911),
  DSP16_Q(0.00183385),
  DSP16_Q(-0.00327579),
  DSP16_Q(0.00499408),
  DSP16_Q(-0.00668613),
  DSP16_Q(0.00789428),
  DSP16_Q(-0.00800401),
  DSP16_Q(0.00621478),
  DSP16_Q(-0.00140684),
  DSP16_Q(-0.00833943),
  DSP16_Q(0.02761668),
  DSP16_Q(-0.07419697),
  DSP16_Q(0.37724612),
  DSP16_Q(0.21754121),
  DSP16_Q(-0.08944958),
  DSP16_Q(0.05269275),
  DSP16_Q(-0.03297147),
  DSP16_Q(0.02006451),
  DSP16_Q(-0.01113588),
  DSP16_Q(0.00506818),
  DSP16_Q(-0.00123462),
  DSP16_Q(-0.00085787),
  DSP16_Q(0.00167247),
  DSP16_Q(-0.00165383),
  DSP16_Q(0.00120395),
  DSP16_Q(-0.00064950),
  DSP16_Q(0.00021536),
  DSP16_Q(-0.00001275),
  DSP16_Q(-0.00002601),
  DSP16_Q(0.00024399),
  DSP16_Q(-0.00081422),
  DSP16_Q(0.00183127),
  DSP16_Q(-0.00328549),
  DSP16_Q(0.00503196),
  DSP16_Q(-0.00677369),
  DSP16_Q(0.00805743),
  DSP16_Q(-0.00827142),
  DSP16_Q(0.00661637),
  DSP16_Q(-0.00197328),
  DSP16_Q(-0.00757429),
  DSP16_Q(0.02660775),
  DSP16_Q(-0.07289604),
  DSP16_Q(0.37980996),
  DSP16_Q(0.21375713),
  DSP16_Q(-0.08889076),
  DSP16_Q(0.05270067),
  DSP16_Q(-0.03317512),
  DSP16_Q(0.02033242),
  DSP16_Q(-0.01140385),
  DSP16_Q(0.00530250),
  DSP16_Q(-0.00141992),
  DSP16_Q(-0.00072455),
  DSP16_Q(0.00158588),
  DSP16_Q(-0.00160400),
  DSP16_Q(0.00117938),
  DSP16_Q(-0.00063963),
  DSP16_Q(0.00021233),
  DSP16_Q(-0.00001225),
  DSP16_Q(-0.00002564),
  DSP16_Q(0.00024112),
  DSP16_Q(-0.00080893),
  DSP16_Q(0.00182792),
  DSP16_Q(-0.00329392),
  DSP16_Q(0.00506806),
  DSP16_Q(-0.00685902),
  DSP16_Q(0.00821816),
  DSP16_Q(-0.00853677),
  DSP16_Q(0.00701712),
  DSP16_Q(-0.00254152),
  DSP16_Q(-0.00680226),
  DSP16_Q(0.02558181),
  DSP16_Q(-0.07155273),
  DSP16_Q(0.38233131),
  DSP16_Q(0.20996764),
  DSP16_Q(-0.08830236),
  DSP16_Q(0.05268810),
  DSP16_Q(-0.03336491),
  DSP16_Q(0.02059125),
  DSP16_Q(-0.01166622),
  DSP16_Q(0.00553372),
  DSP16_Q(-0.00160379),
  DSP16_Q(-0.00059165),
  DSP16_Q(0.00149917),
  DSP16_Q(-0.00155389),
  DSP16_Q(0.00115455),
  DSP16_Q(-0.00062960),
  DSP16_Q(0.00020925),
  DSP16_Q(-0.00001175),
  DSP16_Q(-0.00002523),
  DSP16_Q(0.00023807),
  DSP16_Q(-0.00080323),
  DSP16_Q(0.00182378),
  DSP16_Q(-0.00330109),
  DSP16_Q(0.00510235),
  DSP16_Q(-0.00694207),
  DSP16_Q(0.00837641),
  DSP16_Q(-0.00879994),
  DSP16_Q(0.00741686),
  DSP16_Q(-0.00311136),
  DSP16_Q(-0.00602362),
  DSP16_Q(0.02453913),
  DSP16_Q(-0.07016704),
  DSP16_Q(0.38480959),
  DSP16_Q(0.20617354),
  DSP16_Q(-0.08768482),
  DSP16_Q(0.05265518),
  DSP16_Q(-0.03354082),
  DSP16_Q(0.02084092),
  DSP16_Q(-0.01192292),
  DSP16_Q(0.00576175),
  DSP16_Q(-0.00178617),
  DSP16_Q(-0.00045921),
  DSP16_Q(0.00141239),
  DSP16_Q(-0.00150351),
  DSP16_Q(0.00112946),
  DSP16_Q(-0.00061942),
  DSP16_Q(0.00020612),
  DSP16_Q(-0.00001126),
  DSP16_Q(-0.00002477),
  DSP16_Q(0.00023486),
  DSP16_Q(-0.00079713),
  DSP16_Q(0.00181887),
  DSP16_Q(-0.00330698),
  DSP16_Q(0.00513480),
  DSP16_Q(-0.00702280),
  DSP16_Q(0.00853210),
  DSP16_Q(-0.00906081),
  DSP16_Q(0.00781545),
  DSP16_Q(-0.00368257),
  DSP16_Q(-0.00523861),
  DSP16_Q(0.02348000),
  DSP16_Q(-0.06873898),
  DSP16_Q(0.38724424),
  DSP16_Q(0.20237565),
  DSP16_Q(-0.08703864),
  DSP16_Q(0.05260204),
  DSP16_Q(-0.03370286),
  DSP16_Q(0.02108139),
  DSP16_Q(-0.01217387),
  DSP16_Q(0.00598652),
  DSP16_Q(-0.00196698),
  DSP16_Q(-0.00032727),
  DSP16_Q(0.00132556),
  DSP16_Q(-0.00145288),
  DSP16_Q(0.00110414),
  DSP16_Q(-0.00060910),
  DSP16_Q(0.00020294),
  DSP16_Q(-0.00001077),
  DSP16_Q(-0.00002427),
  DSP16_Q(0.00023148),
  DSP16_Q(-0.00079061),
  DSP16_Q(0.00181316),
  DSP16_Q(-0.00331158),
  DSP16_Q(0.00516540),
  DSP16_Q(-0.00710117),
  DSP16_Q(0.00868515),
  DSP16_Q(-0.00931928),
  DSP16_Q(0.00821271),
  DSP16_Q(-0.00425494),
  DSP16_Q(-0.00444752),
  DSP16_Q(0.02240470),
  DSP16_Q(-0.06726858),
  DSP16_Q(0.38963469),
  DSP16_Q(0.19857476),
  DSP16_Q(-0.08636427),
  DSP16_Q(0.05252882),
  DSP16_Q(-0.03385104),
  DSP16_Q(0.02131260),
  DSP16_Q(-0.01241900),
  DSP16_Q(0.00620796),
  DSP16_Q(-0.00214617),
  DSP16_Q(-0.00019590),
  DSP16_Q(0.00123873),
  DSP16_Q(-0.00140203),
  DSP16_Q(0.00107858),
  DSP16_Q(-0.00059864),
  DSP16_Q(0.00019972),
  DSP16_Q(-0.00001029),
  DSP16_Q(-0.00002373),
  DSP16_Q(0.00022792),
  DSP16_Q(-0.00078368),
  DSP16_Q(0.00180667),
  DSP16_Q(-0.00331488),
  DSP16_Q(0.00519413),
  DSP16_Q(-0.00717713),
  DSP16_Q(0.00883550),
  DSP16_Q(-0.00957524),
  DSP16_Q(0.00860848),
  DSP16_Q(-0.00482825),
  DSP16_Q(-0.00365061),
  DSP16_Q(0.02131354),
  DSP16_Q(-0.06575588),
  DSP16_Q(0.39198038),
  DSP16_Q(0.19477169),
  DSP16_Q(-0.08566220),
  DSP16_Q(0.05243565),
  DSP16_Q(-0.03398535),
  DSP16_Q(0.02153450),
  DSP16_Q(-0.01265823),
  DSP16_Q(0.00642600),
  DSP16_Q(-0.00232367),
  DSP16_Q(-0.00006514),
  DSP16_Q(0.00115192),
  DSP16_Q(-0.00135098),
  DSP16_Q(0.00105281),
  DSP16_Q(-0.00058804),
  DSP16_Q(0.00019646),
  DSP16_Q(-0.00000982),
  DSP16_Q(-0.00002314),
  DSP16_Q(0.00022419),
  DSP16_Q(-0.00077634),
  DSP16_Q(0.00179937),
  DSP16_Q(-0.00331686),
  DSP16_Q(0.00522095),
  DSP16_Q(-0.00725064),
  DSP16_Q(0.00898307),
  DSP16_Q(-0.00982856),
  DSP16_Q(0.00900262),
  DSP16_Q(-0.00540229),
  DSP16_Q(-0.00284815),
  DSP16_Q(0.02020680),
  DSP16_Q(-0.06420092),
  DSP16_Q(0.39428077),
  DSP16_Q(0.19096724),
  DSP16_Q(-0.08493292),
  DSP16_Q(0.05232270),
  DSP16_Q(-0.03410582),
  DSP16_Q(0.02174706),
  DSP16_Q(-0.01289150),
  DSP16_Q(0.00664057),
  DSP16_Q(-0.00249942),
  DSP16_Q(0.00006497),
  DSP16_Q(0.00106518),
  DSP16_Q(-0.00129975),
  DSP16_Q(0.00102685),
  DSP16_Q(-0.00057732),
  DSP16_Q(0.00019315),
  DSP16_Q(-0.00000936),
  DSP16_Q(-0.00002250),
  DSP16_Q(0.00022029),
  DSP16_Q(-0.00076858),
  DSP16_Q(0.00179128),
  DSP16_Q(-0.00331753),
  DSP16_Q(0.00524585),
  DSP16_Q(-0.00732165),
  DSP16_Q(0.00912780),
  DSP16_Q(-0.01007914),
  DSP16_Q(0.00939494),
  DSP16_Q(-0.00597684),
  DSP16_Q(-0.00204044),
  DSP16_Q(0.01908481),
  DSP16_Q(-0.06260376),
  DSP16_Q(0.39653532),
  DSP16_Q(0.18716221),
  DSP16_Q(-0.08417692),
  DSP16_Q(0.05219012),
  DSP16_Q(-0.03421247),
  DSP16_Q(0.02195022),
  DSP16_Q(-0.01311875),
  DSP16_Q(0.00685159),
  DSP16_Q(-0.00267336),
  DSP16_Q(0.00019437),
  DSP16_Q(0.00097854),
  DSP16_Q(-0.00124837),
  DSP16_Q(0.00100069),
  DSP16_Q(-0.00056648),
  DSP16_Q(0.00018982),
  DSP16_Q(-0.00000891),
  DSP16_Q(-0.00002182),
  DSP16_Q(0.00021621),
  DSP16_Q(-0.00076041),
  DSP16_Q(0.00178239),
  DSP16_Q(-0.00331687),
  DSP16_Q(0.00526880),
  DSP16_Q(-0.00739014),
  DSP16_Q(0.00926960),
  DSP16_Q(-0.01032688),
  DSP16_Q(0.00978530),
  DSP16_Q(-0.00655168),
  DSP16_Q(-0.00122775),
  DSP16_Q(0.01794788),
  DSP16_Q(-0.06096448),
  DSP16_Q(0.39874352),
  DSP16_Q(0.18335739),
  DSP16_Q(-0.08339469),
  DSP16_Q(0.05203808),
  DSP16_Q(-0.03430532),
  DSP16_Q(0.02214395),
  DSP16_Q(-0.01333990),
  DSP16_Q(0.00705900),
  DSP16_Q(-0.00284543),
  DSP16_Q(0.00032301),
  DSP16_Q(0.00089203),
  DSP16_Q(-0.00119685),
  DSP16_Q(0.00097435),
  DSP16_Q(-0.00055553),
  DSP16_Q(0.00018645),
  DSP16_Q(-0.00000846),
  DSP16_Q(-0.00002109),
  DSP16_Q(0.00021196),
  DSP16_Q(-0.00075182),
  DSP16_Q(0.00177270),
  DSP16_Q(-0.00331487),
  DSP16_Q(0.00528980),
  DSP16_Q(-0.00745605),
  DSP16_Q(0.00940841),
  DSP16_Q(-0.01057165),
  DSP16_Q(0.01017353),
  DSP16_Q(-0.00712658),
  DSP16_Q(-0.00041036),
  DSP16_Q(0.01679634),
  DSP16_Q(-0.05928317),
  DSP16_Q(0.40090485),
  DSP16_Q(0.17955359),
  DSP16_Q(-0.08258673),
  DSP16_Q(0.05186674),
  DSP16_Q(-0.03438441),
  DSP16_Q(0.02232822),
  DSP16_Q(-0.01355490),
  DSP16_Q(0.00726274),
  DSP16_Q(-0.00301558),
  DSP16_Q(0.00045086),
  DSP16_Q(0.00080568),
  DSP16_Q(-0.00114523),
  DSP16_Q(0.00094786),
  DSP16_Q(-0.00054448),
  DSP16_Q(0.00018305),
  DSP16_Q(-0.00000802),
  DSP16_Q(-0.00002031),
  DSP16_Q(0.00020753),
  DSP16_Q(-0.00074281),
  DSP16_Q(0.00176219),
  DSP16_Q(-0.00331153),
  DSP16_Q(0.00530881),
  DSP16_Q(-0.00751935),
  DSP16_Q(0.00954417),
  DSP16_Q(-0.01081336),
  DSP16_Q(0.01055948),
  DSP16_Q(-0.00770132),
  DSP16_Q(0.00041143),
  DSP16_Q(0.01563053),
  DSP16_Q(-0.05755991),
  DSP16_Q(0.40301881),
  DSP16_Q(0.17575161),
  DSP16_Q(-0.08175355),
  DSP16_Q(0.05167628),
  DSP16_Q(-0.03444976),
  DSP16_Q(0.02250300),
  DSP16_Q(-0.01376370),
  DSP16_Q(0.00746273),
  DSP16_Q(-0.00318373),
  DSP16_Q(0.00057785),
  DSP16_Q(0.00071953),
  DSP16_Q(-0.00109351),
  DSP16_Q(0.00092121),
  DSP16_Q(-0.00053332),
  DSP16_Q(0.00017962),
  DSP16_Q(-0.00000760),
  DSP16_Q(-0.00001949),
  DSP16_Q(0.00020293),
  DSP16_Q(-0.00073339),
  DSP16_Q(0.00175088),
  DSP16_Q(-0.00330683),
  DSP16_Q(0.00532581),
  DSP16_Q(-0.00758001),
  DSP16_Q(0.00967681),
  DSP16_Q(-0.01105189),
  DSP16_Q(0.01094297),
  DSP16_Q(-0.00827568),
  DSP16_Q(0.00123733),
  DSP16_Q(0.01445077),
  DSP16_Q(-0.05579482),
  DSP16_Q(0.40508490),
  DSP16_Q(0.17195223),
  DSP16_Q(-0.08089565),
  DSP16_Q(0.05146689),
  DSP16_Q(-0.03450143),
  DSP16_Q(0.02266826),
  DSP16_Q(-0.01396624),
  DSP16_Q(0.00765893),
  DSP16_Q(-0.00334984),
  DSP16_Q(0.00070395),
  DSP16_Q(0.00063362),
  DSP16_Q(-0.00104172),
  DSP16_Q(0.00089443),
  DSP16_Q(-0.00052207),
  DSP16_Q(0.00017617),
  DSP16_Q(-0.00000718),
  DSP16_Q(-0.00001861),
  DSP16_Q(0.00019815),
  DSP16_Q(-0.00072355),
  DSP16_Q(0.00173876),
  DSP16_Q(-0.00330078),
  DSP16_Q(0.00534080),
  DSP16_Q(-0.00763797),
  DSP16_Q(0.00980625),
  DSP16_Q(-0.01128713),
  DSP16_Q(0.01132386),
  DSP16_Q(-0.00884944),
  DSP16_Q(0.00206704),
  DSP16_Q(0.01325742),
  DSP16_Q(-0.05398801),
  DSP16_Q(0.40710265),
  DSP16_Q(0.16815624),
  DSP16_Q(-0.08001355),
  DSP16_Q(0.05123875),
  DSP16_Q(-0.03453945),
  DSP16_Q(0.02282397),
  DSP16_Q(-0.01416246),
  DSP16_Q(0.00785127),
  DSP16_Q(-0.00351385),
  DSP16_Q(0.00082911),
  DSP16_Q(0.00054797),
  DSP16_Q(-0.00098989),
  DSP16_Q(0.00086752),
  DSP16_Q(-0.00051074),
  DSP16_Q(0.00017270),
  DSP16_Q(-0.00000677),
  DSP16_Q(-0.00001768),
  DSP16_Q(0.00019320),
  DSP16_Q(-0.00071330),
  DSP16_Q(0.00172583),
  DSP16_Q(-0.00329335),
  DSP16_Q(0.00535376),
  DSP16_Q(-0.00769321),
  DSP16_Q(0.00993244),
  DSP16_Q(-0.01151899),
  DSP16_Q(0.01170197),
  DSP16_Q(-0.00942237),
  DSP16_Q(0.00290028),
  DSP16_Q(0.01205084),
  DSP16_Q(-0.05213961),
  DSP16_Q(0.40907159),
  DSP16_Q(0.16436442),
  DSP16_Q(-0.07910777),
  DSP16_Q(0.05099206),
  DSP16_Q(-0.03456388),
  DSP16_Q(0.02297013),
  DSP16_Q(-0.01435233),
  DSP16_Q(0.00803968),
  DSP16_Q(-0.00367570),
  DSP16_Q(0.00095329),
  DSP16_Q(0.00046262),
  DSP16_Q(-0.00093804),
  DSP16_Q(0.00084050),
  DSP16_Q(-0.00049932),
  DSP16_Q(0.00016920),
  DSP16_Q(-0.00000638),
  DSP16_Q(-0.00001670),
  DSP16_Q(0.00018807),
  DSP16_Q(-0.00070263),
  DSP16_Q(0.00171208),
  DSP16_Q(-0.00328456),
  DSP16_Q(0.00536466),
  DSP16_Q(-0.00774570),
  DSP16_Q(0.01005530),
  DSP16_Q(-0.01174735),
  DSP16_Q(0.01207716),
  DSP16_Q(-0.00999423),
  DSP16_Q(0.00373673),
  DSP16_Q(0.01083138),
  DSP16_Q(-0.05024977),
  DSP16_Q(0.41099125),
  DSP16_Q(0.16057757),
  DSP16_Q(-0.07817883),
  DSP16_Q(0.05072702),
  DSP16_Q(-0.03457477),
  DSP16_Q(0.02310671),
  DSP16_Q(-0.01453578),
  DSP16_Q(0.00822413),
  DSP16_Q(-0.00383534),
  DSP16_Q(0.00107644),
  DSP16_Q(0.00037761),
  DSP16_Q(-0.00088618),
  DSP16_Q(0.00081338),
  DSP16_Q(-0.00048783),
  DSP16_Q(0.00016569),
  DSP16_Q(-0.00000599),
  DSP16_Q(-0.00001568),
  DSP16_Q(0.00018277),
  DSP16_Q(-0.00069154),
  DSP16_Q(0.00169752),
  DSP16_Q(-0.00327439),
  DSP16_Q(0.00537349),
  DSP16_Q(-0.00779539),
  DSP16_Q(0.01017478),
  DSP16_Q(-0.01197211),
  DSP16_Q(0.01244926),
  DSP16_Q(-0.01056482),
  DSP16_Q(0.00457609),
  DSP16_Q(0.00959941),
  DSP16_Q(-0.04831864),
  DSP16_Q(0.41286119),
  DSP16_Q(0.15679645),
  DSP16_Q(-0.07722724),
  DSP16_Q(0.05044384),
  DSP16_Q(-0.03457219),
  DSP16_Q(0.02323371),
  DSP16_Q(-0.01471278),
  DSP16_Q(0.00840454),
  DSP16_Q(-0.00399273),
  DSP16_Q(0.00119852),
  DSP16_Q(0.00029296),
  DSP16_Q(-0.00083435),
  DSP16_Q(0.00078618),
  DSP16_Q(-0.00047627),
  DSP16_Q(0.00016216),
  DSP16_Q(-0.00000562),
  DSP16_Q(-0.00001459),
  DSP16_Q(0.00017729),
  DSP16_Q(-0.00068004),
  DSP16_Q(0.00168215),
  DSP16_Q(-0.00326284),
  DSP16_Q(0.00538023),
  DSP16_Q(-0.00784225),
  DSP16_Q(0.01029081),
  DSP16_Q(-0.01219316),
  DSP16_Q(0.01281811),
  DSP16_Q(-0.01113390),
  DSP16_Q(0.00541806),
  DSP16_Q(0.00835532),
  DSP16_Q(-0.04634639),
  DSP16_Q(0.41468097),
  DSP16_Q(0.15302185),
  DSP16_Q(-0.07625354),
  DSP16_Q(0.05014271),
  DSP16_Q(-0.03455620),
  DSP16_Q(0.02335112),
  DSP16_Q(-0.01488328),
  DSP16_Q(0.00858087),
  DSP16_Q(-0.00414780),
  DSP16_Q(0.00131948),
  DSP16_Q(0.00020870),
  DSP16_Q(-0.00078255),
  DSP16_Q(0.00075890),
  DSP16_Q(-0.00046465),
  DSP16_Q(0.00015862),
  DSP16_Q(-0.00000525),
  DSP16_Q(-0.00001346),
  DSP16_Q(0.00017163),
  DSP16_Q(-0.00066812),
  DSP16_Q(0.00166596),
  DSP16_Q(-0.00324990),
  DSP16_Q(0.00538488),
  DSP16_Q(-0.00788626),
  DSP16_Q(0.01040334),
  DSP16_Q(-0.01241040),
  DSP16_Q(0.01318356),
  DSP16_Q(-0.01170124),
  DSP16_Q(0.00626232),
  DSP16_Q(0.00709947),
  DSP16_Q(-0.04433320),
  DSP16_Q(0.41645017),
  DSP16_Q(0.14925453),
  DSP16_Q(-0.07525826),
  DSP16_Q(0.04982387),
  DSP16_Q(-0.03452686),
  DSP16_Q(0.02345893),
  DSP16_Q(-0.01504725),
  DSP16_Q(0.00875306),
  DSP16_Q(-0.00430051),
  DSP16_Q(0.00143928),
  DSP16_Q(0.00012487),
  DSP16_Q(-0.00073081),
  DSP16_Q(0.00073155),
  DSP16_Q(-0.00045298),
  DSP16_Q(0.00015507),
  DSP16_Q(-0.00000490),
  DSP16_Q(-0.00001227),
  DSP16_Q(0.00016581),
  DSP16_Q(-0.00065579),
  DSP16_Q(0.00164897),
  DSP16_Q(-0.00323557),
  DSP16_Q(0.00538742),
  DSP16_Q(-0.00792737),
  DSP16_Q(0.01051229),
  DSP16_Q(-0.01262374),
  DSP16_Q(0.01354545),
  DSP16_Q(-0.01226661),
  DSP16_Q(0.00710857),
  DSP16_Q(0.00583227),
  DSP16_Q(-0.04227924),
  DSP16_Q(0.41816837),
  DSP16_Q(0.14549527),
  DSP16_Q(-0.07424194),
  DSP16_Q(0.04948754),
  DSP16_Q(-0.03448426),
  DSP16_Q(0.02355715),
  DSP16_Q(-0.01520466),
  DSP16_Q(0.00892108),
  DSP16_Q(-0.00445080),
  DSP16_Q(0.00155789),
  DSP16_Q(0.00004150),
  DSP16_Q(-0.00067916),
  DSP16_Q(0.00070416),
  DSP16_Q(-0.00044125),
  DSP16_Q(0.00015151),
  DSP16_Q(-0.00000456),
  DSP16_Q(-0.00001103),
  DSP16_Q(0.00015980),
  DSP16_Q(-0.00064305),
  DSP16_Q(0.00163115),
  DSP16_Q(-0.00321985),
  DSP16_Q(0.00538783),
  DSP16_Q(-0.00796557),
  DSP16_Q(0.01061762),
  DSP16_Q(-0.01283306),
  DSP16_Q(0.01390362),
  DSP16_Q(-0.01282979),
  DSP16_Q(0.00795649),
  DSP16_Q(0.00455410),
  DSP16_Q(-0.04018474),
  DSP16_Q(0.41983517),
  DSP16_Q(0.14174481),
  DSP16_Q(-0.07320510),
  DSP16_Q(0.04913393),
  DSP16_Q(-0.03442847),
  DSP16_Q(0.02364577),
  DSP16_Q(-0.01535546),
  DSP16_Q(0.00908486),
  DSP16_Q(-0.00459864),
  DSP16_Q(0.00167525),
  DSP16_Q(-0.00004138),
  DSP16_Q(-0.00062761),
  DSP16_Q(0.00067673),
  DSP16_Q(-0.00042949),
  DSP16_Q(0.00014795),
  DSP16_Q(-0.00000424),
  DSP16_Q(-0.00000974),
  DSP16_Q(0.00015362),
  DSP16_Q(-0.00062990),
  DSP16_Q(0.00161253),
  DSP16_Q(-0.00320274),
  DSP16_Q(0.00538611),
  DSP16_Q(-0.00800081),
  DSP16_Q(0.01071926),
  DSP16_Q(-0.01303828),
  DSP16_Q(0.01425791),
  DSP16_Q(-0.01339055),
  DSP16_Q(0.00880576),
  DSP16_Q(0.00326536),
  DSP16_Q(-0.03804989),
  DSP16_Q(0.42145019),
  DSP16_Q(0.13800393),
  DSP16_Q(-0.07214829),
  DSP16_Q(0.04876329),
  DSP16_Q(-0.03435958),
  DSP16_Q(0.02372482),
  DSP16_Q(-0.01549963),
  DSP16_Q(0.00924436),
  DSP16_Q(-0.00474397),
  DSP16_Q(0.00179134),
  DSP16_Q(-0.00012374),
  DSP16_Q(-0.00057618),
  DSP16_Q(0.00064928),
  DSP16_Q(-0.00041769),
  DSP16_Q(0.00014439),
  DSP16_Q(-0.00000392),
  DSP16_Q(-0.00000839),
  DSP16_Q(0.00014727),
  DSP16_Q(-0.00061634),
  DSP16_Q(0.00159310),
  DSP16_Q(-0.00318422),
  DSP16_Q(0.00538223),
  DSP16_Q(-0.00803307),
  DSP16_Q(0.01081715),
  DSP16_Q(-0.01323928),
  DSP16_Q(0.01460818),
  DSP16_Q(-0.01394866),
  DSP16_Q(0.00965607),
  DSP16_Q(0.00196647),
  DSP16_Q(-0.03587493),
  DSP16_Q(0.42301304),
  DSP16_Q(0.13427338),
  DSP16_Q(-0.07107206),
  DSP16_Q(0.04837585),
  DSP16_Q(-0.03427767),
  DSP16_Q(0.02379429),
  DSP16_Q(-0.01563714),
  DSP16_Q(0.00939955),
  DSP16_Q(-0.00488675),
  DSP16_Q(0.00190610),
  DSP16_Q(-0.00020555),
  DSP16_Q(-0.00052489),
  DSP16_Q(0.00062181),
  DSP16_Q(-0.00040585),
  DSP16_Q(0.00014082),
  DSP16_Q(-0.00000362),
  DSP16_Q(-0.00000699),
  DSP16_Q(0.00014075),
  DSP16_Q(-0.00060238),
  DSP16_Q(0.00157286),
  DSP16_Q(-0.00316431),
  DSP16_Q(0.00537620),
  DSP16_Q(-0.00806232),
  DSP16_Q(0.01091125),
  DSP16_Q(-0.01343598),
  DSP16_Q(0.01495426),
  DSP16_Q(-0.01450389),
  DSP16_Q(0.01050710),
  DSP16_Q(0.00065784),
  DSP16_Q(-0.03366009),
  DSP16_Q(0.42452337),
  DSP16_Q(0.13055389),
  DSP16_Q(-0.06997694),
  DSP16_Q(0.04797185),
  DSP16_Q(-0.03418285),
  DSP16_Q(0.02385420),
  DSP16_Q(-0.01576797),
  DSP16_Q(0.00955038),
  DSP16_Q(-0.00502693),
  DSP16_Q(0.00201951),
  DSP16_Q(-0.00028678),
  DSP16_Q(-0.00047377),
  DSP16_Q(0.00059434),
  DSP16_Q(-0.00039399),
  DSP16_Q(0.00013725),
  DSP16_Q(-0.00000333),
  DSP16_Q(-0.00000553),
  DSP16_Q(0.00013405),
  DSP16_Q(-0.00058801),
  DSP16_Q(0.00155182),
  DSP16_Q(-0.00314300),
  DSP16_Q(0.00536800),
  DSP16_Q(-0.00808854),
  DSP16_Q(0.01100149),
  DSP16_Q(-0.01362828),
  DSP16_Q(0.01529601),
  DSP16_Q(-0.01505602),
  DSP16_Q(0.01135852),
  DSP16_Q(-0.00066012),
  DSP16_Q(-0.03140561),
  DSP16_Q(0.42598080),
  DSP16_Q(0.12684622),
  DSP16_Q(-0.06886349),
  DSP16_Q(0.04755155),
  DSP16_Q(-0.03407520),
  DSP16_Q(0.02390458),
  DSP16_Q(-0.01589209),
  DSP16_Q(0.00969680),
  DSP16_Q(-0.00516448),
  DSP16_Q(0.00213152),
  DSP16_Q(-0.00036740),
  DSP16_Q(-0.00042284),
  DSP16_Q(0.00056688),
  DSP16_Q(-0.00038212),
  DSP16_Q(0.00013369),
  DSP16_Q(-0.00000306),
  DSP16_Q(-0.00000402),
  DSP16_Q(0.00012719),
  DSP16_Q(-0.00057323),
  DSP16_Q(0.00152997),
  DSP16_Q(-0.00312029),
  DSP16_Q(0.00535763),
  DSP16_Q(-0.00811171),
  DSP16_Q(0.01108782),
  DSP16_Q(-0.01381608),
  DSP16_Q(0.01563327),
  DSP16_Q(-0.01560481),
  DSP16_Q(0.01221001),
  DSP16_Q(-0.00198696),
  DSP16_Q(-0.02911177),
  DSP16_Q(0.42738501),
  DSP16_Q(0.12315110),
  DSP16_Q(-0.06773224),
  DSP16_Q(0.04711518),
  DSP16_Q(-0.03395483),
  DSP16_Q(0.02394544),
  DSP16_Q(-0.01600948),
  DSP16_Q(0.00983879),
  DSP16_Q(-0.00529934),
  DSP16_Q(0.00224210),
  DSP16_Q(-0.00044738),
  DSP16_Q(-0.00037210),
  DSP16_Q(0.00053944),
  DSP16_Q(-0.00037023),
  DSP16_Q(0.00013013),
  DSP16_Q(-0.00000279),
  DSP16_Q(-0.00000245),
  DSP16_Q(0.00012015),
  DSP16_Q(-0.00055806),
  DSP16_Q(0.00150732),
  DSP16_Q(-0.00309618),
  DSP16_Q(0.00534507),
  DSP16_Q(-0.00813178),
  DSP16_Q(0.01117020),
  DSP16_Q(-0.01399930),
  DSP16_Q(0.01596589),
  DSP16_Q(-0.01615004),
  DSP16_Q(0.01306124),
  DSP16_Q(-0.00332227),
  DSP16_Q(-0.02677882),
  DSP16_Q(0.42873567),
  DSP16_Q(0.11946927),
  DSP16_Q(-0.06658376),
  DSP16_Q(0.04666301),
  DSP16_Q(-0.03382185),
  DSP16_Q(0.02397681),
  DSP16_Q(-0.01612013),
  DSP16_Q(0.00997630),
  DSP16_Q(-0.00543148),
  DSP16_Q(0.00235120),
  DSP16_Q(-0.00052669),
  DSP16_Q(-0.00032159),
  DSP16_Q(0.00051204),
  DSP16_Q(-0.00035833),
  DSP16_Q(0.00012659),
  DSP16_Q(-0.00000254),
  DSP16_Q(-0.00000083),
  DSP16_Q(0.00011295),
  DSP16_Q(-0.00054249),
  DSP16_Q(0.00148387),
  DSP16_Q(-0.00307067),
  DSP16_Q(0.00533032),
  DSP16_Q(-0.00814876),
  DSP16_Q(0.01124856),
  DSP16_Q(-0.01417783),
  DSP16_Q(0.01629371),
  DSP16_Q(-0.01669147),
  DSP16_Q(0.01391189),
  DSP16_Q(-0.00466561),
  DSP16_Q(-0.02440705),
  DSP16_Q(0.43003245),
  DSP16_Q(0.11580144),
  DSP16_Q(-0.06541860),
  DSP16_Q(0.04619529),
  DSP16_Q(-0.03367637),
  DSP16_Q(0.02399872),
  DSP16_Q(-0.01622402),
  DSP16_Q(0.01010930),
  DSP16_Q(-0.00556086),
  DSP16_Q(0.00245880),
  DSP16_Q(-0.00060532),
  DSP16_Q(-0.00027132),
  DSP16_Q(0.00048468),
  DSP16_Q(-0.00034643),
  DSP16_Q(0.00012305),
  DSP16_Q(-0.00000230),
  DSP16_Q(0.00000085),
  DSP16_Q(0.00010558),
  DSP16_Q(-0.00052653),
  DSP16_Q(0.00145963),
  DSP16_Q(-0.00304377),
  DSP16_Q(0.00531337),
  DSP16_Q(-0.00816260),
  DSP16_Q(0.01132287),
  DSP16_Q(-0.01435159),
  DSP16_Q(0.01661661),
  DSP16_Q(-0.01722889),
  DSP16_Q(0.01476163),
  DSP16_Q(-0.00601652),
  DSP16_Q(-0.02199676),
  DSP16_Q(0.43127506),
  DSP16_Q(0.11214835),
  DSP16_Q(-0.06423730),
  DSP16_Q(0.04571230),
  DSP16_Q(-0.03351850),
  DSP16_Q(0.02401120),
  DSP16_Q(-0.01632115),
  DSP16_Q(0.01023776),
  DSP16_Q(-0.00568745),
  DSP16_Q(0.00256486),
  DSP16_Q(-0.00068321),
  DSP16_Q(-0.00022131),
  DSP16_Q(0.00045738),
  DSP16_Q(-0.00033454),
  DSP16_Q(0.00011952),
  DSP16_Q(-0.00000208),
  DSP16_Q(0.00000258),
  DSP16_Q(0.00009804),
  DSP16_Q(-0.00051017),
  DSP16_Q(0.00143461),
  DSP16_Q(-0.00301546),
  DSP16_Q(0.00529422),
  DSP16_Q(-0.00817329),
  DSP16_Q(0.01139307),
  DSP16_Q(-0.01452049),
  DSP16_Q(0.01693441),
  DSP16_Q(-0.01776207),
  DSP16_Q(0.01561013),
  DSP16_Q(-0.00737456),
  DSP16_Q(-0.01954824),
  DSP16_Q(0.43246320),
  DSP16_Q(0.10851070),
  DSP16_Q(-0.06304043),
  DSP16_Q(0.04521430),
  DSP16_Q(-0.03334836),
  DSP16_Q(0.02401429),
  DSP16_Q(-0.01641150),
  DSP16_Q(0.01036166),
  DSP16_Q(-0.00581120),
  DSP16_Q(0.00266935),
  DSP16_Q(-0.00076037),
  DSP16_Q(-0.00017158),
  DSP16_Q(0.00043015),
  DSP16_Q(-0.00032265),
  DSP16_Q(0.00011601),
  DSP16_Q(-0.00000187),
  DSP16_Q(0.00000437),
  DSP16_Q(0.00009034),
  DSP16_Q(-0.00049343),
  DSP16_Q(0.00140879),
  DSP16_Q(-0.00298577),
  DSP16_Q(0.00527287),
  DSP16_Q(-0.00818082),
  DSP16_Q(0.01145912),
  DSP16_Q(-0.01468444),
  DSP16_Q(0.01724699),
  DSP16_Q(-0.01829078),
  DSP16_Q(0.01645705),
  DSP16_Q(-0.00873928),
  DSP16_Q(-0.01706183),
  DSP16_Q(0.43359659),
  DSP16_Q(0.10488921),
  DSP16_Q(-0.06182854),
  DSP16_Q(0.04470156),
  DSP16_Q(-0.03316608),
  DSP16_Q(0.02400802),
  DSP16_Q(-0.01649506),
  DSP16_Q(0.01048095),
  DSP16_Q(-0.00593208),
  DSP16_Q(0.00277223),
  DSP16_Q(-0.00083674),
  DSP16_Q(-0.00012215),
  DSP16_Q(0.00040299),
  DSP16_Q(-0.00031078),
  DSP16_Q(0.00011251),
  DSP16_Q(-0.00000167),
  DSP16_Q(0.00000621),
  DSP16_Q(0.00008247),
  DSP16_Q(-0.00047630),
  DSP16_Q(0.00138220),
  DSP16_Q(-0.00295469),
  DSP16_Q(0.00524930),
  DSP16_Q(-0.00818515),
  DSP16_Q(0.01152098),
  DSP16_Q(-0.01484336),
  DSP16_Q(0.01755418),
  DSP16_Q(-0.01881479),
  DSP16_Q(0.01730206),
  DSP16_Q(-0.01011021),
  DSP16_Q(-0.01453784),
  DSP16_Q(0.43467497),
  DSP16_Q(0.10128456),
  DSP16_Q(-0.06060219),
  DSP16_Q(0.04417437),
  DSP16_Q(-0.03297178),
  DSP16_Q(0.02399245),
  DSP16_Q(-0.01657184),
  DSP16_Q(0.01059562),
  DSP16_Q(-0.00605005),
  DSP16_Q(0.00287346),
  DSP16_Q(-0.00091231),
  DSP16_Q(-0.00007304),
  DSP16_Q(0.00037593),
  DSP16_Q(-0.00029894),
  DSP16_Q(0.00010904),
  DSP16_Q(-0.00000148),
  DSP16_Q(0.00000811),
  DSP16_Q(0.00007445),
  DSP16_Q(-0.00045879),
  DSP16_Q(0.00135483),
  DSP16_Q(-0.00292222),
  DSP16_Q(0.00522352),
  DSP16_Q(-0.00818629),
  DSP16_Q(0.01157859),
  DSP16_Q(-0.01499717),
  DSP16_Q(0.01785586),
  DSP16_Q(-0.01933388),
  DSP16_Q(0.01814484),
  DSP16_Q(-0.01148689),
  DSP16_Q(-0.01197662),
  DSP16_Q(0.43569808),
  DSP16_Q(0.09769747),
  DSP16_Q(-0.05936193),
  DSP16_Q(0.04363299),
  DSP16_Q(-0.03276560),
  DSP16_Q(0.02396762),
  DSP16_Q(-0.01664183),
  DSP16_Q(0.01070563),
  DSP16_Q(-0.00616509),
  DSP16_Q(0.00297303),
  DSP16_Q(-0.00098706),
  DSP16_Q(-0.00002426),
  DSP16_Q(0.00034896),
  DSP16_Q(-0.00028712),
  DSP16_Q(0.00010558),
  DSP16_Q(-0.00000130),
  DSP16_Q(0.00001006),
  DSP16_Q(0.00006626),
  DSP16_Q(-0.00044091),
  DSP16_Q(0.00132670),
  DSP16_Q(-0.00288837),
  DSP16_Q(0.00519552),
  DSP16_Q(-0.00818420),
  DSP16_Q(0.01163192),
  DSP16_Q(-0.01514577),
  DSP16_Q(0.01815188),
  DSP16_Q(-0.01984782),
  DSP16_Q(0.01898504),
  DSP16_Q(-0.01286885),
  DSP16_Q(-0.00937851),
  DSP16_Q(0.43666569),
  DSP16_Q(0.09412862),
  DSP16_Q(-0.05810833),
  DSP16_Q(0.04307773),
  DSP16_Q(-0.03254766),
  DSP16_Q(0.02393358),
  DSP16_Q(-0.01670504),
  DSP16_Q(0.01081098),
  DSP16_Q(-0.00627716),
  DSP16_Q(0.00307089),
  DSP16_Q(-0.00106095),
  DSP16_Q(0.00002417),
  DSP16_Q(0.00032211),
  DSP16_Q(-0.00027533),
  DSP16_Q(0.00010214),
  DSP16_Q(-0.00000114),
  DSP16_Q(0.00001207),
  DSP16_Q(0.00005792),
  DSP16_Q(-0.00042266),
  DSP16_Q(0.00129780),
  DSP16_Q(-0.00285314),
  DSP16_Q(0.00516531),
  DSP16_Q(-0.00817887),
  DSP16_Q(0.01168092),
  DSP16_Q(-0.01528909),
  DSP16_Q(0.01844210),
  DSP16_Q(-0.02035640),
  DSP16_Q(0.01982232),
  DSP16_Q(-0.01425561),
  DSP16_Q(-0.00674388),
  DSP16_Q(0.43757756),
  DSP16_Q(0.09057868),
  DSP16_Q(-0.05684193),
  DSP16_Q(0.04250885),
  DSP16_Q(-0.03231811),
  DSP16_Q(0.02389038),
  DSP16_Q(-0.01676146),
  DSP16_Q(0.01091163),
  DSP16_Q(-0.00638623),
  DSP16_Q(0.00316702),
  DSP16_Q(-0.00113397),
  DSP16_Q(0.00007223),
  DSP16_Q(0.00029538),
  DSP16_Q(-0.00026357),
  DSP16_Q(0.00009873),
  DSP16_Q(-0.00000099),
  DSP16_Q(0.00001414),
  DSP16_Q(0.00004942),
  DSP16_Q(-0.00040403),
  DSP16_Q(0.00126814),
  DSP16_Q(-0.00281655),
  DSP16_Q(0.00513289),
  DSP16_Q(-0.00817029),
  DSP16_Q(0.01172557),
  DSP16_Q(-0.01542705),
  DSP16_Q(0.01872638),
  DSP16_Q(-0.02085939),
  DSP16_Q(0.02065637),
  DSP16_Q(-0.01564669),
  DSP16_Q(-0.00407310),
  DSP16_Q(0.43843349),
  DSP16_Q(0.08704833),
  DSP16_Q(-0.05556332),
  DSP16_Q(0.04192666),
  DSP16_Q(-0.03207710),
  DSP16_Q(0.02383807),
  DSP16_Q(-0.01681111),
  DSP16_Q(0.01100757),
  DSP16_Q(-0.00649227),
  DSP16_Q(0.00326139),
  DSP16_Q(-0.00120609),
  DSP16_Q(0.00011990),
  DSP16_Q(0.00026878),
  DSP16_Q(-0.00025186),
  DSP16_Q(0.00009534),
  DSP16_Q(-0.00000085),
  DSP16_Q(0.00001625),
  DSP16_Q(0.00004077),
  DSP16_Q(-0.00038505),
  DSP16_Q(0.00123773),
  DSP16_Q(-0.00277858),
  DSP16_Q(0.00509824),
  DSP16_Q(-0.00815846),
  DSP16_Q(0.01176581),
  DSP16_Q(-0.01555957),
  DSP16_Q(0.01900458),
  DSP16_Q(-0.02135658),
  DSP16_Q(0.02148683),
  DSP16_Q(-0.01704161),
  DSP16_Q(-0.00136656),
  DSP16_Q(0.43923326),
  DSP16_Q(0.08353825),
  DSP16_Q(-0.05427303),
  DSP16_Q(0.04133146),
  DSP16_Q(-0.03182476),
  DSP16_Q(0.02377673),
  DSP16_Q(-0.01685400),
  DSP16_Q(0.01109878),
  DSP16_Q(-0.00659526),
  DSP16_Q(0.00335397),
  DSP16_Q(-0.00127728),
  DSP16_Q(0.00016717),
  DSP16_Q(0.00024233),
  DSP16_Q(-0.00024020),
  DSP16_Q(0.00009198),
  DSP16_Q(-0.00000072),
  DSP16_Q(0.00001843),
  DSP16_Q(0.00003197),
  DSP16_Q(-0.00036570),
  DSP16_Q(0.00120658),
  DSP16_Q(-0.00273927),
  DSP16_Q(0.00506139),
  DSP16_Q(-0.00814334),
  DSP16_Q(0.01180162),
  DSP16_Q(-0.01568658),
  DSP16_Q(0.01927657),
  DSP16_Q(-0.02184773),
  DSP16_Q(0.02231337),
  DSP16_Q(-0.01843987),
  DSP16_Q(0.00137535),
  DSP16_Q(0.43997670),
  DSP16_Q(0.08004908),
  DSP16_Q(-0.05297163),
  DSP16_Q(0.04072353),
  DSP16_Q(-0.03156126),
  DSP16_Q(0.02370641),
  DSP16_Q(-0.01689014),
  DSP16_Q(0.01118526),
  DSP16_Q(-0.00669517),
  DSP16_Q(0.00344473),
  DSP16_Q(-0.00134752),
  DSP16_Q(0.00021401),
  DSP16_Q(0.00021603),
  DSP16_Q(-0.00022859),
  DSP16_Q(0.00008865),
  DSP16_Q(-0.00000061),
  DSP16_Q(0.00002065),
  DSP16_Q(0.00002301),
  DSP16_Q(-0.00034601),
  DSP16_Q(0.00117469),
  DSP16_Q(-0.00269860),
  DSP16_Q(0.00502232),
  DSP16_Q(-0.00812495),
  DSP16_Q(0.01183296),
  DSP16_Q(-0.01580801),
  DSP16_Q(0.01954222),
  DSP16_Q(-0.02233264),
  DSP16_Q(0.02313565),
  DSP16_Q(-0.01984098),
  DSP16_Q(0.00415223),
  DSP16_Q(0.44066362),
  DSP16_Q(0.07658148),
  DSP16_Q(-0.05165969),
  DSP16_Q(0.04010318),
  DSP16_Q(-0.03128673),
  DSP16_Q(0.02362717),
  DSP16_Q(-0.01691954),
  DSP16_Q(0.01126697),
  DSP16_Q(-0.00679198),
  DSP16_Q(0.00353364),
  DSP16_Q(-0.00141679),
  DSP16_Q(0.00026042),
  DSP16_Q(0.00018989),
  DSP16_Q(-0.00021703),
  DSP16_Q(0.00008535),
  DSP16_Q(-0.00000050),
  DSP16_Q(0.00002294),
  DSP16_Q(0.00001392),
  DSP16_Q(-0.00032596),
  DSP16_Q(0.00114207),
  DSP16_Q(-0.00265659),
  DSP16_Q(0.00498105),
  DSP16_Q(-0.00810326),
  DSP16_Q(0.01185980),
  DSP16_Q(-0.01592377),
  DSP16_Q(0.01980139),
  DSP16_Q(-0.02281109),
  DSP16_Q(0.02395334),
  DSP16_Q(-0.02124444),
  DSP16_Q(0.00696365),
  DSP16_Q(0.44129387),
  DSP16_Q(0.07313609),
  DSP16_Q(-0.05033775),
  DSP16_Q(0.03947071),
  DSP16_Q(-0.03100134),
  DSP16_Q(0.02353909),
  DSP16_Q(-0.01694222),
  DSP16_Q(0.01134392),
  DSP16_Q(-0.00688565),
  DSP16_Q(0.00362069),
  DSP16_Q(-0.00148507),
  DSP16_Q(0.00030638),
  DSP16_Q(0.00016392),
  DSP16_Q(-0.00020554),
  DSP16_Q(0.00008208),
  DSP16_Q(-0.00000041),
  DSP16_Q(0.00002527),
  DSP16_Q(0.00000467),
  DSP16_Q(-0.00030557),
  DSP16_Q(0.00110874),
  DSP16_Q(-0.00261325),
  DSP16_Q(0.00493757),
  DSP16_Q(-0.00807827),
  DSP16_Q(0.01188210),
  DSP16_Q(-0.01603381),
  DSP16_Q(0.02005396),
  DSP16_Q(-0.02328285),
  DSP16_Q(0.02476610),
  DSP16_Q(-0.02264975),
  DSP16_Q(0.00980919),
  DSP16_Q(0.44186730),
  DSP16_Q(0.06971355),
  DSP16_Q(-0.04900638),
  DSP16_Q(0.03882643),
  DSP16_Q(-0.03070526),
  DSP16_Q(0.02344225),
  DSP16_Q(-0.01695820),
  DSP16_Q(0.01141609),
  DSP16_Q(-0.00697618),
  DSP16_Q(0.00370584),
  DSP16_Q(-0.00155234),
  DSP16_Q(0.00035187),
  DSP16_Q(0.00013814),
  DSP16_Q(-0.00019412),
  DSP16_Q(0.00007884),
  DSP16_Q(-0.00000033),
  DSP16_Q(0.00002766),
  DSP16_Q(-0.00000471),
  DSP16_Q(-0.00028485),
  DSP16_Q(0.00107469),
  DSP16_Q(-0.00256858),
  DSP16_Q(0.00489190),
  DSP16_Q(-0.00804998),
  DSP16_Q(0.01189985),
  DSP16_Q(-0.01613805),
  DSP16_Q(0.02029980),
  DSP16_Q(-0.02374773),
  DSP16_Q(0.02557359),
  DSP16_Q(-0.02405641),
  DSP16_Q(0.01268842),
  DSP16_Q(0.44238378),
  DSP16_Q(0.06631449),
  DSP16_Q(-0.04766613),
  DSP16_Q(0.03817066),
  DSP16_Q(-0.03039864),
  DSP16_Q(0.02333671),
  DSP16_Q(-0.01696751),
  DSP16_Q(0.01148348),
  DSP16_Q(-0.00706353),
  DSP16_Q(0.00378908),
  DSP16_Q(-0.00161857),
  DSP16_Q(0.00039688),
  DSP16_Q(0.00011254),
  DSP16_Q(-0.00018276),
  DSP16_Q(0.00007564),
  DSP16_Q(-0.00000025),
  DSP16_Q(0.00003010),
  DSP16_Q(-0.00001423),
  DSP16_Q(-0.00026379),
  DSP16_Q(0.00103993),
  DSP16_Q(-0.00252260),
  DSP16_Q(0.00484404),
  DSP16_Q(-0.00801837),
  DSP16_Q(0.01191300),
  DSP16_Q(-0.01623643),
  DSP16_Q(0.02053878),
  DSP16_Q(-0.02420550),
  DSP16_Q(0.02637547),
  DSP16_Q(-0.02546389),
  DSP16_Q(0.01560087),
  DSP16_Q(0.44284317),
  DSP16_Q(0.06293952),
  DSP16_Q(-0.04631756),
  DSP16_Q(0.03750369),
  DSP16_Q(-0.03008165),
  DSP16_Q(0.02322255),
  DSP16_Q(-0.01697016),
  DSP16_Q(0.01154609),
  DSP16_Q(-0.00714770),
  DSP16_Q(0.00387037),
  DSP16_Q(-0.00168375),
  DSP16_Q(0.00044139),
  DSP16_Q(0.00008715),
  DSP16_Q(-0.00017148),
  DSP16_Q(0.00007247),
  DSP16_Q(-0.00000019),
  DSP16_Q(0.00003259),
  DSP16_Q(-0.00002389),
  DSP16_Q(-0.00024241),
  DSP16_Q(0.00100449),
  DSP16_Q(-0.00247532),
  DSP16_Q(0.00479399),
  DSP16_Q(-0.00798345),
  DSP16_Q(0.01192154),
  DSP16_Q(-0.01632888),
  DSP16_Q(0.02077078),
  DSP16_Q(-0.02465596),
  DSP16_Q(0.02717141),
  DSP16_Q(-0.02687168),
  DSP16_Q(0.01854610),
  DSP16_Q(0.44324537),
  DSP16_Q(0.05958926),
  DSP16_Q(-0.04496122),
  DSP16_Q(0.03682585),
  DSP16_Q(-0.02975447),
  DSP16_Q(0.02309986),
  DSP16_Q(-0.01696620),
  DSP16_Q(0.01160390),
  DSP16_Q(-0.00722865),
  DSP16_Q(0.00394970),
  DSP16_Q(-0.00174785),
  DSP16_Q(0.00048538),
  DSP16_Q(0.00006197),
  DSP16_Q(-0.00016029),
  DSP16_Q(0.00006934),
  DSP16_Q(-0.00000014),
  DSP16_Q(0.00003513),
  DSP16_Q(-0.00003368),
  DSP16_Q(-0.00022071),
  DSP16_Q(0.00096836),
  DSP16_Q(-0.00242674),
  DSP16_Q(0.00474177),
  DSP16_Q(-0.00794522),
  DSP16_Q(0.01192543),
  DSP16_Q(-0.01641534),
  DSP16_Q(0.02099568),
  DSP16_Q(-0.02509890),
  DSP16_Q(0.02796107),
  DSP16_Q(-0.02827927),
  DSP16_Q(0.02152364),
  DSP16_Q(0.44359030),
  DSP16_Q(0.05626431),
  DSP16_Q(-0.04359768),
  DSP16_Q(0.03613746),
  DSP16_Q(-0.02941726),
  DSP16_Q(0.02296873),
  DSP16_Q(-0.01695564),
  DSP16_Q(0.01165693),
  DSP16_Q(-0.00730639),
  DSP16_Q(0.00402705),
  DSP16_Q(-0.00181085),
  DSP16_Q(0.00052885),
  DSP16_Q(0.00003701),
  DSP16_Q(-0.00014917),
  DSP16_Q(0.00006625),
  DSP16_Q(-0.00000009),
  DSP16_Q(0.00003772),
  DSP16_Q(-0.00004360),
  DSP16_Q(-0.00019870),
  DSP16_Q(0.00093155),
  DSP16_Q(-0.00237688),
  DSP16_Q(0.00468738),
  DSP16_Q(-0.00790366),
  DSP16_Q(0.01192467),
  DSP16_Q(-0.01649576),
  DSP16_Q(0.02121336),
  DSP16_Q(-0.02553410),
  DSP16_Q(0.02874411),
  DSP16_Q(-0.02968613),
  DSP16_Q(0.02453300),
  DSP16_Q(0.44387786),
  DSP16_Q(0.05296527),
  DSP16_Q(-0.04222747),
  DSP16_Q(0.03543883),
  DSP16_Q(-0.02907020),
  DSP16_Q(0.02282923),
  DSP16_Q(-0.01693852),
  DSP16_Q(0.01170516),
  DSP16_Q(-0.00738088),
  DSP16_Q(0.00410239),
  DSP16_Q(-0.00187275),
  DSP16_Q(0.00057177),
  DSP16_Q(0.00001228),
  DSP16_Q(-0.00013815),
  DSP16_Q(0.00006320),
  DSP16_Q(-0.00000006),
  DSP16_Q(0.00004037),
  DSP16_Q(-0.00005364),
  DSP16_Q(-0.00017639),
  DSP16_Q(0.00089408),
  DSP16_Q(-0.00232576),
  DSP16_Q(0.00463084),
  DSP16_Q(-0.00785879),
  DSP16_Q(0.01191922),
  DSP16_Q(-0.01657007),
  DSP16_Q(0.02142370),
  DSP16_Q(-0.02596138),
  DSP16_Q(0.02952020),
  DSP16_Q(-0.03109174),
  DSP16_Q(0.02757369),
  DSP16_Q(0.44410799),
  DSP16_Q(0.04969271),
  DSP16_Q(-0.04085115),
  DSP16_Q(0.03473029),
  DSP16_Q(-0.02871348),
  DSP16_Q(0.02268146),
  DSP16_Q(-0.01691487),
  DSP16_Q(0.01174860),
  DSP16_Q(-0.00745211),
  DSP16_Q(0.00417571),
  DSP16_Q(-0.00193351),
  DSP16_Q(0.00061414),
  DSP16_Q(-0.00001222),
  DSP16_Q(-0.00012722),
  DSP16_Q(0.00006019),
  DSP16_Q(-0.00000003),
  DSP16_Q(0.00004306),
  DSP16_Q(-0.00006381),
  DSP16_Q(-0.00015377),
  DSP16_Q(0.00085596),
  DSP16_Q(-0.00227337),
  DSP16_Q(0.00457215),
  DSP16_Q(-0.00781060),
  DSP16_Q(0.01190907),
  DSP16_Q(-0.01663821),
  DSP16_Q(0.02162660),
  DSP16_Q(-0.02638052),
  DSP16_Q(0.03028901),
  DSP16_Q(-0.03249557),
  DSP16_Q(0.03064522),
  DSP16_Q(0.44428063),
  DSP16_Q(0.04644721),
  DSP16_Q(-0.03946928),
  DSP16_Q(0.03401215),
  DSP16_Q(-0.02834727),
  DSP16_Q(0.02252552),
  DSP16_Q(-0.01688473),
  DSP16_Q(0.01178726),
  DSP16_Q(-0.00752008),
  DSP16_Q(0.00424698),
  DSP16_Q(-0.00199312),
  DSP16_Q(0.00065594),
  DSP16_Q(-0.00003647),
  DSP16_Q(-0.00011638),
  DSP16_Q(0.00005722),
  DSP16_Q(-0.00000001),
  DSP16_Q(0.00004580),
  DSP16_Q(-0.00007410),
  DSP16_Q(-0.00013086),
  DSP16_Q(0.00081720),
  DSP16_Q(-0.00221975),
  DSP16_Q(0.00451133),
  DSP16_Q(-0.00775910),
  DSP16_Q(0.01189420),
  DSP16_Q(-0.01670015),
  DSP16_Q(0.02182193),
  DSP16_Q(-0.02679132),
  DSP16_Q(0.03105020),
  DSP16_Q(-0.03389709),
  DSP16_Q(0.03374708),
  DSP16_Q(0.44439575),
  DSP16_Q(0.04322935),
  DSP16_Q(-0.03808239),
  DSP16_Q(0.03328474),
  DSP16_Q(-0.02797176),
  DSP16_Q(0.02236149),
  DSP16_Q(-0.01684815),
  DSP16_Q(0.01182114),
  DSP16_Q(-0.00758478),
  DSP16_Q(0.00431620),
  DSP16_Q(-0.00205157),
  DSP16_Q(0.00069716),
  DSP16_Q(-0.00006047),
  DSP16_Q(-0.00010565),
  DSP16_Q(0.00005430),
  DSP16_Q(-0.00000000),
  DSP16_Q(0.00004858),
  DSP16_Q(-0.00008451),
  DSP16_Q(-0.00010767),
  DSP16_Q(0.00077780),
  DSP16_Q(-0.00216490),
  DSP16_Q(0.00444839),
  DSP16_Q(-0.00770430),
  DSP16_Q(0.01187460),
  DSP16_Q(-0.01675581),
  DSP16_Q(0.02200960),
  DSP16_Q(-0.02719359),
  DSP16_Q(0.03180344),
  DSP16_Q(-0.03529575),
  DSP16_Q(0.03687874),
  DSP16_Q(0.44445332),
  DSP16_Q(0.04003968),
  DSP16_Q(-0.03669104),
  DSP16_Q(0.03254840),
  DSP16_Q(-0.02758714),
  DSP16_Q(0.02218949),
  DSP16_Q(-0.01680516),
  DSP16_Q(0.01185025),
  DSP16_Q(-0.00764618),
  DSP16_Q(0.00438334),
  DSP16_Q(-0.00210883),
  DSP16_Q(0.00073778),
  DSP16_Q(-0.00008421),
  DSP16_Q(-0.00009503),
  DSP16_Q(0.00005142),
  DSP16_Q(-0.00000000)
};
