/*****************************************************************************
 *
 * \file
 *
 * \brief FIR coefficients for the dsp16_resampling function from the DPSLib.
 *        These coefficients have the following caracterizations:
 *          - Input sampling frequency: 44100 Hz
 *          - Output sampling frequency: 48000 Hz
 *          - Re-sampling order: 6
 *          - Coefficients are normalized
 *          - Memory foot print: 1920 bytes
 *         It matches the following parameters:
 *         (dsp16_resampling_options_t::dsp16_custom_filter)
 *          - Cut-off frequency (fc_hz): 22050
 *          - Sampling frequency (fs_hz): 7056000
 *          - Actual FIR filter order (order): 960
 *
 * Copyright (c) 2010 Atmel Corporation. All rights reserved.
 *
 * \asf_license_start
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 *    Atmel microcontroller product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * \asf_license_stop
 *
 ******************************************************************************/

A_ALIGNED static const dsp16_t dsp16_resampling_fircoef_ord6_44100_48000_norm[] = {
  DSP16_Q(0.00000000),
  DSP16_Q(-0.00027672),
  DSP16_Q(0.00166185),
  DSP16_Q(0.70595041),
  DSP16_Q(-0.00164526),
  DSP16_Q(0.00027273),
  DSP16_Q(0.00000002),
  DSP16_Q(-0.00084210),
  DSP16_Q(0.00503526),
  DSP16_Q(0.70584454),
  DSP16_Q(-0.00488590),
  DSP16_Q(0.00080625),
  DSP16_Q(0.00000016),
  DSP16_Q(-0.00142343),
  DSP16_Q(0.00847477),
  DSP16_Q(0.70563283),
  DSP16_Q(-0.00805992),
  DSP16_Q(0.00132386),
  DSP16_Q(0.00000050),
  DSP16_Q(-0.00202068),
  DSP16_Q(0.01198016),
  DSP16_Q(0.70531536),
  DSP16_Q(-0.01116720),
  DSP16_Q(0.00182559),
  DSP16_Q(0.00000115),
  DSP16_Q(-0.00263382),
  DSP16_Q(0.01555118),
  DSP16_Q(0.70489222),
  DSP16_Q(-0.01420766),
  DSP16_Q(0.00231148),
  DSP16_Q(0.00000219),
  DSP16_Q(-0.00326284),
  DSP16_Q(0.01918754),
  DSP16_Q(0.70436354),
  DSP16_Q(-0.01718120),
  DSP16_Q(0.00278158),
  DSP16_Q(0.00000373),
  DSP16_Q(-0.00390767),
  DSP16_Q(0.02288896),
  DSP16_Q(0.70372949),
  DSP16_Q(-0.02008781),
  DSP16_Q(0.00323595),
  DSP16_Q(0.00000587),
  DSP16_Q(-0.00456826),
  DSP16_Q(0.02665509),
  DSP16_Q(0.70299027),
  DSP16_Q(-0.02292744),
  DSP16_Q(0.00367465),
  DSP16_Q(0.00000870),
  DSP16_Q(-0.00524454),
  DSP16_Q(0.03048560),
  DSP16_Q(0.70214612),
  DSP16_Q(-0.02570011),
  DSP16_Q(0.00409778),
  DSP16_Q(0.00001232),
  DSP16_Q(-0.00593643),
  DSP16_Q(0.03438009),
  DSP16_Q(0.70119729),
  DSP16_Q(-0.02840585),
  DSP16_Q(0.00450540),
  DSP16_Q(0.00001682),
  DSP16_Q(-0.00664384),
  DSP16_Q(0.03833815),
  DSP16_Q(0.70014408),
  DSP16_Q(-0.03104470),
  DSP16_Q(0.00489763),
  DSP16_Q(0.00002230),
  DSP16_Q(-0.00736666),
  DSP16_Q(0.04235937),
  DSP16_Q(0.69898684),
  DSP16_Q(-0.03361676),
  DSP16_Q(0.00527456),
  DSP16_Q(0.00002886),
  DSP16_Q(-0.00810477),
  DSP16_Q(0.04644326),
  DSP16_Q(0.69772591),
  DSP16_Q(-0.03612211),
  DSP16_Q(0.00563631),
  DSP16_Q(0.00003660),
  DSP16_Q(-0.00885805),
  DSP16_Q(0.05058935),
  DSP16_Q(0.69636170),
  DSP16_Q(-0.03856089),
  DSP16_Q(0.00598300),
  DSP16_Q(0.00004560),
  DSP16_Q(-0.00962635),
  DSP16_Q(0.05479713),
  DSP16_Q(0.69489463),
  DSP16_Q(-0.04093324),
  DSP16_Q(0.00631476),
  DSP16_Q(0.00005596),
  DSP16_Q(-0.01040951),
  DSP16_Q(0.05906605),
  DSP16_Q(0.69332517),
  DSP16_Q(-0.04323934),
  DSP16_Q(0.00663173),
  DSP16_Q(0.00006778),
  DSP16_Q(-0.01120737),
  DSP16_Q(0.06339555),
  DSP16_Q(0.69165380),
  DSP16_Q(-0.04547938),
  DSP16_Q(0.00693406),
  DSP16_Q(0.00008114),
  DSP16_Q(-0.01201975),
  DSP16_Q(0.06778504),
  DSP16_Q(0.68988106),
  DSP16_Q(-0.04765357),
  DSP16_Q(0.00722189),
  DSP16_Q(0.00009614),
  DSP16_Q(-0.01284645),
  DSP16_Q(0.07223389),
  DSP16_Q(0.68800748),
  DSP16_Q(-0.04976217),
  DSP16_Q(0.00749539),
  DSP16_Q(0.00011286),
  DSP16_Q(-0.01368727),
  DSP16_Q(0.07674147),
  DSP16_Q(0.68603367),
  DSP16_Q(-0.05180543),
  DSP16_Q(0.00775472),
  DSP16_Q(0.00013139),
  DSP16_Q(-0.01454199),
  DSP16_Q(0.08130711),
  DSP16_Q(0.68396024),
  DSP16_Q(-0.05378363),
  DSP16_Q(0.00800006),
  DSP16_Q(0.00015182),
  DSP16_Q(-0.01541037),
  DSP16_Q(0.08593010),
  DSP16_Q(0.68178784),
  DSP16_Q(-0.05569708),
  DSP16_Q(0.00823159),
  DSP16_Q(0.00017422),
  DSP16_Q(-0.01629218),
  DSP16_Q(0.09060973),
  DSP16_Q(0.67951714),
  DSP16_Q(-0.05754611),
  DSP16_Q(0.00844949),
  DSP16_Q(0.00019869),
  DSP16_Q(-0.01718714),
  DSP16_Q(0.09534524),
  DSP16_Q(0.67714886),
  DSP16_Q(-0.05933106),
  DSP16_Q(0.00865396),
  DSP16_Q(0.00022530),
  DSP16_Q(-0.01809499),
  DSP16_Q(0.10013587),
  DSP16_Q(0.67468372),
  DSP16_Q(-0.06105230),
  DSP16_Q(0.00884519),
  DSP16_Q(0.00025413),
  DSP16_Q(-0.01901545),
  DSP16_Q(0.10498081),
  DSP16_Q(0.67212251),
  DSP16_Q(-0.06271022),
  DSP16_Q(0.00902339),
  DSP16_Q(0.00028525),
  DSP16_Q(-0.01994821),
  DSP16_Q(0.10987925),
  DSP16_Q(0.66946602),
  DSP16_Q(-0.06430524),
  DSP16_Q(0.00918877),
  DSP16_Q(0.00031874),
  DSP16_Q(-0.02089296),
  DSP16_Q(0.11483032),
  DSP16_Q(0.66671508),
  DSP16_Q(-0.06583776),
  DSP16_Q(0.00934153),
  DSP16_Q(0.00035467),
  DSP16_Q(-0.02184937),
  DSP16_Q(0.11983317),
  DSP16_Q(0.66387053),
  DSP16_Q(-0.06730825),
  DSP16_Q(0.00948191),
  DSP16_Q(0.00039310),
  DSP16_Q(-0.02281711),
  DSP16_Q(0.12488688),
  DSP16_Q(0.66093327),
  DSP16_Q(-0.06871717),
  DSP16_Q(0.00961011),
  DSP16_Q(0.00043409),
  DSP16_Q(-0.02379582),
  DSP16_Q(0.12999054),
  DSP16_Q(0.65790420),
  DSP16_Q(-0.07006500),
  DSP16_Q(0.00972637),
  DSP16_Q(0.00047772),
  DSP16_Q(-0.02478514),
  DSP16_Q(0.13514319),
  DSP16_Q(0.65478427),
  DSP16_Q(-0.07135224),
  DSP16_Q(0.00983093),
  DSP16_Q(0.00052403),
  DSP16_Q(-0.02578468),
  DSP16_Q(0.14034387),
  DSP16_Q(0.65157443),
  DSP16_Q(-0.07257942),
  DSP16_Q(0.00992401),
  DSP16_Q(0.00057309),
  DSP16_Q(-0.02679406),
  DSP16_Q(0.14559158),
  DSP16_Q(0.64827569),
  DSP16_Q(-0.07374707),
  DSP16_Q(0.01000585),
  DSP16_Q(0.00062494),
  DSP16_Q(-0.02781286),
  DSP16_Q(0.15088530),
  DSP16_Q(0.64488905),
  DSP16_Q(-0.07485574),
  DSP16_Q(0.01007670),
  DSP16_Q(0.00067964),
  DSP16_Q(-0.02884067),
  DSP16_Q(0.15622398),
  DSP16_Q(0.64141558),
  DSP16_Q(-0.07590600),
  DSP16_Q(0.01013680),
  DSP16_Q(0.00073722),
  DSP16_Q(-0.02987706),
  DSP16_Q(0.16160657),
  DSP16_Q(0.63785633),
  DSP16_Q(-0.07689845),
  DSP16_Q(0.01018640),
  DSP16_Q(0.00079774),
  DSP16_Q(-0.03092157),
  DSP16_Q(0.16703198),
  DSP16_Q(0.63421240),
  DSP16_Q(-0.07783369),
  DSP16_Q(0.01022575),
  DSP16_Q(0.00086122),
  DSP16_Q(-0.03197374),
  DSP16_Q(0.17249909),
  DSP16_Q(0.63048491),
  DSP16_Q(-0.07871232),
  DSP16_Q(0.01025511),
  DSP16_Q(0.00092771),
  DSP16_Q(-0.03303311),
  DSP16_Q(0.17800677),
  DSP16_Q(0.62667500),
  DSP16_Q(-0.07953499),
  DSP16_Q(0.01027473),
  DSP16_Q(0.00099723),
  DSP16_Q(-0.03409918),
  DSP16_Q(0.18355387),
  DSP16_Q(0.62278385),
  DSP16_Q(-0.08030234),
  DSP16_Q(0.01028486),
  DSP16_Q(0.00106981),
  DSP16_Q(-0.03517146),
  DSP16_Q(0.18913920),
  DSP16_Q(0.61881264),
  DSP16_Q(-0.08101503),
  DSP16_Q(0.01028577),
  DSP16_Q(0.00114547),
  DSP16_Q(-0.03624944),
  DSP16_Q(0.19476158),
  DSP16_Q(0.61476259),
  DSP16_Q(-0.08167374),
  DSP16_Q(0.01027771),
  DSP16_Q(0.00122422),
  DSP16_Q(-0.03733259),
  DSP16_Q(0.20041979),
  DSP16_Q(0.61063493),
  DSP16_Q(-0.08227916),
  DSP16_Q(0.01026096),
  DSP16_Q(0.00130609),
  DSP16_Q(-0.03842036),
  DSP16_Q(0.20611258),
  DSP16_Q(0.60643093),
  DSP16_Q(-0.08283197),
  DSP16_Q(0.01023577),
  DSP16_Q(0.00139108),
  DSP16_Q(-0.03951222),
  DSP16_Q(0.21183871),
  DSP16_Q(0.60215185),
  DSP16_Q(-0.08333291),
  DSP16_Q(0.01020240),
  DSP16_Q(0.00147919),
  DSP16_Q(-0.04060759),
  DSP16_Q(0.21759688),
  DSP16_Q(0.59779900),
  DSP16_Q(-0.08378270),
  DSP16_Q(0.01016112),
  DSP16_Q(0.00157043),
  DSP16_Q(-0.04170591),
  DSP16_Q(0.22338581),
  DSP16_Q(0.59337370),
  DSP16_Q(-0.08418206),
  DSP16_Q(0.01011220),
  DSP16_Q(0.00166478),
  DSP16_Q(-0.04280658),
  DSP16_Q(0.22920418),
  DSP16_Q(0.58887729),
  DSP16_Q(-0.08453175),
  DSP16_Q(0.01005589),
  DSP16_Q(0.00176225),
  DSP16_Q(-0.04390901),
  DSP16_Q(0.23505065),
  DSP16_Q(0.58431113),
  DSP16_Q(-0.08483252),
  DSP16_Q(0.00999247),
  DSP16_Q(0.00186281),
  DSP16_Q(-0.04501257),
  DSP16_Q(0.24092387),
  DSP16_Q(0.57967658),
  DSP16_Q(-0.08508515),
  DSP16_Q(0.00992220),
  DSP16_Q(0.00196646),
  DSP16_Q(-0.04611666),
  DSP16_Q(0.24682247),
  DSP16_Q(0.57497506),
  DSP16_Q(-0.08529041),
  DSP16_Q(0.00984534),
  DSP16_Q(0.00207315),
  DSP16_Q(-0.04722063),
  DSP16_Q(0.25274507),
  DSP16_Q(0.57020796),
  DSP16_Q(-0.08544909),
  DSP16_Q(0.00976216),
  DSP16_Q(0.00218287),
  DSP16_Q(-0.04832383),
  DSP16_Q(0.25869026),
  DSP16_Q(0.56537673),
  DSP16_Q(-0.08556199),
  DSP16_Q(0.00967292),
  DSP16_Q(0.00229558),
  DSP16_Q(-0.04942562),
  DSP16_Q(0.26465661),
  DSP16_Q(0.56048280),
  DSP16_Q(-0.08562990),
  DSP16_Q(0.00957788),
  DSP16_Q(0.00241124),
  DSP16_Q(-0.05052531),
  DSP16_Q(0.27064271),
  DSP16_Q(0.55552764),
  DSP16_Q(-0.08565365),
  DSP16_Q(0.00947731),
  DSP16_Q(0.00252981),
  DSP16_Q(-0.05162223),
  DSP16_Q(0.27664709),
  DSP16_Q(0.55051271),
  DSP16_Q(-0.08563405),
  DSP16_Q(0.00937145),
  DSP16_Q(0.00265123),
  DSP16_Q(-0.05271569),
  DSP16_Q(0.28266829),
  DSP16_Q(0.54543953),
  DSP16_Q(-0.08557193),
  DSP16_Q(0.00926057),
  DSP16_Q(0.00277546),
  DSP16_Q(-0.05380498),
  DSP16_Q(0.28870482),
  DSP16_Q(0.54030957),
  DSP16_Q(-0.08546812),
  DSP16_Q(0.00914493),
  DSP16_Q(0.00290244),
  DSP16_Q(-0.05488940),
  DSP16_Q(0.29475521),
  DSP16_Q(0.53512438),
  DSP16_Q(-0.08532346),
  DSP16_Q(0.00902478),
  DSP16_Q(0.00303209),
  DSP16_Q(-0.05596823),
  DSP16_Q(0.30081793),
  DSP16_Q(0.52988547),
  DSP16_Q(-0.08513880),
  DSP16_Q(0.00890036),
  DSP16_Q(0.00316436),
  DSP16_Q(-0.05704072),
  DSP16_Q(0.30689147),
  DSP16_Q(0.52459439),
  DSP16_Q(-0.08491499),
  DSP16_Q(0.00877193),
  DSP16_Q(0.00329915),
  DSP16_Q(-0.05810615),
  DSP16_Q(0.31297430),
  DSP16_Q(0.51925270),
  DSP16_Q(-0.08465288),
  DSP16_Q(0.00863974),
  DSP16_Q(0.00343640),
  DSP16_Q(-0.05916376),
  DSP16_Q(0.31906487),
  DSP16_Q(0.51386195),
  DSP16_Q(-0.08435333),
  DSP16_Q(0.00850403),
  DSP16_Q(0.00357602),
  DSP16_Q(-0.06021279),
  DSP16_Q(0.32516164),
  DSP16_Q(0.50842373),
  DSP16_Q(-0.08401721),
  DSP16_Q(0.00836504),
  DSP16_Q(0.00371791),
  DSP16_Q(-0.06125247),
  DSP16_Q(0.33126303),
  DSP16_Q(0.50293962),
  DSP16_Q(-0.08364538),
  DSP16_Q(0.00822301),
  DSP16_Q(0.00386198),
  DSP16_Q(-0.06228203),
  DSP16_Q(0.33736747),
  DSP16_Q(0.49741122),
  DSP16_Q(-0.08323872),
  DSP16_Q(0.00807818),
  DSP16_Q(0.00400812),
  DSP16_Q(-0.06330069),
  DSP16_Q(0.34347337),
  DSP16_Q(0.49184012),
  DSP16_Q(-0.08279809),
  DSP16_Q(0.00793077),
  DSP16_Q(0.00415624),
  DSP16_Q(-0.06430764),
  DSP16_Q(0.34957915),
  DSP16_Q(0.48622794),
  DSP16_Q(-0.08232437),
  DSP16_Q(0.00778102),
  DSP16_Q(0.00430621),
  DSP16_Q(-0.06530210),
  DSP16_Q(0.35568320),
  DSP16_Q(0.48057630),
  DSP16_Q(-0.08181844),
  DSP16_Q(0.00762915),
  DSP16_Q(0.00445791),
  DSP16_Q(-0.06628325),
  DSP16_Q(0.36178391),
  DSP16_Q(0.47488682),
  DSP16_Q(-0.08128118),
  DSP16_Q(0.00747538),
  DSP16_Q(0.00461123),
  DSP16_Q(-0.06725028),
  DSP16_Q(0.36787967),
  DSP16_Q(0.46916113),
  DSP16_Q(-0.08071346),
  DSP16_Q(0.00731994),
  DSP16_Q(0.00476604),
  DSP16_Q(-0.06820237),
  DSP16_Q(0.37396885),
  DSP16_Q(0.46340086),
  DSP16_Q(-0.08011617),
  DSP16_Q(0.00716303),
  DSP16_Q(0.00492219),
  DSP16_Q(-0.06913870),
  DSP16_Q(0.38004983),
  DSP16_Q(0.45760766),
  DSP16_Q(-0.07949018),
  DSP16_Q(0.00700487),
  DSP16_Q(0.00507956),
  DSP16_Q(-0.07005842),
  DSP16_Q(0.38612097),
  DSP16_Q(0.45178317),
  DSP16_Q(-0.07883637),
  DSP16_Q(0.00684565),
  DSP16_Q(0.00523800),
  DSP16_Q(-0.07096069),
  DSP16_Q(0.39218062),
  DSP16_Q(0.44592904),
  DSP16_Q(-0.07815563),
  DSP16_Q(0.00668559),
  DSP16_Q(0.00539735),
  DSP16_Q(-0.07184469),
  DSP16_Q(0.39822716),
  DSP16_Q(0.44004692),
  DSP16_Q(-0.07744882),
  DSP16_Q(0.00652488),
  DSP16_Q(0.00555746),
  DSP16_Q(-0.07270955),
  DSP16_Q(0.40425893),
  DSP16_Q(0.43413845),
  DSP16_Q(-0.07671682),
  DSP16_Q(0.00636372),
  DSP16_Q(0.00571818),
  DSP16_Q(-0.07355442),
  DSP16_Q(0.41027428),
  DSP16_Q(0.42820530),
  DSP16_Q(-0.07596052),
  DSP16_Q(0.00620228),
  DSP16_Q(0.00587934),
  DSP16_Q(-0.07437845),
  DSP16_Q(0.41627156),
  DSP16_Q(0.42224912),
  DSP16_Q(-0.07518077),
  DSP16_Q(0.00604076),
  DSP16_Q(0.00604076),
  DSP16_Q(-0.07518077),
  DSP16_Q(0.42224912),
  DSP16_Q(0.41627156),
  DSP16_Q(-0.07437845),
  DSP16_Q(0.00587934),
  DSP16_Q(0.00620228),
  DSP16_Q(-0.07596052),
  DSP16_Q(0.42820530),
  DSP16_Q(0.41027428),
  DSP16_Q(-0.07355442),
  DSP16_Q(0.00571818),
  DSP16_Q(0.00636372),
  DSP16_Q(-0.07671682),
  DSP16_Q(0.43413845),
  DSP16_Q(0.40425893),
  DSP16_Q(-0.07270955),
  DSP16_Q(0.00555746),
  DSP16_Q(0.00652488),
  DSP16_Q(-0.07744882),
  DSP16_Q(0.44004692),
  DSP16_Q(0.39822716),
  DSP16_Q(-0.07184469),
  DSP16_Q(0.00539735),
  DSP16_Q(0.00668559),
  DSP16_Q(-0.07815563),
  DSP16_Q(0.44592904),
  DSP16_Q(0.39218062),
  DSP16_Q(-0.07096069),
  DSP16_Q(0.00523800),
  DSP16_Q(0.00684565),
  DSP16_Q(-0.07883637),
  DSP16_Q(0.45178317),
  DSP16_Q(0.38612097),
  DSP16_Q(-0.07005842),
  DSP16_Q(0.00507956),
  DSP16_Q(0.00700487),
  DSP16_Q(-0.07949018),
  DSP16_Q(0.45760766),
  DSP16_Q(0.38004983),
  DSP16_Q(-0.06913870),
  DSP16_Q(0.00492219),
  DSP16_Q(0.00716303),
  DSP16_Q(-0.08011617),
  DSP16_Q(0.46340086),
  DSP16_Q(0.37396885),
  DSP16_Q(-0.06820237),
  DSP16_Q(0.00476604),
  DSP16_Q(0.00731994),
  DSP16_Q(-0.08071346),
  DSP16_Q(0.46916113),
  DSP16_Q(0.36787967),
  DSP16_Q(-0.06725028),
  DSP16_Q(0.00461123),
  DSP16_Q(0.00747538),
  DSP16_Q(-0.08128118),
  DSP16_Q(0.47488682),
  DSP16_Q(0.36178391),
  DSP16_Q(-0.06628325),
  DSP16_Q(0.00445791),
  DSP16_Q(0.00762915),
  DSP16_Q(-0.08181844),
  DSP16_Q(0.48057630),
  DSP16_Q(0.35568320),
  DSP16_Q(-0.06530210),
  DSP16_Q(0.00430621),
  DSP16_Q(0.00778102),
  DSP16_Q(-0.08232437),
  DSP16_Q(0.48622794),
  DSP16_Q(0.34957915),
  DSP16_Q(-0.06430764),
  DSP16_Q(0.00415624),
  DSP16_Q(0.00793077),
  DSP16_Q(-0.08279809),
  DSP16_Q(0.49184012),
  DSP16_Q(0.34347337),
  DSP16_Q(-0.06330069),
  DSP16_Q(0.00400812),
  DSP16_Q(0.00807818),
  DSP16_Q(-0.08323872),
  DSP16_Q(0.49741122),
  DSP16_Q(0.33736747),
  DSP16_Q(-0.06228203),
  DSP16_Q(0.00386198),
  DSP16_Q(0.00822301),
  DSP16_Q(-0.08364538),
  DSP16_Q(0.50293962),
  DSP16_Q(0.33126303),
  DSP16_Q(-0.06125247),
  DSP16_Q(0.00371791),
  DSP16_Q(0.00836504),
  DSP16_Q(-0.08401721),
  DSP16_Q(0.50842373),
  DSP16_Q(0.32516164),
  DSP16_Q(-0.06021279),
  DSP16_Q(0.00357602),
  DSP16_Q(0.00850403),
  DSP16_Q(-0.08435333),
  DSP16_Q(0.51386195),
  DSP16_Q(0.31906487),
  DSP16_Q(-0.05916376),
  DSP16_Q(0.00343640),
  DSP16_Q(0.00863974),
  DSP16_Q(-0.08465288),
  DSP16_Q(0.51925270),
  DSP16_Q(0.31297430),
  DSP16_Q(-0.05810615),
  DSP16_Q(0.00329915),
  DSP16_Q(0.00877193),
  DSP16_Q(-0.08491499),
  DSP16_Q(0.52459439),
  DSP16_Q(0.30689147),
  DSP16_Q(-0.05704072),
  DSP16_Q(0.00316436),
  DSP16_Q(0.00890036),
  DSP16_Q(-0.08513880),
  DSP16_Q(0.52988547),
  DSP16_Q(0.30081793),
  DSP16_Q(-0.05596823),
  DSP16_Q(0.00303209),
  DSP16_Q(0.00902478),
  DSP16_Q(-0.08532346),
  DSP16_Q(0.53512438),
  DSP16_Q(0.29475521),
  DSP16_Q(-0.05488940),
  DSP16_Q(0.00290244),
  DSP16_Q(0.00914493),
  DSP16_Q(-0.08546812),
  DSP16_Q(0.54030957),
  DSP16_Q(0.28870482),
  DSP16_Q(-0.05380498),
  DSP16_Q(0.00277546),
  DSP16_Q(0.00926057),
  DSP16_Q(-0.08557193),
  DSP16_Q(0.54543953),
  DSP16_Q(0.28266829),
  DSP16_Q(-0.05271569),
  DSP16_Q(0.00265123),
  DSP16_Q(0.00937145),
  DSP16_Q(-0.08563405),
  DSP16_Q(0.55051271),
  DSP16_Q(0.27664709),
  DSP16_Q(-0.05162223),
  DSP16_Q(0.00252981),
  DSP16_Q(0.00947731),
  DSP16_Q(-0.08565365),
  DSP16_Q(0.55552764),
  DSP16_Q(0.27064271),
  DSP16_Q(-0.05052531),
  DSP16_Q(0.00241124),
  DSP16_Q(0.00957788),
  DSP16_Q(-0.08562990),
  DSP16_Q(0.56048280),
  DSP16_Q(0.26465661),
  DSP16_Q(-0.04942562),
  DSP16_Q(0.00229558),
  DSP16_Q(0.00967292),
  DSP16_Q(-0.08556199),
  DSP16_Q(0.56537673),
  DSP16_Q(0.25869026),
  DSP16_Q(-0.04832383),
  DSP16_Q(0.00218287),
  DSP16_Q(0.00976216),
  DSP16_Q(-0.08544909),
  DSP16_Q(0.57020796),
  DSP16_Q(0.25274507),
  DSP16_Q(-0.04722063),
  DSP16_Q(0.00207315),
  DSP16_Q(0.00984534),
  DSP16_Q(-0.08529041),
  DSP16_Q(0.57497506),
  DSP16_Q(0.24682247),
  DSP16_Q(-0.04611666),
  DSP16_Q(0.00196646),
  DSP16_Q(0.00992220),
  DSP16_Q(-0.08508515),
  DSP16_Q(0.57967658),
  DSP16_Q(0.24092387),
  DSP16_Q(-0.04501257),
  DSP16_Q(0.00186281),
  DSP16_Q(0.00999247),
  DSP16_Q(-0.08483252),
  DSP16_Q(0.58431113),
  DSP16_Q(0.23505065),
  DSP16_Q(-0.04390901),
  DSP16_Q(0.00176225),
  DSP16_Q(0.01005589),
  DSP16_Q(-0.08453175),
  DSP16_Q(0.58887729),
  DSP16_Q(0.22920418),
  DSP16_Q(-0.04280658),
  DSP16_Q(0.00166478),
  DSP16_Q(0.01011220),
  DSP16_Q(-0.08418206),
  DSP16_Q(0.59337370),
  DSP16_Q(0.22338581),
  DSP16_Q(-0.04170591),
  DSP16_Q(0.00157043),
  DSP16_Q(0.01016112),
  DSP16_Q(-0.08378270),
  DSP16_Q(0.59779900),
  DSP16_Q(0.21759688),
  DSP16_Q(-0.04060759),
  DSP16_Q(0.00147919),
  DSP16_Q(0.01020240),
  DSP16_Q(-0.08333291),
  DSP16_Q(0.60215185),
  DSP16_Q(0.21183871),
  DSP16_Q(-0.03951222),
  DSP16_Q(0.00139108),
  DSP16_Q(0.01023577),
  DSP16_Q(-0.08283197),
  DSP16_Q(0.60643093),
  DSP16_Q(0.20611258),
  DSP16_Q(-0.03842036),
  DSP16_Q(0.00130609),
  DSP16_Q(0.01026096),
  DSP16_Q(-0.08227916),
  DSP16_Q(0.61063493),
  DSP16_Q(0.20041979),
  DSP16_Q(-0.03733259),
  DSP16_Q(0.00122422),
  DSP16_Q(0.01027771),
  DSP16_Q(-0.08167374),
  DSP16_Q(0.61476259),
  DSP16_Q(0.19476158),
  DSP16_Q(-0.03624944),
  DSP16_Q(0.00114547),
  DSP16_Q(0.01028577),
  DSP16_Q(-0.08101503),
  DSP16_Q(0.61881264),
  DSP16_Q(0.18913920),
  DSP16_Q(-0.03517146),
  DSP16_Q(0.00106981),
  DSP16_Q(0.01028486),
  DSP16_Q(-0.08030234),
  DSP16_Q(0.62278385),
  DSP16_Q(0.18355387),
  DSP16_Q(-0.03409918),
  DSP16_Q(0.00099723),
  DSP16_Q(0.01027473),
  DSP16_Q(-0.07953499),
  DSP16_Q(0.62667500),
  DSP16_Q(0.17800677),
  DSP16_Q(-0.03303311),
  DSP16_Q(0.00092771),
  DSP16_Q(0.01025511),
  DSP16_Q(-0.07871232),
  DSP16_Q(0.63048491),
  DSP16_Q(0.17249909),
  DSP16_Q(-0.03197374),
  DSP16_Q(0.00086122),
  DSP16_Q(0.01022575),
  DSP16_Q(-0.07783369),
  DSP16_Q(0.63421240),
  DSP16_Q(0.16703198),
  DSP16_Q(-0.03092157),
  DSP16_Q(0.00079774),
  DSP16_Q(0.01018640),
  DSP16_Q(-0.07689845),
  DSP16_Q(0.63785633),
  DSP16_Q(0.16160657),
  DSP16_Q(-0.02987706),
  DSP16_Q(0.00073722),
  DSP16_Q(0.01013680),
  DSP16_Q(-0.07590600),
  DSP16_Q(0.64141558),
  DSP16_Q(0.15622398),
  DSP16_Q(-0.02884067),
  DSP16_Q(0.00067964),
  DSP16_Q(0.01007670),
  DSP16_Q(-0.07485574),
  DSP16_Q(0.64488905),
  DSP16_Q(0.15088530),
  DSP16_Q(-0.02781286),
  DSP16_Q(0.00062494),
  DSP16_Q(0.01000585),
  DSP16_Q(-0.07374707),
  DSP16_Q(0.64827569),
  DSP16_Q(0.14559158),
  DSP16_Q(-0.02679406),
  DSP16_Q(0.00057309),
  DSP16_Q(0.00992401),
  DSP16_Q(-0.07257942),
  DSP16_Q(0.65157443),
  DSP16_Q(0.14034387),
  DSP16_Q(-0.02578468),
  DSP16_Q(0.00052403),
  DSP16_Q(0.00983093),
  DSP16_Q(-0.07135224),
  DSP16_Q(0.65478427),
  DSP16_Q(0.13514319),
  DSP16_Q(-0.02478514),
  DSP16_Q(0.00047772),
  DSP16_Q(0.00972637),
  DSP16_Q(-0.07006500),
  DSP16_Q(0.65790420),
  DSP16_Q(0.12999054),
  DSP16_Q(-0.02379582),
  DSP16_Q(0.00043409),
  DSP16_Q(0.00961011),
  DSP16_Q(-0.06871717),
  DSP16_Q(0.66093327),
  DSP16_Q(0.12488688),
  DSP16_Q(-0.02281711),
  DSP16_Q(0.00039310),
  DSP16_Q(0.00948191),
  DSP16_Q(-0.06730825),
  DSP16_Q(0.66387053),
  DSP16_Q(0.11983317),
  DSP16_Q(-0.02184937),
  DSP16_Q(0.00035467),
  DSP16_Q(0.00934153),
  DSP16_Q(-0.06583776),
  DSP16_Q(0.66671508),
  DSP16_Q(0.11483032),
  DSP16_Q(-0.02089296),
  DSP16_Q(0.00031874),
  DSP16_Q(0.00918877),
  DSP16_Q(-0.06430524),
  DSP16_Q(0.66946602),
  DSP16_Q(0.10987925),
  DSP16_Q(-0.01994821),
  DSP16_Q(0.00028525),
  DSP16_Q(0.00902339),
  DSP16_Q(-0.06271022),
  DSP16_Q(0.67212251),
  DSP16_Q(0.10498081),
  DSP16_Q(-0.01901545),
  DSP16_Q(0.00025413),
  DSP16_Q(0.00884519),
  DSP16_Q(-0.06105230),
  DSP16_Q(0.67468372),
  DSP16_Q(0.10013587),
  DSP16_Q(-0.01809499),
  DSP16_Q(0.00022530),
  DSP16_Q(0.00865396),
  DSP16_Q(-0.05933106),
  DSP16_Q(0.67714886),
  DSP16_Q(0.09534524),
  DSP16_Q(-0.01718714),
  DSP16_Q(0.00019869),
  DSP16_Q(0.00844949),
  DSP16_Q(-0.05754611),
  DSP16_Q(0.67951714),
  DSP16_Q(0.09060973),
  DSP16_Q(-0.01629218),
  DSP16_Q(0.00017422),
  DSP16_Q(0.00823159),
  DSP16_Q(-0.05569708),
  DSP16_Q(0.68178784),
  DSP16_Q(0.08593010),
  DSP16_Q(-0.01541037),
  DSP16_Q(0.00015182),
  DSP16_Q(0.00800006),
  DSP16_Q(-0.05378363),
  DSP16_Q(0.68396024),
  DSP16_Q(0.08130711),
  DSP16_Q(-0.01454199),
  DSP16_Q(0.00013139),
  DSP16_Q(0.00775472),
  DSP16_Q(-0.05180543),
  DSP16_Q(0.68603367),
  DSP16_Q(0.07674147),
  DSP16_Q(-0.01368727),
  DSP16_Q(0.00011286),
  DSP16_Q(0.00749539),
  DSP16_Q(-0.04976217),
  DSP16_Q(0.68800748),
  DSP16_Q(0.07223389),
  DSP16_Q(-0.01284645),
  DSP16_Q(0.00009614),
  DSP16_Q(0.00722189),
  DSP16_Q(-0.04765357),
  DSP16_Q(0.68988106),
  DSP16_Q(0.06778504),
  DSP16_Q(-0.01201975),
  DSP16_Q(0.00008114),
  DSP16_Q(0.00693406),
  DSP16_Q(-0.04547938),
  DSP16_Q(0.69165380),
  DSP16_Q(0.06339555),
  DSP16_Q(-0.01120737),
  DSP16_Q(0.00006778),
  DSP16_Q(0.00663173),
  DSP16_Q(-0.04323934),
  DSP16_Q(0.69332517),
  DSP16_Q(0.05906605),
  DSP16_Q(-0.01040951),
  DSP16_Q(0.00005596),
  DSP16_Q(0.00631476),
  DSP16_Q(-0.04093324),
  DSP16_Q(0.69489463),
  DSP16_Q(0.05479713),
  DSP16_Q(-0.00962635),
  DSP16_Q(0.00004560),
  DSP16_Q(0.00598300),
  DSP16_Q(-0.03856089),
  DSP16_Q(0.69636170),
  DSP16_Q(0.05058935),
  DSP16_Q(-0.00885805),
  DSP16_Q(0.00003660),
  DSP16_Q(0.00563631),
  DSP16_Q(-0.03612211),
  DSP16_Q(0.69772591),
  DSP16_Q(0.04644326),
  DSP16_Q(-0.00810477),
  DSP16_Q(0.00002886),
  DSP16_Q(0.00527456),
  DSP16_Q(-0.03361676),
  DSP16_Q(0.69898684),
  DSP16_Q(0.04235937),
  DSP16_Q(-0.00736666),
  DSP16_Q(0.00002230),
  DSP16_Q(0.00489763),
  DSP16_Q(-0.03104470),
  DSP16_Q(0.70014408),
  DSP16_Q(0.03833815),
  DSP16_Q(-0.00664384),
  DSP16_Q(0.00001682),
  DSP16_Q(0.00450540),
  DSP16_Q(-0.02840585),
  DSP16_Q(0.70119729),
  DSP16_Q(0.03438009),
  DSP16_Q(-0.00593643),
  DSP16_Q(0.00001232),
  DSP16_Q(0.00409778),
  DSP16_Q(-0.02570011),
  DSP16_Q(0.70214612),
  DSP16_Q(0.03048560),
  DSP16_Q(-0.00524454),
  DSP16_Q(0.00000870),
  DSP16_Q(0.00367465),
  DSP16_Q(-0.02292744),
  DSP16_Q(0.70299027),
  DSP16_Q(0.02665509),
  DSP16_Q(-0.00456826),
  DSP16_Q(0.00000587),
  DSP16_Q(0.00323595),
  DSP16_Q(-0.02008781),
  DSP16_Q(0.70372949),
  DSP16_Q(0.02288896),
  DSP16_Q(-0.00390767),
  DSP16_Q(0.00000373),
  DSP16_Q(0.00278158),
  DSP16_Q(-0.01718120),
  DSP16_Q(0.70436354),
  DSP16_Q(0.01918754),
  DSP16_Q(-0.00326284),
  DSP16_Q(0.00000219),
  DSP16_Q(0.00231148),
  DSP16_Q(-0.01420766),
  DSP16_Q(0.70489222),
  DSP16_Q(0.01555118),
  DSP16_Q(-0.00263382),
  DSP16_Q(0.00000115),
  DSP16_Q(0.00182559),
  DSP16_Q(-0.01116720),
  DSP16_Q(0.70531536),
  DSP16_Q(0.01198016),
  DSP16_Q(-0.00202068),
  DSP16_Q(0.00000050),
  DSP16_Q(0.00132386),
  DSP16_Q(-0.00805992),
  DSP16_Q(0.70563283),
  DSP16_Q(0.00847477),
  DSP16_Q(-0.00142343),
  DSP16_Q(0.00000016),
  DSP16_Q(0.00080625),
  DSP16_Q(-0.00488590),
  DSP16_Q(0.70584454),
  DSP16_Q(0.00503526),
  DSP16_Q(-0.00084210),
  DSP16_Q(0.00000002),
  DSP16_Q(0.00027273),
  DSP16_Q(-0.00164526),
  DSP16_Q(0.70595041),
  DSP16_Q(0.00166185),
  DSP16_Q(-0.00027672),
  DSP16_Q(0.00000000)
};
